# vi: ts=8 sw=8 sts=8

package Tongues::Balgarski;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Cyrillic CP1251
# not KOI8-R or ISO 8859-5

# Alphabetical order
#                              
#                              

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::CyrillicWin;

$charset = new Charsets::CyrillicWin;

# Table for converting words to root form
$grammar = [
 # Noun case
 # Noun gender
 # Noun plural
 [ '',		'',	'',		's',	'n' ],
 # Adjectives
 # Verb past participle
 # Verb gerund
 # Verb present participle
 # Verb present
 # Verb present subjunctive
 # Verb imperitive
 # Verb preterite
 # Verb imperfect
 # Verb future
 # Verb conditional
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translation		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			nouns, pronouns, adjectives
#	m -> masculine		default
#	f -> feminine
#	n -> neuter
# n -> number:			articles, pronouns, verbs, adjectives
#	s -> singular		default
#	p -> plural		default for words ending in s
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative
# c -> case:
#	n -> nominative 
#	g -> genitive 
#	d -> dative 
#	a -> accusative 
#	v -> vocative 
#	l -> locative 
#	inst -> instrumental 

# Russian to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 #    Masculine
 #     Singular
 #     Plural
 #    Feminine
 #     Singular
 #     Plural
 #   Indefinite articles
 #  Pronouns & possessive adjectives
 #   1st person
 #   2nd person
 #   3rd person
 #  Other functional words
 ''		=> { 'x' => 'in',
		     '#' => 'on, at, within',
 		     't' => 'p' },
 ''	=> { 'x' => 'every',
		     '#' => 'each; everyone' },
 ''	=> { 'x' => 'everything',
		     '#' => 'all' },
 ''		=> { 'x' => 'yes',
		     '#' => 'let (subjunctive particle?)',
 		     't' => 'interj' },
 ''		=> { 'x' => 'for',
		     '#' => 'to',
 		     't' => 'p' },
 ''		=> { 'x' => 'and',
		     '#' => 'also, too; her!',
 		     't' => 'conj' },
 ''		=> { 'x' => 'or',
		     '#' => 'either',
 		     't' => 'conj' },
 ''	=> { 'x' => 'what' },
 ''		=> { 'x' => 'toward',
		     '#' => 'to, about, near',
 		     't' => 'p' },
 ''		=> { 'x' => 'of',
		     '#' => 'to; on, upon, at, in; on; for',
 		     't' => 'p' },
 ''		=> { 'x' => 'no',
		     '#' => 'not' },
 ''		=> { 'x' => 'from',
		     '#' => 'away from, out of, off',
 		     't' => 'p' },
 ''		=> { 'x' => 'on',
		     '#' => 'over, along',
 		     't' => 'p' },
 ''		=> { 'x' => 'at',
		     '#' => 'near, by, close to, with, at',
 		     't' => 'p' },
 ''		=> { 'x' => 'with',
		     '#' => 'and',
 		     't' => 'p' },
 ''		=> { 'x' => 'that',
		     '#' => 'he said *that* ...; because' },
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 ''		=> { 'x' => 'hundred' },
 ''	=> { 'x' => 'thousand' },
 # Days and months
 ''	=> { 'x' => 'sunday' },
 ''	=> { 'x' => 'monday' },
 ''	=> { 'x' => 'tuesday' },
 ''	=> { 'x' => 'wednesday' },
 ''	=> { 'x' => 'thursday' },
 ''	=> { 'x' => 'friday' },
 ''	=> { 'x' => 'saturday' },
 ''	=> { 'x' => 'january' },
 ''	=> { 'x' => 'february' },
 ''		=> { 'x' => 'march' },
 ''	=> { 'x' => 'april' },
 ''		=> { 'x' => 'may' },
 ''		=> { 'x' => 'june' },
 ''		=> { 'x' => 'july' },
 ''	=> { 'x' => 'august' },
 ''	=> { 'x' => 'september' },
 ''	=> { 'x' => 'october' },
 ''	=> { 'x' => 'november' },
 ''	=> { 'x' => 'december' },
 # Key verbs
 ''		=> { 'x' => 'there is',
		     '#' => 'there are; shall, will',
 		     't' => 'v' },
 ''	=> { 'x' => 'must',
		     '#' => 'should, have to' },
 # Vocabulary
 ''	=> { 'x' => 'australia',
 		     't' => 'n' },
 ''	=> { 'x' => 'austria',
 		     't' => 'n' },
 ''		=> { 'x' => 'asia',
 		     't' => 'n' },
 ''	=> { 'x' => 'albania',
 		     't' => 'n' },
 ''	=> { 'x' => 'america',
 		     't' => 'n' },
 ''	=> { 'x' => 'english',
 		     't' => 'n' },
 ''	=> { 'x' => 'arabic',
		     '#' => 'adj. and noun?' },
 ''	=> { 'x' => 'astronaut',
 		     't' => 'n' },
 ''	=> { 'x' => 'africa',
 		     't' => 'n' },
 ''		=> { 'x' => 'beer',
 		     't' => 'n' },
 ''	=> { 'x' => 'brazil',
 		     't' => 'n' },
 ''	=> { 'x' => 'bulgaria',
 		     't' => 'n' },
 ''	=> { 'x' => 'bulgarian',
		     '#' => 'language; noun and/or adj.?' },
 ''	=> { 'x' => 'germany',
 		     't' => 'n' },
 ''	=> { 'x' => 'hungry',
 		     't' => 'a' },
 ''	=> { 'x' => 'speak',
 		     't' => 'v' },
 ''	=> { 'x' => 'grammar',
 		     't' => 'n' },
 ''	=> { 'x' => 'denmark',
 		     't' => 'n' },
 ''	=> { 'x' => 'greece',
 		     't' => 'n' },
 ''	=> { 'x' => 'europe',
 		     't' => 'n' },
 ''		=> { 'x' => 'language',
		     '#' => 'tongue',
 		     't' => 'n' },
 ''	=> { 'x' => 'electricity',
 			     't' => 'n' },
 ''		=> { 'x' => 'autumn',
		     '#' => 'fall',
 		     't' => 'n' },
 ''	=> { 'x' => 'gesticulate',
 		     't' => 'v' },
 ''		=> { 'x' => 'winter',
 		     't' => 'n' },
 ''	=> { 'x' => 'israel',
 		     't' => 'n' },
 ''	=> { 'x' => 'india',
 		     't' => 'n' },
 ''	=> { 'x' => 'ireland',
 		     't' => 'n' },
 ''	=> { 'x' => 'iceland',
 		     't' => 'n' },
 ''	=> { 'x' => 'spain',
 		     't' => 'n' },
 ''	=> { 'x' => 'italy',
 		     't' => 'n' },
 ''	=> { 'x' => 'canada',
 		     't' => 'n' },
 ''	=> { 'x' => 'cartography',
 		     't' => 'n' },
 ''		=> { 'x' => 'coffee',
 		     't' => 'n' },
 ''	=> { 'x' => 'china',
 		     't' => 'n' },
 ''	=> { 'x' => 'computer',
 		     't' => 'n' },
 ''	=> { 'x' => 'korea',
 		     't' => 'n' },
 ''	=> { 'x' => 'cosmonaut',
 		     't' => 'n' },
 ''	=> { 'x' => 'latin',
		     '#' => 'adj.?',
 		     't' => 'n' },
 ''		=> { 'x' => 'summer',
 		     't' => 'n' },
 ''	=> { 'x' => 'mexico',
 		     't' => 'n' },
 ''	=> { 'x' => 'norway',
 		     't' => 'n' },
 ''	=> { 'x' => 'passport',
 		     't' => 'n' },
 ''		=> { 'x' => 'beach',
 		     't' => 'n' },
 ''	=> { 'x' => 'poland',
 		     't' => 'n' },
 ''	=> { 'x' => 'portugal',
 		     't' => 'n' },
 ''	=> { 'x' => 'right',
		     '#' => 'title; law, justice',
 		     't' => 'n' },
 ''	=> { 'x' => 'translate',
		     '#' => 'render, interpret',
 		     't' => 'v' },
 ''	=> { 'x' => 'swim',
 		     't' => 'v' },
 ''	=> { 'x' => 'trip',
		     '#' => 'journey, voyage',
 		     't' => 'n' },
 ''	=> { 'x' => 'travel',
		     '#' => 'journey, voyage, sail, fly',
 		     't' => 'v' },
 ''	=> { 'x' => 'dictionary',
 		     't' => 'n' },
 ''	=> { 'x' => 'russia',
 		     't' => 'n' },
 ''	=> { 'x' => 'sofia',
 		     't' => 'n' },
 ''	=> { 'x' => 'telephone',
 		     't' => 'n' },
 ''	=> { 'x' => 'turkey',
		     '#' => 'the country',
 		     't' => 'n' },
 ''	=> { 'x' => 'hungary',
 		     't' => 'n' },
 ''	=> { 'x' => 'finland',
 		     't' => 'n' },
 ''	=> { 'x' => 'france',
 		     't' => 'n' },
 ''	=> { 'x' => 'french',
		     '#' => 'adj. and noun?' },
 ''	=> { 'x' => 'holland',
 		     't' => 'n' },
 ''	=> { 'x' => 'gypsy',
 		     't' => 'n' },
 ''	=> { 'x' => 'czech',
		     '#' => 'the language?',
 		     't' => 'n' },
 ''		=> { 'x' => 'article',
		     '#' => 'member, fellow, clause',
 		     't' => 'n' },
 ''	=> { 'x' => 'man',
		     '#' => 'person, guy',
 		     't' => 'n' },
 ''	=> { 'x' => 'foreigner',
 		     't' => 'n' },
 ''	=> { 'x' => 'switzerland',
 		     't' => 'n' },
 ''	=> { 'x' => 'sweden',
 		     't' => 'n' },
 ''	=> { 'x' => 'chocolate',
 		     't' => 'n' },
 ''	=> { 'x' => 'scotland',
 		     't' => 'n' },
 ''	=> { 'x' => 'yugoslavia',
 		     't' => 'n' },
 ''		=> { 'x' => 'eat',
 		     't' => 'v' },
 ''	=> { 'x' => 'japan',
 		     't' => 'n' },
);
}

1;

