# vi: ts=8 sw=8 sts=8

package Tongues::Esperanto;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set UTF-8 

# Alphabetical order
# A B C Ĉ D E F G Ĝ H Ĥ I J Ĵ K L M N O P Q R S Ŝ T U Ŭ V W X Y Z
# a b c ĉ d e f g ĝ h ĥ i j ĵ k l m n o p q r s ŝ t u ŭ v w x y z

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::UTF_8::Esperanto;

$charset = new Charsets::UTF_8::Esperanto;

# Table for converting words to root form
$grammar = [
 # Pronoun
 [ 'n',		'',	'',		'',	'pro' ],	# obj.
 [ 'a',		'',	'',		'\'s',	'pro' ],	# poss. adj.
 [ 'aj',	'',	'',		'\'s',	'pro' ],	# poss. adj. plural
 # Noun
 # Noun object
 [ 'on',	'o',	'',		'',	'n' ],
 # Noun gender
 [ 'ino',	'o',	'',		'',	'n' ],	# feminine
 [ 'inon',	'o',	'',		'',	'n' ],	# feminine obj.
 # Noun plural
 [ 'oj',	'o',	'',		's',	'n' ],
 [ 'ojn',	'o',	'',		's',	'n' ],	# plural obj.
 [ 'inoj',	'o',	'',		's',	'n' ],	# fem. plural
 [ 'inojn',	'o',	'',		's',	'n' ],	# fem. plural obj.
 [ 'ge-oj',	'o',	'',		's',	'n' ],	# mixed genders
 [ 'ge-ojn',	'o',	'',		's',	'n' ],	# mixed genders obj.
 # Adjective
 # Adjective plural
 [ 'aj',	'a',	'',		'',	'a' ],
 # Adjective opposite
 [ 'mal-',	'',	'un',		'',	'a' ],
 # Verb
 # Verb present
 [ 'as',	'i',	'',		'',	'v' ],
 # Verb past
 [ 'is',	'i',	'',		'ed',	'v' ],
 # Verb future
 [ 'os',	'i',	'will ',	'',	'v' ],
 # Verb imperitive
 [ 'u',		'i',	'',		'',	'v' ],
 # Verb continuous?
 [ 'ante',	'i',	'',		'ing',	'v' ],
 # Adverb
 [ 'en',	'e',	'',		'ward',		'adv' ],	# from adj.
 [ 'e',		'a',	'',		'ly',		'a' ],	# from adj.
 # Higher level transformations
 [ 'a',		'o',	'',		'',		'n' ],	# adj. from noun
 [ 'ego',	'o',	'big ',		'',		'n' ],	# aug.
 [ 'ega',	'a',	'big-',		'',		'a' ],	# aug.
 [ 'ejo',	'o',	'',		'place',	'n' ],
 [ 'eto',	'o',	'little ',	'',		'n' ],	# dimin.
 [ 'eta',	'a',	'a little ',	'',		'a' ],	# dimin.
 [ 'ulo',	'a',	'',		'person',	'a' ],
 [ 'ulo',	'o',	'',		'person',	'n' ],
 [ 're-',	'',	're-',		'',		'v' ],	# back
 [ 'io',	'ujo',	'',		'',		'n' ],	# alt. country name
];

#Fields:
# x -> translatioin		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			pronouns
#	m -> masculine
#	f -> feminine
# n -> number:			nouns, pronouns
#	s -> singular		default
#	p -> plural
# p -> person:			pronouns
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative

# Esperanto to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 'la'		=> { 'x' => 'the' },
 #   Indefinite articles
 #  Pronouns & possessive adjectives
 #   1st person
 'mi'		=> { 'x' => 'me',
		     '#' => 'i',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 'ni'		=> { 'x' => 'we',
		     '#' => 'us',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 'p' },
 #   2nd person
 'vi'		=> { 'x' => 'you',
 		     't' => 'pro',
		     'p' => '2',
		     'n' => 's' },
 #   3rd person
 'li'		=> { 'x' => 'he',
		     '#' => 'him',
 		     't' => 'pro',
		     'p' => '3',
		     'n' => 's',
		     'g' => 'm' },
 'ŝi'		=> { 'x' => 'she',
		     '#' => 'her',
 		     't' => 'pro',
		     'p' => '3',
		     'n' => 's',
		     'g' => 'f' },
 'ĝi'		=> { 'x' => 'it',
 		     't' => 'pro',
		     'p' => '3',
		     'n' => 's',
		     'g' => 'n' },
 'ili'		=> { 'x' => 'they',
		     '#' => 'them',
 		     't' => 'pro',
		     'p' => '3',
		     'n' => 'p' },
 #   Other pronouns
 'kia'		=> { 'x' => 'what kind',
		     '#' => 'interr.' },
 'kie'		=> { 'x' => 'where',
		     '#' => 'interr.',
 		     't' => 'adv' },
 'kiel'		=> { 'x' => 'how',
		     '#' => 'interr.; like cf. es. como',
 		     't' => 'adv' },
 'kio'		=> { 'x' => 'what',
		     '#' => 'interr.',
 		     't' => 'pro',
		     'n' => 's' },
 'kioj'		=> { 'x' => 'what',
		     '#' => 'interr.',
 		     't' => 'pro',
		     'n' => 'p' },
 'kiu'		=> { 'x' => 'who',
		     '#' => 'interr.; which',
 		     't' => 'pro',
		     'n' => 's' },
 'kiuj'		=> { 'x' => 'who',
		     '#' => 'interr.; which',
 		     't' => 'pro',
		     'n' => 'p' },
 'tio'		=> { 'x' => 'that',
		     '#' => 'demon.; that one',
 		     't' => 'pro' },
 'tioj'		=> { 'x' => 'those',
		     '#' => 'demon.; that one',
 		     't' => 'pro',
		     'n' => 'p' },
 'tiu'		=> { 'x' => 'that',
		     '#' => 'demon.; that one',
 		     't' => 'pro' },
 'tiuj'		=> { 'x' => 'those',
		     '#' => 'demon.; that one',
 		     't' => 'pro',
		     'n' => 'p' },
 'si'		=> { 'x' => 'self',
		     '#' => 'reflexive pronoun',
		     't' => 'p' },
 #  Other functional words
 'ajn'		=> { 'x' => 'ever',
		     '#' => 'as in whoever, whatever' },
 'al'		=> { 'x' => 'to',
 		     't' => 'p' },
 'almenaŭ'	=> { 'x' => 'at least' },
 'ambaŭ'	=> { 'x' => 'both' },
 'ankaŭ'	=> { 'x' => 'also',
		     '#' => 'conj.?' },
 'ankoraŭ'	=> { 'x' => 'still',
		     '#' => 'yet' },
 'anstataŭ'	=> { 'x' => 'instead of' },
 'antaŭ'	=> { 'x' => 'before',
		     '#' => 'in front of',
 		     't' => 'p' },
 'antaŭen'	=> { 'x' => 'forwards',
 		     't' => 'adv' },
 'apud'		=> { 'x' => 'near',
 		     't' => 'p' },
 'aŭ'		=> { 'x' => 'or',
 		     't' => 'conj' },
 'baldaŭ'	=> { 'x' => 'soon',
 		     't' => 'adv' },
 'ĉar'		=> { 'x' => 'because',
 		     't' => 'conj' },
 'ĉe'		=> { 'x' => 'at',
 		     't' => 'p' },
 'ĉi'		=> { 'x' => 'here',
		     '#' => 'modifies tie, tiu' },
 'ĉirkaŭ'	=> { 'x' => 'round',
		     '#' => 'about; which part of speech?' },
 'ĉiuj'		=> { 'x' => 'all' },
 'ĉu'		=> { 'x' => 'if',
		     '#' => 'whether; question particle cf jap. -ka' },
 'dankon'	=> { 'x' => 'thank you',
		     '#' => 'please?',
 		     't' => 'interj' },
 'de'		=> { 'x' => 'of',
		     '#' => 'from',
 		     't' => 'p' },
 'dum'		=> { 'x' => 'during',
		     '#' => 'while',
 		     't' => 'p' },
 'eĉ'		=> { 'x' => 'even',
		     '#' => 'adv.?, conj.?' },
 'el'		=> { 'x' => 'out of',
		     '#' => 'multiword',
 		     't' => 'p' },
 'en'		=> { 'x' => 'in',
 		     't' => 'p' },
 'ha'		=> { 'x' => 'ah',
 		     't' => 'interj' },
 'hieraŭ'	=> { 'x' => 'yesterday',
		     '#' => 'adv.?' },
 'jam'		=> { 'x' => 'already',
 		     't' => 'adv' },
 'je'		=> { 'x' => 'on',
		     '#' => 'indef.!; at',
 		     't' => 'p' },
 'jen'		=> { 'x' => 'here is',
		     '#' => 'behold!' },
 'jes'		=> { 'x' => 'yes',
		     '#' => 'interj.',
 		     't' => 'interj' },
 'ĵus'		=> { 'x' => 'just',
		     '#' => 'cf es "acabo de"',
 		     't' => 'adv' },
 'kaj'		=> { 'x' => 'and',
 		     't' => 'conj' },
 'ke'		=> { 'x' => 'that',
 		     't' => 'conj' },
 'kelkaj'	=> { 'x' => 'several',
		     '#' => 'a few' },
 'kial'		=> { 'x' => 'why' },
 'kie'		=> { 'x' => 'where',
		     '#' => 'interr. adv.?' },
 'kontraŭ'	=> { 'x' => 'opposite',
 		     't' => 'p' },
 'kun'		=> { 'x' => 'with',
		     '#' => 'accomp. or instrum.?',
 		     't' => 'p' },
 'malantaŭ'	=> { 'x' => 'behind',
 		     't' => 'p' },
 'malantaŭen'	=> { 'x' => 'backwards',
 		     't' => 'adv' },
 'malsupren'	=> { 'x' => 'downwards',
 		     't' => 'adv' },
 'morgaŭ'	=> { 'x' => 'tomorrow',
 		     't' => 'adv' },
 'multaj'	=> { 'x' => 'many',
		     '#' => 'a lot of' },
 'ne'		=> { 'x' => 'no',
 		     't' => 'interj' },
 'nu'		=> { 'x' => 'well',
		     '#' => 'well (then)',
 		     't' => 'interj' },
 'nun'		=> { 'x' => 'now',
		     '#' => 'adv.' },
 'nur'		=> { 'x' => 'only',
		     '#' => 'merely' },
 'plej'		=> { 'x' => 'most',
		     't' => 'adv' },
 'pli'		=> { 'x' => 'more',
		     't' => 'adv' },
 'por'		=> { 'x' => 'for',
 		     't' => 'p' },
 'post'		=> { 'x' => 'after',
 		     't' => 'p' },
 'poste'	=> { 'x' => 'afterwards' },
 'pri'		=> { 'x' => 'about',
		     '#' => 'concerning',
 		     't' => 'p' },
 'pro'		=> { 'x' => 'for',
		     '#' => 'because of',
 		     't' => 'p' },
 'septembro'	=> { 'x' => 'september' },
 'saluton'	=> { 'x' => 'hello',
 		     't' => 'interj' },
 'se'		=> { 'x' => 'if',
		     't' => 'conj' },
 'sed'		=> { 'x' => 'but',
 		     't' => 'conj' },
 'sen'		=> { 'x' => 'without',
		     't' => 'p' },
 'sub'		=> { 'x' => 'under',
		     '#' => 'below',
 		     't' => 'p' },
 'super'	=> { 'x' => 'above',
		     '#' => 'over',
 		     't' => 'p' },
 'supre'	=> { 'x' => 'above',
 		     't' => 'adv' },
 'supren'	=> { 'x' => 'upwards',
 		     't' => 'adv' },
 'sur'		=> { 'x' => 'on',
 		     't' => 'p' },
 'tia'		=> { 'x' => 'such' },
 'tial'		=> { 'x' => 'therefore',
		     '#' => 'for that reason' },
 'tie'		=> { 'x' => 'there',
		     '#' => 'in that place',
 		     't' => 'adv' },
 'tiel'		=> { 'x' => 'thus',
		     '#' => 'in that way',
		     'x-es' => 'así',
 		     't' => 'adv' },
 'tra'		=> { 'x' => 'through',
		     't' => 'p' },
 'tre'		=> { 'x' => 'very',
		     '#' => 'very much' },
 'tuj'		=> { 'x' => 'immediately',
		     't' => 'adv' },
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 'unu'		=> { 'x' => 'one' },
 'du'		=> { 'x' => 'two' },
 'tri'		=> { 'x' => 'three' },
 'kvar'		=> { 'x' => 'four' },
 'kvin'		=> { 'x' => 'five' },
 'ses'		=> { 'x' => 'six' },
 'sep'		=> { 'x' => 'seven' },
 'ok'		=> { 'x' => 'eight' },
 'naŭ'		=> { 'x' => 'nine' },
 'dek'		=> { 'x' => 'ten' },
 'cent'		=> { 'x' => 'hundred' },
 'mil'		=> { 'x' => 'thousand' },
 # Days and months
 'dimanĉo'	=> { 'x' => 'sunday' },
 'lundo'	=> { 'x' => 'monday' },
 'mardo'	=> { 'x' => 'tuesday' },
 'merkredo'	=> { 'x' => 'wednesday' },
 'ĵaŭdo'	=> { 'x' => 'thursday' },
 'vendredo'	=> { 'x' => 'friday' },
 'sabato'	=> { 'x' => 'saturday' },
 'januaro'	=> { 'x' => 'january' },
 'februaro'	=> { 'x' => 'february' },
 'marto'	=> { 'x' => 'march' },
 'aprilo'	=> { 'x' => 'april' },
 'majo'		=> { 'x' => 'may' },
 'junio'	=> { 'x' => 'june' },
 'julio'	=> { 'x' => 'july' },
 'aŭgusto'	=> { 'x' => 'august' },
 'septembro'	=> { 'x' => 'september' },
 'oktobro'	=> { 'x' => 'october' },
 'novembro'	=> { 'x' => 'november' },
 'decembro'	=> { 'x' => 'december' },
 # Key verbs
 'esti'		=> { 'x' => 'be' },
 'havi'		=> { 'x' => 'have' },
 'iri'		=> { 'x' => 'go' },
 'povi'		=> { 'x' => 'can' },
 'preni'	=> { 'x' => 'take' },
 'uzi'		=> { 'x' => 'use' },
 'voli'		=> { 'x' => 'want' },
 # Vocabulary
 'aboni'	=> { 'x' => 'subscribe',
		     '#' => 'subscribe to' },
 'absoluta'	=> { 'x' => 'absolute' },
 'acida'	=> { 'x' => 'sour',
		     '#' => 'acid' },
 'aĉeti'	=> { 'x' => 'buy' },
 'aĉaĵo'	=> { 'x' => 'abomination',
		     '#' => '-aĉ-' },
 'aĉulo'	=> { 'x' => 'creep',
		     '#' => '-aĉ-; thug; person' },
 'adiaŭ'	=> { 'x' => 'good-bye',
 		     't' => 'interj' },
 'adiaŭi'	=> { 'x' => 'say good-bye',
		     '#' => 'multiword' },
 'admiri'	=> { 'x' => 'admire' },
 'adolta'	=> { 'x' => 'adult' },
 'adori'	=> { 'x' => 'adore',
		     '#' => 'worship' },
 'adreso'	=> { 'x' => 'address' },
 'aero'		=> { 'x' => 'air' },
 'aerumi'	=> { 'x' => 'air',
		     '#' => '-um-; aerate, ventilate' },
 'afabla'	=> { 'x' => 'kind',
		     '#' => 'affable' },
 'afero'	=> { 'x' => 'matter',
		     '#' => 'affair, thing' },
 'agadi'	=> { 'x' => 'act',
		     '#' => '-ad-' },
 'agado'	=> { 'x' => 'activity',
		     '#' => '-ad-; action' },
 'agi'		=> { 'x' => 'act' },
 'agiti'	=> { 'x' => 'agitate' },
 'agrabla'	=> { 'x' => 'pleasant',
		     '#' => 'agreeable' },
 'aĝo'		=> { 'x' => 'age' },
 'aĵo'		=> { 'x' => 'thing',
		     '#' => '-aĵ-; object' },
 'akceli'	=> { 'x' => 'accelerate' },
 'akcepti'	=> { 'x' => 'accept' },
 'akcidento'	=> { 'x' => 'accident' },
 'akiri'	=> { 'x' => 'acquire',
		     '#' => 'get' },
 'akompani'	=> { 'x' => 'accompany' },
 'akra'		=> { 'x' => 'sharp' },
 'akrobato'	=> { 'x' => 'acrobat' },
 'aktoro'	=> { 'x' => 'actor' },
 'aktori'	=> { 'x' => 'act',
		     '#' => '(a role)' },
 'aktuala'	=> { 'x' => 'topical',
		     '#' => 'present; (not actual)' },
 'akurata'	=> { 'x' => 'punctual',
		     '#' => 'prompt; (not accurate)' },
 'akuzi'	=> { 'x' => 'accuse',
		     '#' => 'charge' },
 'akvo'		=> { 'x' => 'water' },
 'alfabeto'	=> { 'x' => 'alphabet' },
 'algebro'	=> { 'x' => 'algebra' },
 'alĝerio'	=> { 'x' => 'algeria',
		     '#' => 'proper; place' },
 'alia'		=> { 'x' => 'other' },
 'alkoholismo'	=> { 'x' => 'alcoholism',
		     '#' => '-ism-' },
 'alkoholo'	=> { 'x' => 'alcohol' },
 'allogi'	=> { 'x' => 'attract' },
 'alta'		=> { 'x' => 'high' },
 'amaso'	=> { 'x' => 'mass',
		     '#' => 'pile, heap, crowd' },
 'amatoro'	=> { 'x' => 'amature' },
 'ambasadoro'	=> { 'x' => 'ambassador' },
 'ambaŭseksema'	=> { 'x' => 'bisexual',
		     '#' => '-em-' },
 'ambulanco'	=> { 'x' => 'ambulance' },
 'ameriko'	=> { 'x' => 'america',
		     '#' => '(the continent)' },
 'ami'		=> { 'x' => 'love' },
 'amikeco'	=> { 'x' => 'friendship',
		     '#' => '-ec-' },
 'amiko'	=> { 'x' => 'friend' },
 'aminda'	=> { 'x' => 'loveable',
		     '#' => '-ind-' },
 'amo'		=> { 'x' => 'love' },
 'ampleksa'	=> { 'x' => 'extensive' },
 'ampleksi'	=> { 'x' => 'comprise',
		     '#' => 'cover' },
 'amuzi'	=> { 'x' => 'amuse' },
 'amuzo'	=> { 'x' => 'fun',
		     '#' => 'amusement' },
 'angla'	=> { 'x' => 'english' },
 'anglismo'	=> { 'x' => 'anglicism',
		     '#' => '-ism-' },
 'anglo'	=> { 'x' => 'englishman' },
 'anglujo'	=> { 'x' => 'england',
		     '#' => 'proper; place' },
 'angulo'	=> { 'x' => 'angle',
		     '#' => 'corner' },
 'animo'	=> { 'x' => 'soul' },
 'ano'		=> { 'x' => 'member',
		     '#' => '-an-' },
 'anonci'	=> { 'x' => 'announce' },
 'anonco'	=> { 'x' => 'announcement' },
 'antarkta'	=> { 'x' => 'antarctic' },
 'antaŭa'	=> { 'x' => 'previous' },
 'aparato'	=> { 'x' => 'apparatus' },
 'aparta'	=> { 'x' => 'separate',
		     '#' => 'particular' },
 'apartamento'	=> { 'x' => 'apartment' },
 'aparte'	=> { 'x' => 'specifically' },
 'aparteni'	=> { 'x' => 'belong' },
 'apenaŭ'	=> { 'x' => 'hardly',
		     '#' => 'scarcely' },
 'aperi'	=> { 'x' => 'appear' },
 'aplaŭdi'	=> { 'x' => 'applaud',
		     '#' => 'clap' },
 'apokalipso'	=> { 'x' => 'apocalypse' },
 'aprobi'	=> { 'x' => 'approve' },
 'aranĝi'	=> { 'x' => 'arrange' },
 'arbaro'	=> { 'x' => 'forest',
		     '#' => '-ar-; wood' },
 'arbo'		=> { 'x' => 'tree' },
 'aresti'	=> { 'x' => 'arrest' },
 'argilo'	=> { 'x' => 'clay' },
 'arĝento'	=> { 'x' => 'silver' },
 'aritmetiko'	=> { 'x' => 'arithmetic' },
 'arkta'	=> { 'x' => 'arctic' },
 'armi'		=> { 'x' => 'arm' },
 'armilo'	=> { 'x' => 'weapon',
		     '#' => 'arm' },
 'aro'		=> { 'x' => 'collection',
		     '#' => '-ar-; set' },
 'artikolo'	=> { 'x' => 'article' },
 'artiŝoko'	=> { 'x' => 'artichoke' },
 'artisto'	=> { 'x' => 'artist',
		     '#' => '-ist-' },
 'arto'		=> { 'x' => 'arto' },
 'asembleo'	=> { 'x' => 'assembly' },
 'aso'		=> { 'x' => 'ace',
		     '#' => '(playing cards)' },
 'aspekti'	=> { 'x' => 'appear',
		     '#' => 'look, seem' },
 'aspekto'	=> { 'x' => 'appearance' },
 'asocio'	=> { 'x' => 'association' },
 'ataki'	=> { 'x' => 'attack' },
 'atenci'	=> { 'x' => 'assault' },
 'atendi'	=> { 'x' => 'wait',
		     '#' => 'wait for, await, expect' },
 'atenti'	=> { 'x' => 'beware',
		     '#' => 'pay attention' },
 'atesti'	=> { 'x' => 'attest',
		     '#' => 'testify' },
 'atingi'	=> { 'x' => 'reach',
		     '#' => 'attain' },
 'atomo'	=> { 'x' => 'atom' },
 'aŭdantaro'	=> { 'x' => 'audience',
		     '#' => '-ar-' },
 'aŭdi'		=> { 'x' => 'hear' },
 'aŭskulti'	=> { 'x' => 'listen',
		     '#' => 'listen to' },
 'aŭstra'	=> { 'x' => 'austrian' },
 'aŭstraliano'	=> { 'x' => 'australian' },
 'aŭstralio'	=> { 'x' => 'australia',
		     '#' => 'proper; place' },
 'aŭstrujo'	=> { 'x' => 'austria',
		     '#' => 'proper; place' },
 'aŭto'		=> { 'x' => 'car' },
 'aŭtomata'	=> { 'x' => 'automatic' },
 'aŭtomobilo'	=> { 'x' => 'car' },
 'aŭtobus'	=> { 'x' => 'bus' },
 'aŭtuno'	=> { 'x' => 'autumn' },
 'avantaĝo'	=> { 'x' => 'advantage' },
 'avara'	=> { 'x' => 'mean',
		     '#' => 'miserly' },
 'aventuro'	=> { 'x' => 'adventure' },
 'averti'	=> { 'x' => 'warn' },
 'aviadilo'	=> { 'x' => 'aircraft' },
 'aviado'	=> { 'x' => 'aviation' },
 'avo'		=> { 'x' => 'grandfather' },
 'azeno'	=> { 'x' => 'donkey',
		     '#' => 'ass' },
 'azio'		=> { 'x' => 'asia',
		     '#' => 'proper; place' },
 'babilema'	=> { 'x' => 'loquacious',
		     '#' => '-em-' },
 'babili'	=> { 'x' => 'chat',
		     '#' => 'chatter' },
 'baki'		=> { 'x' => 'bake' },
 'bakujo'	=> { 'x' => 'oven' },
 'balai'	=> { 'x' => 'sweep' },
 'balailo'	=> { 'x' => 'broom' },
 'baleto'	=> { 'x' => 'ballet' },
 'balo'		=> { 'x' => 'ball',
		     '#' => 'dance' },
 'bani'		=> { 'x' => 'bathe' },
 'bankedo'	=> { 'x' => 'banquet' },
 'banko'	=> { 'x' => 'bank',
		     '#' => '(finance)' },
 'bano'		=> { 'x' => 'bath' },
 'bantuko'	=> { 'x' => 'towell',
		     '#' => 'bath towell' },
 'bari'		=> { 'x' => 'bar',
		     '#' => 'block, dam' },
 'barilo'	=> { 'x' => 'barrier' },
 'bastono'	=> { 'x' => 'stick' },
 'batali'	=> { 'x' => 'fight' },
 'batalo'	=> { 'x' => 'battle' },
 'bati'		=> { 'x' => 'beat',
		     '#' => 'strike' },
 'bazo'		=> { 'x' => 'base',
		     '#' => 'basis' },
 'bedaŭri'	=> { 'x' => 'regret' },
 'bedaŭrinde'	=> { 'x' => 'unfortunately' },
 'bela'		=> { 'x' => 'beautiful' },
 'belga'	=> { 'x' => 'belgian' },
 'belgujo'	=> { 'x' => 'belgium',
		     '#' => 'proper; place' },
 'beni'		=> { 'x' => 'bless' },
 'benko'	=> { 'x' => 'bench' },
 'benzino'	=> { 'x' => 'petrol' },
 'bestĝardeno'	=> { 'x' => 'zoo' },
 'besto'	=> { 'x' => 'animal',
		     '#' => 'animate' },
 'bezoni'	=> { 'x' => 'need',
		     '#' => 'require' },
 'biblio'	=> { 'x' => 'bible' },
 'biblioteko'	=> { 'x' => 'library' },
 'biciklisto'	=> { 'x' => 'cyclist',
		     '#' => '-ist-' },
 'biciklo'	=> { 'x' => 'bicycle' },
 'bido'		=> { 'x' => 'bead' },
 'biero'	=> { 'x' => 'beer' },
 'bildkarto'	=> { 'x' => 'postcard' },
 'bildo'	=> { 'x' => 'picture' },
 'bileto'	=> { 'x' => 'ticket',
		     '#' => 'bill, banknote' },
 'biletujo'	=> { 'x' => 'wallet' },
 'birdo'	=> { 'x' => 'bird' },
 'birmo'	=> { 'x' => 'burma',
		     '#' => 'proper; place' },
 'biskvito'	=> { 'x' => 'biscuit' },
 'blanka'	=> { 'x' => 'white',
		     '#' => 'blank' },
 'blinda'	=> { 'x' => 'blind' },
 'blovi'	=> { 'x' => 'blow' },
 'blua'		=> { 'x' => 'blue' },
 'boji'		=> { 'x' => 'bark' },
 'boli'		=> { 'x' => 'boil' },
 'bona'		=> { 'x' => 'good' },
 'bondeziro'	=> { 'x' => 'good wish',
		     '#' => 'good wishes' },
 'bone'		=> { 'x' => 'well' },
 'bonega'	=> { 'x' => 'excellent',
		     '#' => '-eg-' },
 'bonvena'	=> { 'x' => 'welcome' },
 'bonvolu'	=> { 'x' => 'please' },
 'bordo'	=> { 'x' => 'bank',
		     '#' => 'shore' },
 'botelo'	=> { 'x' => 'bottle' },
 'bovaĵo'	=> { 'x' => 'beef',
		     '#' => '-aĵ-' },
 'bovido'	=> { 'x' => 'calf',
		     '#' => '-id-' },
 'bovino'	=> { 'x' => 'cow',
		     '#' => 'animate' },
 'bovo'		=> { 'x' => 'ox',
		     '#' => 'animate' },
 'brako'	=> { 'x' => 'arm' },
 'brakumi'	=> { 'x' => 'embrace' },
 'branĉo'	=> { 'x' => 'branch' },
 'brasiko'	=> { 'x' => 'cabbage' },
 'brava'	=> { 'x' => 'brave',
		     '#' => 'worthy, valiant' },
 'brave'	=> { 'x' => 'bravo',
		     '#' => 'well done',
 		     't' => 'interj' },
 'brazilo'	=> { 'x' => 'brazil',
		     '#' => 'proper; place' },
 'breto'	=> { 'x' => 'shelf' },
 'briko'	=> { 'x' => 'brick' },
 'brila'	=> { 'x' => 'brilliant' },
 'brili'	=> { 'x' => 'shine' },
 'brita'	=> { 'x' => 'british' },
 'britio'	=> { 'x' => 'britain',
		     '#' => '-i-; proper; place' },
 'brito'	=> { 'x' => 'briton' },
 'britujo'	=> { 'x' => 'britain' },
 'brodi'	=> { 'x' => 'embroider' },
 'brokolo'	=> { 'x' => 'broccoli' },
 'broso'	=> { 'x' => 'brush' },
 'brui'		=> { 'x' => 'make noise',
		     '#' => 'multiword' },
 'bruli'	=> { 'x' => 'burn' },
 'bruna'	=> { 'x' => 'brown' },
 'bruo'		=> { 'x' => 'noise' },
 'bruligi'	=> { 'x' => 'burn',
		     '#' => '-ig-; transitive' },
 'brusto'	=> { 'x' => 'chest' },
 'bulgara'	=> { 'x' => 'bulgarian' },
 'bulgario'	=> { 'x' => 'bulgaria',
		     '#' => '-i-; proper; place' },
 'bulgarujo'	=> { 'x' => 'bulgaria',
		     '#' => 'proper; place' },
 'buŝo'		=> { 'x' => 'mouth' },
 'butero'	=> { 'x' => 'butter' },
 'butiko'	=> { 'x' => 'shop' },
 'butikumi'	=> { 'x' => 'shop',
		     '#' => 'go shopping' },
 'butono'	=> { 'x' => 'button' },
 'celi'		=> { 'x' => 'aim at',
		     '#' => 'multiword' },
 'celo'		=> { 'x' => 'aim',
		     '#' => 'purpose, destination' },
 'centro'	=> { 'x' => 'cenre' },
 'certa'	=> { 'x' => 'sure',
		     '#' => 'certain' },
 'clareco'	=> { 'x' => 'clarity',
		     '#' => '-ec-' },
 'ĉambro'	=> { 'x' => 'room' },
 'ĉefo'		=> { 'x' => 'main',
		     '#' => 'chief' },
 'ĉefstrato'	=> { 'x' => 'main street',
		     '#' => 'multiword' },
 'ĉenero'	=> { 'x' => 'link',
		     '#' => '-er-' },
 'ĉeĥoslovakujo'	=> { 'x' => 'czechoslovakia',
		     '#' => 'proper; place' },
 'ĉevalido'	=> { 'x' => 'colt',
		     '#' => '-id-' },
 'ĉevalino'	=> { 'x' => 'mare',
		     '#' => '-in-' },
 'ĉielo'	=> { 'x' => 'sky',
		     '#' => 'heaven' },
 'damo'		=> { 'x' => 'queen',
		     '#' => '(playing cards)' },
 'danlando'	=> { 'x' => 'denmark',
		     '#' => 'proper; place' },
 'deklaracio'	=> { 'x' => 'declaration' },
 'dekstra'	=> { 'x' => 'right',
		     '#' => 'opp. left' },
 'demando'	=> { 'x' => 'question' },
 'demokrata'	=> { 'x' => 'democratic' },
 'dio'		=> { 'x' => 'god' },
 'diri'		=> { 'x' => 'say' },
 'disĵeti'	=> { 'x' => 'scatter',
		     '#' => 'dis-' },
 'disdoni'	=> { 'x' => 'distribute',
		     '#' => 'dis-' },
 'disaŭdigi'	=> { 'x' => 'broadcast',
		     '#' => 'dis-' },
 'disigi'	=> { 'x' => 'separate',
		     '#' => 'dis-; take apart' },
 'disiĝi'	=> { 'x' => 'disintegrate',
		     '#' => 'dis-; fall apart' },
 'diversa'	=> { 'x' => 'diverse' },
 'dolĉaĵoj'	=> { 'x' => 'sweets',
		     '#' => '-aĵ-; lollies, candy' },
 'dolori'	=> { 'x' => 'hurt' },
 'domaĉo'	=> { 'x' => 'hovel',
		     '#' => '-aĉ-; shack; shanty' },
 'domego'	=> { 'x' => 'mansion',
		     '#' => '-eg-' },
 'dometo'	=> { 'x' => 'cottage',
		     '#' => '-et-' },
 'domo'		=> { 'x' => 'house' },
 'doni'		=> { 'x' => 'give' },
 'dormeti'	=> { 'x' => 'doze',
		     '#' => '-et-; slumber' },
 'dormi'	=> { 'x' => 'sleep' },
 'drinkulo'	=> { 'x' => 'drunkard',
		     '#' => '-ul-; person' },
 'drogisto'	=> { 'x' => 'druggist',
		     '#' => '-ist-' },
 'duobla'	=> { 'x' => 'double',
		     '#' => '-obl-' },
 'duonigi'	=> { 'x' => 'halve',
		     '#' => '-on-' },
 'duono'	=> { 'x' => 'half',
		     '#' => '-on-' },
 'ebla'		=> { 'x' => 'possible',
		     '#' => '-ebl-' },
 'eble'		=> { 'x' => 'perhaps',
		     '#' => '-ebl-',
		     't' => 'adv' },
 'ebleco'	=> { 'x' => 'possibility',
		     '#' => '-ebl-' },
 'eco'		=> { 'x' => 'quality',
		     '#' => '-ec-' },
 'eduki'	=> { 'x' => 'educate',
		     '#' => 'bring up' },
 'eduko'	=> { 'x' => 'education' },
 'edzo'		=> { 'x' => 'husband' },
 'edzino'	=> { 'x' => 'wife' },
 'ega'		=> { 'x' => 'great',
		     '#' => '-eg-' },
 'ege'		=> { 'x' => 'very',
		     '#' => '-eg-',
		     't' => 'adv' },
 'ejo'		=> { 'x' => 'place',
		     '#' => '-ej-' },
 'ekbrili'	=> { 'x' => 'flash',
		     '#' => 'ek-' },
 'eki'		=> { 'x' => 'begin',
		     '#' => 'ek-; start' },
 'ekiri'	=> { 'x' => 'start',
		     '#' => 'ek-' },
 'eksigi'	=> { 'x' => 'discharge',
		     '#' => 'eks-; (from office); impeach' },
 'eksiĝi'	=> { 'x' => 'resign',
		     '#' => 'eks-' },
 'ekster'	=> { 'x' => 'outside',
		     '#' => 'adv.?' },
 'eksterlando'	=> { 'x' => 'abroad',
		     '#' => 'outside-land' },
 'ekvidi'	=> { 'x' => 'notice',
		     '#' => 'ek-' },
 'ekzemple'	=> { 'x' => 'examplar',
		     '#' => '?' },
 'ekzisti'	=> { 'x' => 'exist' },
 'ema'		=> { 'x' => 'inclined',
		     '#' => '-em-; disposed, prone, apt' },
 'eme'		=> { 'x' => 'willingly',
		     '#' => '-em-; readily' },
 'emo'		=> { 'x' => 'tendency',
		     '#' => '-em-; inclination, disposition' },
 'eraro'	=> { 'x' => 'error' },
 'ero'		=> { 'x' => 'element',
		     '#' => '-er-; particle, part' },
 'esperantisto'	=> { 'x' => 'esperantist',
		     '#' => '-ist-' },
 'esperanto'	=> { 'x' => 'esperanto' },
 'esperi'	=> { 'x' => 'hope' },
 'esprimo'	=> { 'x' => 'expression' },
 'estri'	=> { 'x' => 'govern',
		     '#' => '-estr-; direct, lead' },
 'estro'	=> { 'x' => 'chief',
		     '#' => '-estr-' },
 'eta'		=> { 'x' => 'small',
		     '#' => '-et-; minimal' },
 'eŭropa'	=> { 'x' => 'european' },
 'eŭropo'	=> { 'x' => 'europe',
		     '#' => 'place' },
 'eviti'	=> { 'x' => 'shun' },
 'fajrero'	=> { 'x' => 'spark',
		     '#' => '-er-' },
 'fajro'	=> { 'x' => 'fire' },
 'fakto'	=> { 'x' => 'fact' },
 'familio'	=> { 'x' => 'family',
		     '#' => 'person' },
 'fanto'	=> { 'x' => 'jack',
		     '#' => '(playing cards)' },
 'feliĉa'	=> { 'x' => 'happy',
		     '#' => 'fortunate' },
 'fenestro'	=> { 'x' => 'window' },
 'fero'		=> { 'x' => 'iron' },
 'fia'		=> { 'x' => 'nasty',
		     '#' => 'fi-; horrid' },
 'fialudi'	=> { 'x' => 'innuendo',
		     '#' => 'fi-; evil insinuation' },
 'fikomercisto'	=> { 'x' => 'swindler',
		     '#' => 'fi-; person' },
 'filo'		=> { 'x' => 'son',
		     '#' => 'person' },
 'fine'		=> { 'x' => 'finally' },
 'fini'		=> { 'x' => 'finish' },
 'fiŝo'		=> { 'x' => 'fish' },
 'flanko'	=> { 'x' => 'side' },
 'florbrasiko'	=> { 'x' => 'cauliflower' },
 'floro'	=> { 'x' => 'flower' },
 'flugilo'	=> { 'x' => 'wing',
		     '#' => '-il-' },
 'fluaĵo'	=> { 'x' => 'liquid',
		     '#' => '-aĵ-' },
 'foliumi'	=> { 'x' => 'browse',
		     '#' => '-um-; glance (through a book)' },
 'forgesi'	=> { 'x' => 'forget' },
 'forta'	=> { 'x' => 'strong' },
 'fotografio'	=> { 'x' => 'photography' },
 'francio'	=> { 'x' => 'france',
		     '#' => '-i-; proper; place' },
 'francujo'	=> { 'x' => 'france',
		     '#' => 'proper; place' },
 'fratino'	=> { 'x' => 'sister',
		     '#' => '-in-' },
 'frato'	=> { 'x' => 'brother',
		     '#' => 'person' },
 'fremdulo'	=> { 'x' => 'stranger',
		     '#' => '-ul-; person' },
 'fumi'		=> { 'x' => 'smoke' },
 'fundamenta'	=> { 'x' => 'fundamental' },
 'fundamento'	=> { 'x' => 'foundation',
		     '#' => 'element (of a subject)' },
 'galerio'	=> { 'x' => 'gallery' },
 'gastejo'	=> { 'x' => 'guest-house',
		     '#' => 'hostel' },
 'gasto'	=> { 'x' => 'guest' },
 'germanujo'	=> { 'x' => 'germany',
		     '#' => 'proper; place' },
 'glavingo'	=> { 'x' => 'scabbard',
		     '#' => '-ing-' },
 'glavo'	=> { 'x' => 'sword',
		     '#' => '??' },
 'gramatiko'	=> { 'x' => 'grammar' },
 'granda'	=> { 'x' => 'big' },
 'grekujo'	=> { 'x' => 'greece',
		     '#' => 'proper; place' },
 'ĝardeno'	=> { 'x' => 'garden' },
 'ĝenerala'	=> { 'x' => 'general' },
 'ĝojo'	=> { 'x' => 'joy' },
 'hakilo'	=> { 'x' => 'axe',
		     '#' => '-il-' },
 'hejme'	=> { 'x' => 'home',
		     '#' => '(at)' },
 'hejmo'	=> { 'x' => 'home' },
 'hejmpaĝo'	=> { 'x' => 'homepage' },
 'helpi'	=> { 'x' => 'help' },
 'herbejo'	=> { 'x' => 'meadow',
		     '#' => '-ej-' },
 'hispanujo'	=> { 'x' => 'spain',
		     '#' => 'proper; place' },
 'historio'	=> { 'x' => 'history' },
 'homa'		=> { 'x' => 'human' },
 'homaro'	=> { 'x' => 'mankind',
		     '#' => '-ar-' },
 'homo'		=> { 'x' => 'person' },
 'honoro'	=> { 'x' => 'honour' },
 'hundeo'	=> { 'x' => 'kennel',
		     '#' => '-ej-' },
 'hundido'	=> { 'x' => 'puppy',
		     '#' => '-id-' },
 'hundo'	=> { 'x' => 'dog',
		     '#' => 'animate' },
 'hungarujo'	=> { 'x' => 'hungary',
		     '#' => 'proper; place' },
 'ideo'		=> { 'x' => 'idea' },
 'ido'		=> { 'x' => 'child',
		     '#' => '-id-; infant; descendant; scion' },
 'idoj'		=> { 'x' => 'progeny',
		     '#' => '-id-' },
 'ilo'		=> { 'x' => 'tool',
		     '#' => '-il-' },
 'inda'		=> { 'x' => 'worthy',
		     '#' => '-ind-' },
 'infanaĉo'	=> { 'x' => 'brat',
		     '#' => '-aĉ-; person' },
 'infano'	=> { 'x' => 'child',
		     '#' => 'infant' },
 'informi'	=> { 'x' => 'inform' },
 'informo'	=> { 'x' => 'information' },
 'ino'		=> { 'x' => 'female',
		     '#' => '-in-' },
 'instruisto'	=> { 'x' => 'teacher',
		     '#' => '-ist-' },
 'interesa'	=> { 'x' => 'interesting' },
 'intereso'	=> { 'x' => 'interest' },
 'internacia'	=> { 'x' => 'international' },
 'inventi'	=> { 'x' => 'invent' },
 'invento'	=> { 'x' => 'invention' },
 'irlando'	=> { 'x' => 'ireland',
		     '#' => 'proper; place' },
 'islando'	=> { 'x' => 'iceland',
		     '#' => 'proper; place' },
 'italujo'	=> { 'x' => 'italy',
		     '#' => 'proper; place' },
 'izraelido'	=> { 'x' => 'israelite',
		     '#' => '-id-' },
 'jaro'		=> { 'x' => 'year' },
 'jugoslavujo'	=> { 'x' => 'yugoslavia',
		     '#' => 'proper; place' },
 'juna'		=> { 'x' => 'young' },
 'junulo'	=> { 'x' => 'youth',
		     '#' => '-ul-; person' },
 'justo'	=> { 'x' => 'justice' },
 'kafo'		=> { 'x' => 'coffee' },
 'kanado'	=> { 'x' => 'canada',
		     '#' => 'proper; place' },
 'kandelingo'	=> { 'x' => 'candlestick',
		     '#' => '-ing-' },
 'kapo'		=> { 'x' => 'head' },
 'kapti'	=> { 'x' => 'catch' },
 'kara'		=> { 'x' => 'dear' },
 'karoo'	=> { 'x' => 'diamonds',
		     '#' => '(playing cards)' },
 'katido'	=> { 'x' => 'kitten',
		     '#' => '-id-' },
 'kato'		=> { 'x' => 'cat',
		     '#' => 'animate' },
 'kero'		=> { 'x' => 'hearts',
		     '#' => '(playing cards)' },
 'kimrujo'	=> { 'x' => 'wales',
		     '#' => 'proper; place' },
# 'klingo'	=> { 'x' => 'blade',
#		     '#' => '??' },
 'knabo'	=> { 'x' => 'boy',
		     '#' => 'person' },
 'kodpaĝo'	=> { 'x' => 'codepage' },
 'kokidaĵo'	=> { 'x' => 'chicken',
		     '#' => '-aĵ-' },
 'kokido'	=> { 'x' => 'chick',
		     '#' => '-id-' },
 'kokinaĵo'	=> { 'x' => 'chicken',
		     '#' => '-aĵ-' },
 'kokino'	=> { 'x' => 'hen',
		     '#' => '-in-' },
 'kolegio'	=> { 'x' => 'college' },
 'kolerema'	=> { 'x' => 'irascible',
		     '#' => '-em-' },
 'kolumo'	=> { 'x' => 'collar',
		     '#' => '-um-' },
 'komorto'	=> { 'x' => 'comfort' },
 'komorta'	=> { 'x' => 'comfortable' },
 'komprenema'	=> { 'x' => 'understanding',
		     '#' => '-em-' },
 'kompreni'	=> { 'x' => 'understand' },
 'komunumo'	=> { 'x' => 'community',
		     '#' => '-um-' },
 'komputilo'	=> { 'x' => 'computer' },
 'koni'		=> { 'x' => 'know',
		     '#' => 'conocer' },
 'konduki'	=> { 'x' => 'lead',
		     '#' => 'guide' },
 'kongresano'	=> { 'x' => 'delegate',
		     '#' => '-an-; congressman' },
 'konsisti'	=> { 'x' => 'consist' },
 'konsorcio'	=> { 'x' => 'consortium' },
 'konstitucio'	=> { 'x' => 'constitution' },
 'kontenta'	=> { 'x' => 'content' },
 'kora'		=> { 'x' => 'cordial' },
 'korespondi'	=> { 'x' => 'correspond' },
 'koro'		=> { 'x' => 'heart' },
 'koverto'	=> { 'x' => 'envelope' },
 'kredebla'	=> { 'x' => 'credible',
		     '#' => '-ebl-; believable' },
 'kredeble'	=> { 'x' => 'possibly',
		     '#' => '-ebl-; probably' },
 'kredema'	=> { 'x' => 'credulous',
		     '#' => '-em-' },
 'kristano'	=> { 'x' => 'christian',
		     '#' => '-an-' },
 'krucumi'	=> { 'x' => 'crucify',
		     '#' => '-um-' },
 'kudrilo'	=> { 'x' => 'needle',
		     '#' => '-il-' },
 'kuŝi'	=> { 'x' => 'lie',
		     '#' => 'tell lies or lie down?' },
 'kuirado'	=> { 'x' => 'cooking',
		     '#' => '-ad-' },
 'kuirejo'	=> { 'x' => 'kitchen',
		     '#' => '-ej-' },
 'kuiri'	=> { 'x' => 'cook' },
 'kunulo'	=> { 'x' => 'companion',
		     '#' => '-ul-' },
 'kuri'		=> { 'x' => 'run' },
 'kvaropo'	=> { 'x' => 'quartet',
		     '#' => '-op-' },
 'laborema'	=> { 'x' => 'industrious',
		     '#' => '-em-; hard-working' },
 'labori'	=> { 'x' => 'work' },
 'lageto'	=> { 'x' => 'pond',
		     '#' => '-et-' },
 'lago'		=> { 'x' => 'lake' },
 'lando'	=> { 'x' => 'land',
		     '#' => 'country' },
 'larĝ'	=> { 'x' => 'wide' },
 'legebla'	=> { 'x' => 'legible' },
 'legi'		=> { 'x' => 'read' },
 'lernejo'	=> { 'x' => 'school',
		     '#' => '-ej-' },
 'lerni'	=> { 'x' => 'learn' },
 'letero'	=> { 'x' => 'letter' },
 'leterportisto'	=> { 'x' => 'postman',
		     '#' => 'person' },
 'libera'	=> { 'x' => 'free' },
 'libero'	=> { 'x' => 'freedom',
		     '#' => 'liberty' },
 'libraro'	=> { 'x' => 'library',
		     '#' => '-ar-' },
 'libreto'	=> { 'x' => 'booklet',
		     '#' => '-et-' },
 'libro'	=> { 'x' => 'book' },
 'lingvo'	=> { 'x' => 'language' },
 'literumi'	=> { 'x' => 'spell',
		     '#' => '-um-' },
 'lito'		=> { 'x' => 'bed' },
 'loĝejo'	=> { 'x' => 'apartment',
		     '#' => '-ej-' },
 'ludema'	=> { 'x' => 'playful',
		     '#' => '-em-' },
 'ludi'		=> { 'x' => 'play' },
 'ludilo'	=> { 'x' => 'toy' },
 'magnetismo'	=> { 'x' => 'magnetism',
		     '#' => '-ism-' },
 'mala'		=> { 'x' => 'opposite' },
 'malami'	=> { 'x' => 'hate',
		     '#' => 'mal-' },
 'malaperi'	=> { 'x' => 'disappear',
		     '#' => 'mal; vanish' },
 'malavara'	=> { 'x' => 'generous' },
 'malbela'	=> { 'x' => 'ugly',
		     '#' => 'mal-' },
 'malbeni'	=> { 'x' => 'curse' },
 'malbona'	=> { 'x' => 'bad',
		     '#' => 'mal-' },
 'maldekstra'	=> { 'x' => 'left',
		     '#' => 'mal-; opp. right' },
 'malema'	=> { 'x' => 'unwilling',
		     '#' => 'mal-; -em-; reluctant' },
 'malfacila'	=> { 'x' => 'difficult',
		     '#' => 'mal-' },
 'malfermi'	=> { 'x' => 'open',
		     '#' => 'mal-' },
 'malforta'	=> { 'x' => 'weak',
		     '#' => 'mal-' },
 'malgranda'	=> { 'x' => 'small',
		     '#' => 'mal-; little' },
 'maljuna'	=> { 'x' => 'old',
		     '#' => 'mal-; opp. young' },
 'malkonsenti'	=> { 'x' => 'disagree',
		     '#' => 'mal-' },
 'mallarĝa'	=> { 'x' => 'narrow' },
 'malnova'	=> { 'x' => 'old',
		     '#' => 'mal-; opp. new' },
 'malpura'	=> { 'x' => 'dirty' },
 'malriĉa'	=> { 'x' => 'poor',
		     '#' => 'mal-' },
 'malsamseksema'	=> { 'x' => 'heterosexual',
		     '#' => 'mal-; -em-' },
 'malsanulejo'	=> { 'x' => 'hospital' },
 'malsata'	=> { 'x' => 'hungry' },
 'malvarma'	=> { 'x' => 'cold' },
 'malvarmeta'	=> { 'x' => 'cool' },
 'manĝaĵo'	=> { 'x' => 'food',
		     '#' => '-aĵ-' },
 'manĝebla'	=> { 'x' => 'edible',
		     '#' => '-ebl-' },
 'manĝi'	=> { 'x' => 'eat' },
 'maristo'	=> { 'x' => 'sailor',
		     '#' => '-ist-' },
 'marksisto'	=> { 'x' => 'marxist',
		     '#' => '-ist-' },
 'maŝinisto'	=> { 'x' => 'machinist',
		     '#' => '-ist-' },
 'meblo'	=> { 'x' => 'furniture',
		     '#' => 'item of furniture' },
 'meksikio'	=> { 'x' => 'mexico',
		     '#' => '-i-; proper; place' },
 'membro'	=> { 'x' => 'member',
		     '#' => 'poss. person' },
 'memorinda'	=> { 'x' => 'memorable',
		     '#' => '-ind-' },
 'mesaĝo'	=> { 'x' => 'message' },
 'meti'		=> { 'x' => 'put' },
 'mezo'		=> { 'x' => 'middle' },
 'miskompreni'	=> { 'x' => 'misunderstand',
		     '#' => 'mis-' },
 'miskompreno'	=> { 'x' => 'misunderstanding',
		     '#' => 'mis-' },
 'misuzi'	=> { 'x' => 'misuse',
		     '#' => 'mis-' },
 'misuzo'	=> { 'x' => 'abuse',
		     '#' => 'mis-' },
 'moderna'	=> { 'x' => 'modern' },
 'mondo'	=> { 'x' => 'world' },
 'monero'	=> { 'x' => 'coin',
		     '#' => '-er-' },
 'monteto'	=> { 'x' => 'hill' },
 'monto'	=> { 'x' => 'mountain' },
 'montri'	=> { 'x' => 'show' },
 'montrilo'	=> { 'x' => 'pointer',
		     '#' => '-il-; arrow' },
 'monujo'	=> { 'x' => 'purse',
		     '#' => '-uj-' },
 'mortema'	=> { 'x' => 'mortal',
		     '#' => '-em-' },
 'mortigi'	=> { 'x' => 'kill',
		     '#' => '-ig-; slay' },
 'mortkuŝi'	=> { 'x' => 'kill',
		     '#' => '??' },
 'movado'	=> { 'x' => 'movement',
		     '#' => '-ad-' },
 'multobligi'	=> { 'x' => 'multiply',
		     '#' => '-obl-' },
 'muro'		=> { 'x' => 'wall' },
 'muso'		=> { 'x' => 'mouse',
		     '#' => 'animate' },
 'muziko'	=> { 'x' => 'music' },
 'nacio'	=> { 'x' => 'nation' },
 'naĝado'	=> { 'x' => 'swimming',
		     '#' => '-ad-' },
 'naski'	=> { 'x' => 'bear',
		     '#' => 'give birth to' },
 'naskiĝi'	=> { 'x' => 'be born',
		     '#' => 'multiword' },
 'natura'	=> { 'x' => 'natural' },
 'nederlando'	=> { 'x' => 'holland',
		     '#' => 'proper; place' },
 'nepre'	=> { 'x' => 'without fail',
		     '#' => 'multiword' },
 'nokto'	=> { 'x' => 'night' },
 'nomo'		=> { 'x' => 'name' },
 'norda'	=> { 'x' => 'northern' },
 'norde'	=> { 'x' => 'north',
		     '#' => 'in the north' },
 'norden'	=> { 'x' => 'northward',
		     '#' => 'to the north' },
 'nordo'	=> { 'x' => 'north',
		     '#' => 'the north' },
 'norvego'	=> { 'x' => 'norwegian',
		     '#' => 'person' },
 'norvegujo'	=> { 'x' => 'norway' },
 'nova'		=> { 'x' => 'new' },
 'novzelando'	=> { 'x' => 'new zealand',
		     '#' => 'proper; place; multiword' },
 'numero'	=> { 'x' => 'number' },
 'obligi'	=> { 'x' => 'multiply',
		     '#' => '-obl-' },
 'oficiala'	=> { 'x' => 'official' },
 'ofta'		=> { 'x' => 'frequent' },
 'ofte'		=> { 'x' => 'often',
		     '#' => 'adv.' },
 'okcidenta'	=> { 'x' => 'western' },
 'okcidente'	=> { 'x' => 'west',
		     '#' => 'in the west' },
 'okcidenten'	=> { 'x' => 'westward',
		     '#' => 'to the west' },
 'okcidento'	=> { 'x' => 'west',
		     '#' => 'the west' },
 'okulo'	=> { 'x' => 'eye' },
 'okulumi'	=> { 'x' => 'ogle',
		     '#' => '-um-' },
 'onklino'	=> { 'x' => 'aunt',
		     '#' => '-in-' },
 'organizi'	=> { 'x' => 'organize' },
 'organizo'	=> { 'x' => 'organization' },
 'orienta'	=> { 'x' => 'eastern' },
 'oriente'	=> { 'x' => 'east',
		     '#' => 'in the east' },
 'orienten'	=> { 'x' => 'eastward',
		     '#' => 'to the east' },
 'oriento'	=> { 'x' => 'east',
		     '#' => 'the east' },
 'ovaĵo'	=> { 'x' => 'scrambled eggs',
		     '#' => '-aĵ-; multiword' },
 'paco'		=> { 'x' => 'peace' },
 'paĉjo'	=> { 'x' => 'dad',
		     '#' => '-ĉj-; person; capitalized; daddy' },
 'pafado'	=> { 'x' => 'shooting',
		     '#' => '-ad-' },
 'pagenda'	=> { 'x' => 'payable',
		     '#' => '-end-; to be paid, due' },
 'paĝo'	=> { 'x' => 'page' },
 'pakaĝo'	=> { 'x' => 'package',
		     '#' => '-aĵ-; thing packed' },
 'panero'	=> { 'x' => 'crumb',
		     '#' => '-er-' },
 'panjo'	=> { 'x' => 'mum',
		     '#' => '-nj-; person; captialized; mummy' },
 'papero'	=> { 'x' => 'paper',
		     '#' => 'piece of' },
 'parko'	=> { 'x' => 'park' },
 'parolado'	=> { 'x' => 'speech',
		     '#' => '-ad-' },
 'parolema'	=> { 'x' => 'talkative',
		     '#' => '-em-' },
 'paroli'	=> { 'x' => 'speak' },
 'parto'	=> { 'x' => 'part' },
 'patrino'	=> { 'x' => 'mother',
		     '#' => 'person' },
 'patro'	=> { 'x' => 'father',
		     '#' => 'person' },
  'gepatroj'	=> { 'x' => 'parents',
		     '#' => 'person; plural' },
 'pendi'	=> { 'x' => 'hang' },
 'pensi'	=> { 'x' => 'think' },
 'penso'	=> { 'x' => 'thought' },
 'pentristo'	=> { 'x' => 'painter',
		     '#' => '-ist-' },
 'persono'	=> { 'x' => 'person',
		     '#' => 'person' },
 'petegi'	=> { 'x' => 'beseech',
		     '#' => '-eg-; implore' },
 'peti'		=> { 'x' => 'ask' },
 'piko'		=> { 'x' => 'spades',
		     '#' => '(playing cards)' },
 'plaĝo'	=> { 'x' => 'beach' },
 'plandumo'	=> { 'x' => 'sole',
		     '#' => '-um-; of a shoe' },
 'planko'	=> { 'x' => 'floor' },
 'platformo'	=> { 'x' => 'platform' },
 'plazo'	=> { 'x' => 'square',
		     '#' => 'cf plaza' },
 'plena'	=> { 'x' => 'full' },
 'plenigi'	=> { 'x' => 'fill',
		     '#' => '-ig-' },
 'plenumi'	=> { 'x' => 'fulfil' },	
 'plezuro'	=> { 'x' => 'pleasure' },
 'plibonigi'	=> { 'x' => 'improve',
		     '#' => '-ig-; transitive' },
 'pliboniĝi'	=> { 'x' => 'improve',
		     '#' => '-iĝ-; intransitive' },
 'plori'	=> { 'x' => 'cry' },
 'plumo'	=> { 'x' => 'pen',
		     '#' => 'feather' },
 'pluvero'	=> { 'x' => 'raindrop',
		     '#' => '-er-' },
 'pluvo'	=> { 'x' => 'rain' },
 'policisto'	=> { 'x' => 'policeman',
		     '#' => '-ist-' },
 'pollando'	=> { 'x' => 'poland',
		     '#' => 'proper; place' },
 'poluso'	=> { 'x' => 'pole',
		     '#' => 'north and south' },
 'pomo'		=> { 'x' => 'apple' },
 'ponto'	=> { 'x' => 'bridge' },
 'pordo'	=> { 'x' => 'door' },
 'portebla'	=> { 'x' => 'portable',
		     '#' => '-ebl-' },
 'porti'	=> { 'x' => 'carry',
		     '#' => 'wear' },
 'postuli'	=> { 'x' => 'require',
		     '#' => 'demand' },
 'poŝisto'	=> { 'x' => 'postal worker',
		     '#' => 'person; multiword' },
 'poŝo'	=> { 'x' => 'pocket' },
 'poŝtkarto'	=> { 'x' => 'postcard' },
 'poŝtmarko'	=> { 'x' => 'stamp' },
 'poŝto'	=> { 'x' => 'post',
		     '#' => 'mail' },
 'praa'		=> { 'x' => 'ancient',
		     '#' => 'pra-' },
 'praavo'	=> { 'x' => 'great-grandfather',
		     '#' => 'pra-; person' },
 'pranepo'	=> { 'x' => 'great-grandson',
		     '#' => 'pra-; person' },
 'prahistorio'	=> { 'x' => 'prehistory',
		     '#' => 'pra-' },
 'prapatro'	=> { 'x' => 'ancestor',
		     '#' => 'pra-; person?' },
 'pratempa'	=> { 'x' => 'ancient',
		     '#' => 'pra-' },
 'precipe'	=> { 'x' => 'mainly',
		     '#' => 'principally' },
 'preĝejo'	=> { 'x' => 'church',
		     '#' => '-ej-; temple' },
 'preĝi'	=> { 'x' => 'pray' },
 'preta'	=> { 'x' => 'ready' },
 'problemo'	=> { 'x' => 'problem' },
 'programo'	=> { 'x' => 'program' },
 'projekto'	=> { 'x' => 'project' },
 'promeni'	=> { 'x' => 'promenade',
		     '#' => 'go for a walk/drive/etc' },
 'prosperi'	=> { 'x' => 'prosper' },
 'protektismo'	=> { 'x' => 'protectionism',
		     '#' => '-ism-' },
 'publika'	=> { 'x' => 'public' },
 'puni'		=> { 'x' => 'punish' },
 'pupo'		=> { 'x' => 'doll' },
 'pura'		=> { 'x' => 'clean',
		     '#' => 'pure' },
 'purigi'	=> { 'x' => 'clean',
		     '#' => '-ig-; purify' },
 'rajto'	=> { 'x' => 'right',
		     '#' => 'as in "human rights"' },
 'rapida'	=> { 'x' => 'quick' },
 'rapideco'	=> { 'x' => 'speed',
		     '#' => '-ec-' },
 'raso'		=> { 'x' => 'race',
		     '#' => 'as in nationality' },
 'razilo'	=> { 'x' => 'razor',
		     '#' => '-il-' },
 'rebrili'	=> { 'x' => 'reflect',
		     '#' => 're-' },
 'reciproke'	=> { 'x' => 'reciprocally',
		     '#' => 'in exchange' },
 'redoni'	=> { 'x' => 'return',
		     '#' => 'give back' },
 'regnestro'	=> { 'x' => 'ruler',
		     '#' => '-estr-' },
 'reĝido'	=> { 'x' => 'prince',
		     '#' => '-id-' },
 'reĝino'	=> { 'x' => 'queen',
		     '#' => '-in-' },
 'reĝo'		=> { 'x' => 'king' },
 'reiri'	=> { 'x' => 'return',
		     '#' => 'go back' },
 'rekta'	=> { 'x' => 'direct',
		     '#' => 'straight' },
 'religio'	=> { 'x' => 'religion' },
 'renkonti'	=> { 'x' => 'meet' },
 'reputacio'	=> { 'x' => 'reputation' },
 'respekto'	=> { 'x' => 'respect' },
 'respondi'	=> { 'x' => 'answer',
		     '#' => 'reply' },
 'resti'	=> { 'x' => 'stay',
		     '#' => 'rest' },
 'retroiri'	=> { 'x' => 'retire',
		     '#' => 'retro-; withdraw, retreat' },
 'reveni'	=> { 'x' => 'return',
		     '#' => 'come back' },
 'revuo'	=> { 'x' => 'magazine' },
 'rezolucio'	=> { 'x' => 'resolution' },
 'ricevi'	=> { 'x' => 'receive' },
 'riĉa'	=> { 'x' => 'rich' },
 'ridegi'	=> { 'x' => 'guffaw',
		     '#' => '-eg-' },
 'rideti'	=> { 'x' => 'smile',
		     '#' => '-et-' },
 'ridi'		=> { 'x' => 'laugh' },
 'rigardi'	=> { 'x' => 'watch',
		     '#' => 'look at' },
 'ripozi'	=> { 'x' => 'rest' },
 'robo'		=> { 'x' => 'dress' },
 'ruinigi'	=> { 'x' => 'ruin',
		     '#' => '-ig-' },
 'ruĝa'	=> { 'x' => 'red' },
 'ruĝiĝi'	=> { 'x' => 'blush',
		     '#' => '-iĝ-' },
 'ruliĝi'	=> { 'x' => 'roll',
		     '#' => '-iĝ-; intransitive' },
 'rumanujo'	=> { 'x' => 'romania',
		     '#' => 'proper; place' },
 'sablo'	=> { 'x' => 'sand' },
 'sago'		=> { 'x' => 'arrow' },
 'saĝulo'	=> { 'x' => 'sage',
		     '#' => '-ul-; wise man' },
 'salono'	=> { 'x' => 'longue' },
 'salti'	=> { 'x' => 'jump' },
 'saluti'	=> { 'x' => 'greet' },
 'saluto'	=> { 'x' => 'greeting' },
 'sama'		=> { 'x' => 'same' },
 'samseksema'	=> { 'x' => 'homosexual',
		     '#' => '-em-' },
 'samseksemulo'	=> { 'x' => 'homosexual',
		     '#' => '-em-; -ul-; person' },
 'sana'		=> { 'x' => 'healthy' },
 'sandviĉo'	=> { 'x' => 'sandwich' },
 'sata'		=> { 'x' => 'satisfied',
		     '#' => 'of hunger' },
 'sati'		=> { 'x' => 'be satisfied',
		     '#' => 'multiword' },
 'scii'		=> { 'x' => 'know',
		     '#' => 'saber' },
 'sciigi'	=> { 'x' => 'inform',
		     '#' => '-ig-; let know' },
 'scribaĉi'	=> { 'x' => 'scrawl',
		     '#' => '-aĉ-' },
 'segaĵo'	=> { 'x' => 'sawdust',
		     '#' => '-aĵ-' },
 'seĵo'	=> { 'x' => 'chair' },
 'seka'		=> { 'x' => 'dry' },
 'sekso'	=> { 'x' => 'sex' },
 'semajno'	=> { 'x' => 'week' },
 'sendaĵo'	=> { 'x' => 'shipment',
		     '#' => '-aĵ-; thing sent' },
 'sendi'	=> { 'x' => 'send' },
 'serĉi'	=> { 'x' => 'seek',
		     '#' => 'look for, seek' },
 'sidi'		=> { 'x' => 'sit' },
 'silenta'	=> { 'x' => 'quiet' },
 'sincera'	=> { 'x' => 'sincere' },
 'sinjoro'	=> { 'x' => 'gentleman',
		     '#' => 'mister; person' },
 'sistemo'	=> { 'x' => 'system' },
 'skatolo'	=> { 'x' => 'box' },
 'skribi'	=> { 'x' => 'write' },
 'skotlando'	=> { 'x' => 'scotland',
		     '#' => 'proper; place' },
 'soifa'	=> { 'x' => 'thirsty' },
 'solvi'	=> { 'x' => 'solve' },
 'soni'		=> { 'x' => 'sound' },
 'stacio'	=> { 'x' => 'station' },
 'staciodomo'	=> { 'x' => 'station',
		     '#' => 'train station' },
 'stari'	=> { 'x' => 'stand' },
 'starigi'	=> { 'x' => 'stand',
		     '#' => '-ig-; transitive' },
 'stato'	=> { 'x' => 'state',
		     '#' => 'condition' },
 'statuo'	=> { 'x' => 'statue' },
 'stari'	=> { 'x' => 'stand' },
 'stepo'	=> { 'x' => 'steppe' },
 'strato'	=> { 'x' => 'street' },
 'studi'	=> { 'x' => 'study' },
 'suda'		=> { 'x' => 'southern' },
 'sude'		=> { 'x' => 'south',
		     '#' => 'in the south' },
 'sude'		=> { 'x' => 'south',
		     '#' => 'to the south' },
 'sudo'		=> { 'x' => 'south',
		     '#' => 'the south' },
 'sufiĉa'	=> { 'x' => 'sufficient' },
 'sukcesi'	=> { 'x' => 'succeed' },
 'sukero'	=> { 'x' => 'sugar' },
 'suno'		=> { 'x' => 'sun' },
 'supozi'	=> { 'x' => 'suppose' },
 'supra'	=> { 'x' => 'top' },
 'supre'	=> { 'x' => 'top',
		     '#' => 'at the top' },
 'supren'	=> { 'x' => 'upward',
		     '#' => 'to the top' },
 'suprizo'	=> { 'x' => 'surprise' },
 'supro'	=> { 'x' => 'top' },
 'svedujo'	=> { 'x' => 'seden',
		     '#' => 'proper; place' },
 'svislando'	=> { 'x' => 'switzerland' },
 'ŝafaĵo'	=> { 'x' => 'mutton',
		     '#' => '-aĵ-' },
 'ŝafo'	=> { 'x' => 'sheep' },
 'ŝati'	=> { 'x' => 'like' },
 'ŝanĝi'	=> { 'x' => 'change',
		     '#' => 'transitive' },
 'ŝanĝiĝi'	=> { 'x' => 'change',
		     '#' => 'intransitive' },
 'ŝipestro'	=> { 'x' => 'captain',
		     '#' => '-estr-; of a ship' },
 'ŝlosilo'	=> { 'x' => 'key',
		     '#' => '-il-' },
 'ŝoseo'	=> { 'x' => 'freeway',
		     '#' => 'motorway' },
 'ŝparema'	=> { 'x' => 'thrifty',
		     '#' => '-em-' },
 'ŝranko'	=> { 'x' => 'cupboard' },
 'ŝuisto'	=> { 'x' => 'shoemaker',
		     '#' => '-ist-; cobbler' },
 'ŝuo'		=> { 'x' => 'shoe' },
 'tablo'	=> { 'x' => 'table' },
 'tago'		=> { 'x' => 'day' },
 'tamtamo'	=> { 'x' => 'tomtom' },
 'tasko'	=> { 'x' => 'task' },
 'taso'		=> { 'x' => 'cup' },
 'teatro'	=> { 'x' => 'theatre' },
 'tegmento'	=> { 'x' => 'roof' },
 'teksto'	=> { 'x' => 'text' },
 'tempo'	=> { 'x' => 'time' },
 'tendumi'	=> { 'x' => 'camp',
		     '#' => '-um-' },
 'teniso'	=> { 'x' => 'tennis' },
 'teo'		=> { 'x' => 'tea' },
 'tero'		=> { 'x' => 'earth' },
 'timigi'	=> { 'x' => 'frighten',
		     '#' => '-ig-' },
 'tipo'		=> { 'x' => 'type' },
 'tirkesto'	=> { 'x' => 'drawer' },
 'traduki'	=> { 'x' => 'translate' },
 'traduko'	=> { 'x' => 'translation' },
 'trafi'	=> { 'x' => 'score',
		     '#' => 'hit' },
 'trajno'	=> { 'x' => 'train' },
 'tranĉi'	=> { 'x' => 'cut' },
 'tranĉilo'	=> { 'x' => 'knife',
		     '#' => '-il-' },
 'trefo'	=> { 'x' => 'clubs',
		     '#' => '(playing cards)' },
 'trinki'	=> { 'x' => 'drink' },
 'trovi'	=> { 'x' => 'find' },
 'turismo'	=> { 'x' => 'tourism' },
 'turisto'	=> { 'x' => 'tourist',
		     '#' => 'person' },
 'tuta' 	=> { 'x' => 'whole' },
 'ujo'		=> { 'x' => 'container',
		     '#' => '-uj-' },
 'ulo'		=> { 'x' => 'person',
		     '#' => '-ul-; individual' },
 'unikodo'	=> { 'x' => 'unicode',
		     '#' => 'proper' },
 'unio'		=> { 'x' => 'union' },
 'universala'	=> { 'x' => 'universal' },
 'unuanima'	=> { 'x' => 'unanimous' },
 'unuobla'	=> { 'x' => 'single',
		     '#' => '-obl-' },
 'urbanoj'	=> { 'x' => 'townspeople',
		     '#' => '-an-' },
 'urbego'	=> { 'x' => 'city' },
 'urbestro'	=> { 'x' => 'mayor',
		     '#' => '-estr-' },
 'urbo'		=> { 'x' => 'town' },
 'urbodomo'	=> { 'x' => 'town hall',
		     '#' => 'multiword' },
 'valizo'	=> { 'x' => 'suitcase' },
 'varbi'	=> { 'x' => 'recruit' },
 'varma'	=> { 'x' => 'warm' },
 'varmega'	=> { 'x' => 'hot',
		     '#' => '-eg-' },
 'vasta'	=> { 'x' => 'vast',
		     '#' => 'huge' },
 'vendejo'	=> { 'x' => 'shop',
		     '#' => '-ej-; store' },
 'vendi'	=> { 'x' => 'sell' },
 'veni'		=> { 'x' => 'come' },
 'ventumi'	=> { 'x' => 'fan',
		     '#' => '-um-' },
 'ventumilo'	=> { 'x' => 'fan',
		     '#' => '-um-' },
 'vera'		=> { 'x' => 'true',
		     '#' => 'real' },
 'verda'	=> { 'x' => 'green' },
 'verdaĵo'	=> { 'x' => 'greenery',
		     '#' => '-aĵ-; something green' },
 'vere'		=> { 'x' => 'truly',
		     '#' => 'really' },
 'versio'	=> { 'x' => 'version' },
 'vespermanĝo'	=> { 'x' => 'dinner',
		     '#' => 'evening meal' },
 'vespero'	=> { 'x' => 'evening' },
 'vetero'	=> { 'x' => 'weather' },
 'veturi'	=> { 'x' => 'travel',
		     '#' => 'go, (in vehicle); cf de fahren' },
 'videbla'	=> { 'x' => 'visible',
		     '#' => '-ebl-' },
 'vidi'		=> { 'x' => 'see' },
 'vilaĝano'	=> { 'x' => 'villager',
		     '#' => '-an-' },
 'vilaĝo'	=> { 'x' => 'village' },
 'vinberujo'	=> { 'x' => 'vine',
		     '#' => '-uj-' },
 'vino'		=> { 'x' => 'wine' },
 'virbovo'	=> { 'x' => 'bull',
		     '#' => 'animate' },
 'virego'	=> { 'x' => 'giant' },
 'vireto'	=> { 'x' => 'dwarf' },
 'virinaĉo'	=> { 'x' => 'hag',
		     '#' => '-aĉ-; person' },
 'virino'	=> { 'x' => 'woman' },
 'viro'		=> { 'x' => 'man',
		     '#' => 'person' },
 'vitro'	=> { 'x' => 'glass' },
 'vivi'		=> { 'x' => 'live' },
 'viziti'	=> { 'x' => 'visit' },
 'vojeto'	=> { 'x' => 'path' },
 'vojo'		=> { 'x' => 'way',
		     '#' => 'road' },
 'vortlisto'	=> { 'x' => 'vocabulary' },
 'vortaro'	=> { 'x' => 'dictionary',
		     '#' => '-ar-' },
 'vorto'	=> { 'x' => 'word' },

 # Below here auto-added
 'aĉeti'	=> { 'x' => 'buy' },
 'aero'		=> { 'x' => 'air' },
 'afabla'	=> { 'x' => 'kind',
		     '#' => ', friendly' },
 'afero'	=> { 'x' => 'matter',
		     '#' => ', affair, thing' },
 'afriko'	=> { 'x' => 'africa',
		     't' => 'n',
		     '#' => 'capitalize' },
 'agrabla'	=> { 'x' => 'pleasant',
		     '#' => ', nice' },
 'aĝo'		=> { 'x' => 'age' },
 'akcepti'	=> { 'x' => 'accept' },
 'akra'		=> { 'x' => 'sharp' },
 'akvo'		=> { 'x' => 'water' },
 'al'		=> { 'x' => 'to',
		     't' => 'p',
		     '#' => ', towards' },
 'alia'		=> { 'x' => 'other' },
 'almenaŭ'	=> { 'x' => 'at least',
		     't' => 'adv' },
 'alta'		=> { 'x' => 'high',
		     '#' => ', tall' },
 'ami'		=> { 'x' => 'love',
		     '#' => ', to like' },
 'amaso'	=> { 'x' => 'mass',
		     '#' => ', crowd' },
 'amiko'	=> { 'x' => 'friend' },
 'anglo'	=> { 'x' => 'englishman',
		     't' => 'n',
		     '#' => 'capitalize' },
 'angulo'	=> { 'x' => 'corner',
		     '#' => ', angle' },
 'ankaŭ'	=> { 'x' => 'also',
		     't' => 'adv',
		     '#' => ', too' },
 'ankoraŭ'	=> { 'x' => 'still',
		     't' => 'adv' },
 'antaŭ'	=> { 'x' => 'before',
		     't' => 'p' },
 'aparta'	=> { 'x' => 'separate' },
 'apenaŭ'	=> { 'x' => 'barely',
		     't' => 'adv',
		     '#' => ', scarcely' },
 'aperi'	=> { 'x' => 'appear' },
 'apetito'	=> { 'x' => 'appetite' },
 'aprilo'	=> { 'x' => 'april' },
 'apud'		=> { 'x' => 'beside',
		     't' => 'p',
		     '#' => ', near' },
 'arbo'		=> { 'x' => 'tree' },
 'arto'		=> { 'x' => 'art' },
 'atendi'	=> { 'x' => 'wait' },
 'atenta'	=> { 'x' => 'attentive',
		     '#' => ', careful' },
 'atesti'	=> { 'x' => 'attest',
		     '#' => ', to certify' },
 'aŭdi'		=> { 'x' => 'hear' },
 'aŭgusto'	=> { 'x' => 'august' },
 'aŭskulti'	=> { 'x' => 'listen' },
 'aŭto'		=> { 'x' => 'automobile',
		     '#' => ', car' },
 'aŭtobuso'	=> { 'x' => 'bus',
		     '#' => ', coach' },
 'aŭtuno'	=> { 'x' => 'autumn',
		     '#' => ', fall' },
 'avo'		=> { 'x' => 'grandfather' },
 'baldaŭ'	=> { 'x' => 'soon',
		     't' => 'adv' },
 'bati'		=> { 'x' => 'hit',
		     '#' => ', to beat' },
 'batali'	=> { 'x' => 'fight' },
 'bela'		=> { 'x' => 'lovely',
		     '#' => ', beautiful' },
 'besto'	=> { 'x' => 'animal' },
 'bezoni'	=> { 'x' => 'need',
		     '#' => ', to require' },
 'biciklo'	=> { 'x' => 'bicycle' },
 'biero'	=> { 'x' => 'beer' },
 'bigamio'	=> { 'x' => 'bigamy' },
 'bilardo'	=> { 'x' => 'billiards',
		     '#' => ', pool' },
 'bildo'	=> { 'x' => 'picture',
		     '#' => ', image' },
 'birdo'	=> { 'x' => 'bird' },
 'blanka'	=> { 'x' => 'white' },
 'blinda'	=> { 'x' => 'blind' },
 'blonda'	=> { 'x' => 'blond' },
 'blua'		=> { 'x' => 'blue' },
 'bona'		=> { 'x' => 'good' },
 'bordo'	=> { 'x' => 'border',
		     '#' => ', shore, bank' },
 'bovo'		=> { 'x' => 'bull',
		     '#' => ', ox' },
 'brako'	=> { 'x' => 'arm' },
 'brili'	=> { 'x' => 'shine',
		     '#' => ', to be bright' },
 'brui'		=> { 'x' => 'make a noise' },
 'bruli'	=> { 'x' => 'burn',
		     '#' => ', to be on fire (intrans.)' },
 'bruna'	=> { 'x' => 'brown' },
 'bubo'		=> { 'x' => 'boy',
		     '#' => ', lad (often pejorative)' },
 'bufedo'	=> { 'x' => 'buffet',
		     '#' => ', snack-bar' },
 'buŝo'		=> { 'x' => 'mouth' },
 'butiko'	=> { 'x' => 'store',
		     '#' => ', shop' },
 'celi'		=> { 'x' => 'aim at' },
 'certa'	=> { 'x' => 'sure',
		     '#' => ', certain' },
 'cigaredo'	=> { 'x' => 'cigarette' },
 'ĉambro'	=> { 'x' => 'room' },
 'ĉapelo'	=> { 'x' => 'hat' },
 'ĉasi'		=> { 'x' => 'hunt' },
 'ĉe'		=> { 'x' => 'at',
		     't' => 'p',
		     '#' => ', by' },
 'ĉevalo'	=> { 'x' => 'horse' },
 'ĉielo'	=> { 'x' => 'heaven',
		     '#' => ', sky' },
 'ĉirkaŭ'	=> { 'x' => 'around',
		     't' => 'adv',
		     '#' => ', approximately' },
 'ĉokolado'	=> { 'x' => 'chocolate' },
 'da'		=> { 'x' => 'of ',
		     't' => 'p',
		     '#' => '(follows quantity or measure)' },
 'dalaso'	=> { 'x' => 'dallas',
		     't' => 'n',
		     '#' => 'capitalize' },
 'danci'	=> { 'x' => 'dance' },
 'danki'	=> { 'x' => 'thank' },
 'daŭri'	=> { 'x' => 'last',
		     '#' => ', to continue, to go on' },
 'de'		=> { 'x' => 'of',
		     't' => 'p',
		     '#' => ', from' },
 'decembro'	=> { 'x' => 'december' },
 'dekstra'	=> { 'x' => 'right ',
		     '#' => '(side)' },
 'demandi'	=> { 'x' => 'ask ',
		     '#' => '(a question)' },
 'densa'	=> { 'x' => 'dense',
		     '#' => ', thick' },
 'dento'	=> { 'x' => 'tooth' },
 'devi'		=> { 'x' => 'have to',
		     '#' => ', to must' },
 'deziri'	=> { 'x' => 'wish',
		     '#' => ', to desire' },
 'dio'		=> { 'x' => 'god' },
 'dika'		=> { 'x' => 'thick',
		     '#' => ', fat' },
 'dimanĉo'	=> { 'x' => 'sunday' },
 'diri'		=> { 'x' => 'say' },
 'direkto'	=> { 'x' => 'direction' },
 'disko'	=> { 'x' => 'disk',
		     '#' => ', record' },
 'diversa'	=> { 'x' => 'varied' },
 'dolĉa'	=> { 'x' => 'sweet' },
 'doloro'	=> { 'x' => 'pain' },
 'domo'		=> { 'x' => 'house',
		     '#' => ', building' },
 'doni'		=> { 'x' => 'give' },
 'dormi'	=> { 'x' => 'sleep' },
 'dubi'		=> { 'x' => 'doubt ',
		     '#' => '(trans.)' },
 'dum'		=> { 'x' => 'while ',
		     't' => 'p',
		     '#' => '(conjunction), during' },
 'eĉ'		=> { 'x' => 'even',
		     't' => 'adv' },
 'edzo'		=> { 'x' => 'husband' },
 'eĥo'		=> { 'x' => 'echo' },
 'ekster'	=> { 'x' => 'outside',
		     't' => 'p',
		     '#' => ', out of' },
 'ekzemplo'	=> { 'x' => 'example' },
 'ekzerci'	=> { 'x' => 'exercise',
		     '#' => ', to practice' },
 'el'		=> { 'x' => 'out of',
		     't' => 'p',
		     '#' => ', from' },
 'elekti'	=> { 'x' => 'choose',
		     '#' => ', to elect' },
 'en'		=> { 'x' => 'in',
		     't' => 'p',
		     '#' => ', into (with accusative)' },
 'erari'	=> { 'x' => 'err',
		     '#' => ', to make a mistake' },
 'eskimo'	=> { 'x' => 'eskimo',
		     '#' => ', inuit' },
 'esperi'	=> { 'x' => 'hope' },
 'esperanto'	=> { 'x' => 'esperanto' },
 'esti'		=> { 'x' => 'be' },
 'eŭklido'	=> { 'x' => 'euclid',
		     't' => 'n',
		     '#' => 'capitalize' },
 'eŭropo'	=> { 'x' => 'europe',
		     't' => 'n',
		     '#' => 'capitalize' },
 'facila'	=> { 'x' => 'easy' },
 'fajro'	=> { 'x' => 'fire' },
 'fali'		=> { 'x' => 'fall' },
 'familio'	=> { 'x' => 'family' },
 'fari'		=> { 'x' => 'do',
		     '#' => ', to make' },
 'farti'	=> { 'x' => 'fare',
		     '#' => ', to feel ("kiel vi fartas?": "how are you?")' },
 'februaro'	=> { 'x' => 'february' },
 'feliĉa'	=> { 'x' => 'happy' },
 'fenestro'	=> { 'x' => 'window' },
 'fero'		=> { 'x' => 'iron' },
 'fermi'	=> { 'x' => 'close' },
 'festi'	=> { 'x' => 'celebrate' },
 'filo'		=> { 'x' => 'son' },
 'fini'		=> { 'x' => 'finish',
		     '#' => ', to end (something) (trans.)' },
 'fingro'	=> { 'x' => 'finger' },
 'fiŝo'		=> { 'x' => 'fish' },
 'flanko'	=> { 'x' => 'side' },
 'flava'	=> { 'x' => 'yellow' },
 'floro'	=> { 'x' => 'flower' },
 'flugi'	=> { 'x' => 'fly' },
 'fojo'		=> { 'x' => 'time',
		     '#' => ', occasion' },
 'for'		=> { 'x' => 'far',
		     't' => 'adv',
		     '#' => ', away' },
 'forgesi'	=> { 'x' => 'forget' },
 'formo'	=> { 'x' => 'form' },
 'forta'	=> { 'x' => 'strong' },
 'frapi'	=> { 'x' => 'hit',
		     '#' => ', to strike' },
 'frato'	=> { 'x' => 'brother' },
 'fraŭlo'	=> { 'x' => 'bachelor ',
		     '#' => '(fraŭlino: unmarried woman, "miss")' },
 'fremda'	=> { 'x' => 'foreign',
		     '#' => ', alien' },
 'frua'		=> { 'x' => 'early' },
 'frukto'	=> { 'x' => 'fruit' },
 'fumo'		=> { 'x' => 'smoke' },
 'gaja'		=> { 'x' => 'happy',
		     '#' => ', cheerful' },
 'gajni'	=> { 'x' => 'win',
		     '#' => ', to acquire' },
 'gazeto'	=> { 'x' => 'magazine' },
 'geografio'	=> { 'x' => 'geography' },
 'glacio'	=> { 'x' => 'ice' },
 'glaso'	=> { 'x' => '',
		     '#' => '(drinking) glass' },
 'globo'	=> { 'x' => 'globe',
		     '#' => ', sphere' },
 'golo'		=> { 'x' => 'goal ',
		     '#' => '(scored)' },
 'granda'	=> { 'x' => 'large',
		     '#' => ', great' },
 'grava'	=> { 'x' => 'important' },
 'griza'	=> { 'x' => 'gray' },
 'gusto'	=> { 'x' => 'taste' },
 'ĝangalo'	=> { 'x' => 'jungle' },
 'ĝardeno'	=> { 'x' => 'garden' },
 'ĝoji'		=> { 'x' => 'be glad',
		     '#' => ', to rejoice' },
 'ĝusta'	=> { 'x' => 'correct',
		     '#' => ', exact' },
 'halti'	=> { 'x' => 'stop ',
		     '#' => '(intrans.)' },
 'haro'		=> { 'x' => '',
		     '#' => '(one) hair' },
 'havi'		=> { 'x' => 'have' },
 'hejmo'	=> { 'x' => 'home' },
 'hela'		=> { 'x' => 'bright',
		     '#' => ', clear' },
 'helpi'	=> { 'x' => 'help' },
 'herbo'	=> { 'x' => 'grass' },
 'historio'	=> { 'x' => 'history' },
 'homo'		=> { 'x' => 'person' },
 'horo'		=> { 'x' => 'hour',
		     '#' => ', time of day' },
 'hundo'	=> { 'x' => 'dog' },
 'ĥoro'		=> { 'x' => 'choir',
		     '#' => ', chorus' },
 'ideo'		=> { 'x' => 'idea' },
 'imagi'	=> { 'x' => 'imagine' },
 'indiano'	=> { 'x' => '',
		     '#' => '(american) indian' },
 'infano'	=> { 'x' => 'child' },
 'insekto'	=> { 'x' => 'insect' },
 'instrui'	=> { 'x' => 'teach' },
 'inter'	=> { 'x' => 'between',
		     't' => 'p',
		     '#' => ', among' },
 'intereso'	=> { 'x' => 'interest' },
 'interesi'	=> { 'x' => 'interest',
		     '#' => ', to be interesting to (trans.)' },
 'interna'	=> { 'x' => 'internal',
		     '#' => ', inside' },
 'iri'		=> { 'x' => 'go' },
 'jaĥto'	=> { 'x' => 'yacht' },
 'jam'		=> { 'x' => 'already',
		     't' => 'adv' },
 'januaro'	=> { 'x' => 'january' },
 'jaro'		=> { 'x' => 'year' },
 'johano'	=> { 'x' => 'john',
		     't' => 'n',
		     '#' => 'capitalize' },
 'julio'	=> { 'x' => 'july' },
 'juna'		=> { 'x' => 'young' },
 'junio'	=> { 'x' => 'june' },
 'justa'	=> { 'x' => 'just',
		     '#' => ', fair' },
 'ĵaluza'	=> { 'x' => 'jealous' },
 'ĵaŭdo'	=> { 'x' => 'thursday' },
 'ĵeti'		=> { 'x' => 'throw' },
 'ĵurnalo'	=> { 'x' => 'newspaper' },
 'ĵus'		=> { 'x' => 'just',
		     't' => 'adv',
		     '#' => ', just now' },
 'kafo'		=> { 'x' => 'coffee' },
 'kalgario'	=> { 'x' => 'calgary',
		     't' => 'n',
		     '#' => 'capitalize' },
 'kalkuli'	=> { 'x' => 'calculate',
		     '#' => ', to count' },
 'kampo'	=> { 'x' => 'field',
		     '#' => ', area' },
 'kanjono'	=> { 'x' => 'canyon' },
 'kanti'	=> { 'x' => 'sing' },
 'kapo'		=> { 'x' => 'head' },
 'kapti'	=> { 'x' => 'catch' },
 'kara'		=> { 'x' => 'dear' },
 'kaŝi'		=> { 'x' => 'hide ',
		     '#' => '(trans.)' },
 'kato'		=> { 'x' => 'cat' },
 'kaŭzo'	=> { 'x' => 'cause' },
 'kelka'	=> { 'x' => 'some' },
 'klara'	=> { 'x' => 'clear' },
 'klini'	=> { 'x' => 'incline',
		     '#' => ', to bend (trans.)' },
 'klubo'	=> { 'x' => 'club',
		     '#' => ', group' },
 'knabo'	=> { 'x' => 'boy' },
 'kolo'		=> { 'x' => 'neck' },
 'kolekti'	=> { 'x' => 'collect ',
		     '#' => '(trans.)' },
 'koleri'	=> { 'x' => 'be angry' },
 'koloro'	=> { 'x' => 'color' },
 'komenci'	=> { 'x' => 'begin ',
		     '#' => '(something) (trans.)' },
 'komerci'	=> { 'x' => 'trade',
		     '#' => ', to do business' },
 'kompreni'	=> { 'x' => 'understand' },
 'komuna'	=> { 'x' => 'common',
		     '#' => ', general' },
 'koni'		=> { 'x' => 'know' },
 'konduki'	=> { 'x' => 'lead' },
 'kongreso'	=> { 'x' => 'congress',
		     '#' => ', convention' },
 'konsenti'	=> { 'x' => 'agree' },
 'konsili'	=> { 'x' => 'advise' },
 'konstrui'	=> { 'x' => 'build' },
 'kontenta'	=> { 'x' => 'satisfied',
		     '#' => ', content' },
 'kontraŭ'	=> { 'x' => 'against',
		     't' => 'p',
		     '#' => ', opposite' },
 'koro'		=> { 'x' => 'heart' },
 'korespondi'	=> { 'x' => 'correspond',
		     '#' => ', to exchange letters' },
 'korpo'	=> { 'x' => 'body' },
 'korto'	=> { 'x' => 'yard',
		     '#' => ', courtyard' },
 'kosti'	=> { 'x' => 'cost' },
 'koverto'	=> { 'x' => 'envelope' },
 'kovri'	=> { 'x' => 'cover' },
 'kredi'	=> { 'x' => 'believe' },
 'kreski'	=> { 'x' => 'grow ',
		     '#' => '(intrans.)' },
 'krii'		=> { 'x' => 'yell',
		     '#' => ', to cry out' },
 'krom'		=> { 'x' => 'besides',
		     't' => 'p',
		     '#' => ', except' },
 'kuiri'	=> { 'x' => 'cook' },
 'kuko'		=> { 'x' => 'cake' },
 'kun'		=> { 'x' => 'with',
		     't' => 'p' },
 'kuniklo'	=> { 'x' => 'rabbit' },
 'kuri'		=> { 'x' => 'run' },
 'kuraĝa'	=> { 'x' => 'brave',
		     '#' => ', courageous' },
 'kurso'	=> { 'x' => 'course',
		     '#' => ', series of lessons' },
 'kuŝi'		=> { 'x' => 'lie down' },
 'kutimo'	=> { 'x' => 'custom',
		     '#' => ', habit' },
 'labori'	=> { 'x' => 'work' },
 'laca'		=> { 'x' => 'tired' },
 'lakto'	=> { 'x' => 'milk' },
 'lando'	=> { 'x' => 'country',
		     '#' => ', land' },
 'larĝa'	=> { 'x' => 'wide' },
 'lasi'		=> { 'x' => 'leave',
		     '#' => ', to allow' },
 'lasta'	=> { 'x' => 'last' },
 'laŭ'		=> { 'x' => 'according to',
		     't' => 'p',
		     '#' => ', along' },
 'lavi'		=> { 'x' => 'wash ',
		     '#' => '(trans.)' },
 'leciono'	=> { 'x' => 'lesson' },
 'legi'		=> { 'x' => 'read' },
 'lerni'	=> { 'x' => 'learn' },
 'letero'	=> { 'x' => 'letter ',
		     '#' => '(correspondence)' },
 'levi'		=> { 'x' => 'lift' },
 'libera'	=> { 'x' => 'free',
		     '#' => ', independent' },
 'libro'	=> { 'x' => 'book' },
 'ligo'		=> { 'x' => 'league',
		     '#' => ', alliance' },
 'ligi'		=> { 'x' => 'tie',
		     '#' => ', to bind' },
 'ligno'	=> { 'x' => 'wood' },
 'limonado'	=> { 'x' => 'lemonade',
		     '#' => ', soft drink (europe)' },
 'lingvo'	=> { 'x' => 'language' },
 'linio'	=> { 'x' => 'line' },
 'lito'		=> { 'x' => 'bed' },
 'loĝi'		=> { 'x' => 'live',
		     '#' => ', to inhabit' },
 'loko'		=> { 'x' => 'place',
		     '#' => ', position' },
 'londono'	=> { 'x' => 'london',
		     't' => 'n',
		     '#' => 'capitalize' },
 'longa'	=> { 'x' => 'long' },
 'ludi'		=> { 'x' => 'play' },
 'lumi'		=> { 'x' => 'shine',
		     '#' => ', to give light' },
 'lundo'	=> { 'x' => 'monday' },
 'majo'		=> { 'x' => 'may ',
		     '#' => '(month)' },
 'mano'		=> { 'x' => 'hand' },
 'manĝi'	=> { 'x' => 'eat' },
 'manki'	=> { 'x' => 'be lacking',
		     '#' => ', to be absent' },
 'maro'		=> { 'x' => 'sea',
		     '#' => ', ocean' },
 'mardo'	=> { 'x' => 'tuesday' },
 'marko'	=> { 'x' => 'sign',
		     '#' => ', mark' },
 'marto'	=> { 'x' => 'march ',
		     '#' => '(month)' },
 'mateno'	=> { 'x' => 'morning' },
 'mejlo'	=> { 'x' => 'mile' },
 'membro'	=> { 'x' => 'member' },
 'memori'	=> { 'x' => 'remember' },
 'merkredo'	=> { 'x' => 'wednesday' },
 'meti'		=> { 'x' => 'put',
		     '#' => ', to place' },
 'mezo'		=> { 'x' => 'middle' },
 'mezuri'	=> { 'x' => 'measure ',
		     '#' => '(something) (trans.)' },
 'miliono'	=> { 'x' => 'million' },
 'militi'	=> { 'x' => 'wage war' },
 'minuto'	=> { 'x' => 'minute' },
 'miri'		=> { 'x' => 'marvel',
		     '#' => ', to be amazed' },
 'momento'	=> { 'x' => 'moment' },
 'mono'		=> { 'x' => 'money' },
 'monato'	=> { 'x' => 'month' },
 'mondo'	=> { 'x' => 'world' },
 'monto'	=> { 'x' => 'mountain' },
 'montri'	=> { 'x' => 'show' },
 'morti'	=> { 'x' => 'die ',
		     '#' => '(intrans.)' },
 'movi'		=> { 'x' => 'move ',
		     '#' => '(something) (trans.)' },
 'multa'	=> { 'x' => 'much',
		     '#' => ', a lot of' },
 'muro'		=> { 'x' => 'wall' },
 'nacio'	=> { 'x' => 'nation' },
 'naĝi'		=> { 'x' => 'swim' },
 'naski'	=> { 'x' => 'give birth ',
		     '#' => '(to) (trans.)' },
 'naturo'	=> { 'x' => 'nature' },
 'nazo'		=> { 'x' => 'nose' },
 'necesa'	=> { 'x' => 'necessary' },
 'neĝo'		=> { 'x' => 'snow' },
 'neŭtrala'	=> { 'x' => 'neutral',
		     '#' => ', impartial' },
 'nigra'	=> { 'x' => 'black' },
 'nokto'	=> { 'x' => 'night' },
 'nomo'		=> { 'x' => 'name' },
 'nombro'	=> { 'x' => 'number',
		     '#' => ', amount' },
 'norda'	=> { 'x' => 'north' },
 'nova'		=> { 'x' => 'new' },
 'nov-jorko'	=> { 'x' => 'new york',
		     't' => 'n',
		     '#' => 'capitalize' },
 'novembro'	=> { 'x' => 'november' },
 'nubo'		=> { 'x' => 'cloud' },
 'nulo'		=> { 'x' => 'nil',
		     '#' => ', name of the number zero' },
 'nur'		=> { 'x' => 'only',
		     't' => 'adv' },
 'ofta'		=> { 'x' => 'frequent',
		     '#' => ', common' },
 'okazi'	=> { 'x' => 'happen',
		     '#' => ', to occur' },
 'oktobro'	=> { 'x' => 'october' },
 'okulo'	=> { 'x' => 'eye' },
 'okupi'	=> { 'x' => 'occupy' },
 'ondo'		=> { 'x' => 'wave' },
 'onklo'	=> { 'x' => 'uncle' },
 'opinii'	=> { 'x' => 'think',
		     '#' => ', to have an opinion' },
 'ordo'		=> { 'x' => 'order' },
 'ordoni'	=> { 'x' => 'order',
		     '#' => ', to command' },
 'orelo'	=> { 'x' => 'ear' },
 'osto'		=> { 'x' => 'bone' },
 'ovo'		=> { 'x' => 'egg' },
 'paco'		=> { 'x' => 'peace' },
 'pafi'		=> { 'x' => 'shoot' },
 'pagi'		=> { 'x' => 'pay' },
 'pano'		=> { 'x' => 'bread' },
 'pantoflo'	=> { 'x' => 'slipper' },
 'papero'	=> { 'x' => 'paper' },
 'pardoni'	=> { 'x' => 'forgive',
		     '#' => ', to excuse' },
 'parizo'	=> { 'x' => 'paris',
		     't' => 'n',
		     '#' => 'capitalize' },
 'paroli'	=> { 'x' => 'speak' },
 'parto'	=> { 'x' => 'part' },
 'pasi'		=> { 'x' => 'pass' },
 'paŝi'		=> { 'x' => 'step',
		     '#' => ', to pace' },
 'patro'	=> { 'x' => 'father' },
 'peco'		=> { 'x' => 'piece',
		     '#' => ', bit' },
 'peni'		=> { 'x' => 'try',
		     '#' => ', to endeavour' },
 'pensi'	=> { 'x' => 'think' },
 'per'		=> { 'x' => 'by ',
		     't' => 'p',
		     '#' => '(means of), with' },
 'perdi'	=> { 'x' => 'lose' },
 'permesi'	=> { 'x' => 'allow',
		     '#' => ', to permit' },
 'persono'	=> { 'x' => 'person' },
 'peti'		=> { 'x' => 'ask ',
		     '#' => '(for), to request' },
 'piedo'	=> { 'x' => 'foot' },
 'pilko'	=> { 'x' => 'ball ',
		     '#' => '(for playing)' },
 'plaĉi'	=> { 'x' => 'please',
		     '#' => ', to be pleasing' },
 'plaĝo'	=> { 'x' => 'beach' },
 'planko'	=> { 'x' => 'floor' },
 'plej'		=> { 'x' => 'most ',
		     't' => 'adv',
		     '#' => '(superlative)' },
 'plena'	=> { 'x' => 'full' },
 'plendi'	=> { 'x' => 'complain' },
 'plezuro'	=> { 'x' => 'pleasure',
		     '#' => ', enjoyment' },
 'pli'		=> { 'x' => 'more ',
		     't' => 'adv',
		     '#' => '(comparative)' },
 'plori'	=> { 'x' => 'cry',
		     '#' => ', to weep' },
 'plu'		=> { 'x' => 'further',
		     't' => 'adv',
		     '#' => ', more' },
 'plumo'	=> { 'x' => 'pen' },
 'pluvo'	=> { 'x' => 'rain' },
 'poluso'	=> { 'x' => 'pole ',
		     '#' => '(as in north pole)' },
 'popolo'	=> { 'x' => 'people',
		     '#' => ', nation' },
 'por'		=> { 'x' => 'for',
		     't' => 'p',
		     '#' => ', in order to' },
 'pordo'	=> { 'x' => 'door' },
 'porti'	=> { 'x' => 'carry' },
 'post'		=> { 'x' => 'after',
		     't' => 'p',
		     '#' => ', behind' },
 'postuli'	=> { 'x' => 'demand',
		     '#' => ', to require' },
 'poŝo'		=> { 'x' => 'pocket' },
 'povi'		=> { 'x' => 'be able ',
		     '#' => '(to)' },
 'prava'	=> { 'x' => 'right',
		     '#' => ', correct' },
 'precipa'	=> { 'x' => 'main',
		     '#' => ', principal' },
 'premi'	=> { 'x' => 'press',
		     '#' => ', to squeeze' },
 'preni'	=> { 'x' => 'take' },
 'preskaŭ'	=> { 'x' => 'almost',
		     't' => 'adv' },
 'preta'	=> { 'x' => 'ready' },
 'preter'	=> { 'x' => 'beyond',
		     't' => 'p',
		     '#' => ', past' },
 'prezenti'	=> { 'x' => 'present' },
 'pri'		=> { 'x' => 'about',
		     't' => 'p',
		     '#' => ', concerning' },
 'printempo'	=> { 'x' => 'spring' },
 'pro'		=> { 'x' => 'because of',
		     't' => 'p',
		     '#' => ', by reason of' },
 'problemo'	=> { 'x' => 'problem' },
 'profunda'	=> { 'x' => 'deep' },
 'proksima'	=> { 'x' => 'near',
		     '#' => ', close' },
 'promeni'	=> { 'x' => 'take a walk' },
 'propra'	=> { 'x' => '',
		     '#' => '(one\'s) own' },
 'prosperi'	=> { 'x' => 'prosper' },
 'provi'	=> { 'x' => 'try',
		     '#' => ', to test' },
 'puni'		=> { 'x' => 'punish' },
 'punkto'	=> { 'x' => 'point',
		     '#' => ', period' },
 'pura'		=> { 'x' => 'clean',
		     '#' => ', pure' },
 'rajto'	=> { 'x' => 'a right' },
 'rakonti'	=> { 'x' => 'tell',
		     '#' => ', to narrate' },
 'rapida'	=> { 'x' => 'quick',
		     '#' => ', fast' },
 'regi'		=> { 'x' => 'rule',
		     '#' => ', to control' },
 'renkonti'	=> { 'x' => 'meet' },
 'respondi'	=> { 'x' => 'answer' },
 'resti'	=> { 'x' => 'remain',
		     '#' => ', to continue to be' },
 'resto'	=> { 'x' => 'rest',
		     '#' => ', remainder' },
 'ricevi'	=> { 'x' => 'receive' },
 'riĉa'		=> { 'x' => 'rich' },
 'ridi'		=> { 'x' => 'laugh' },
 'rigardi'	=> { 'x' => 'look ',
		     '#' => '(at)' },
 'rimarki'	=> { 'x' => 'notice' },
 'rimedo'	=> { 'x' => 'means',
		     '#' => ', resource' },
 'ripozi'	=> { 'x' => 'rest' },
 'rivero'	=> { 'x' => 'river' },
 'robo'		=> { 'x' => 'a dress' },
 'rompi'	=> { 'x' => 'break ',
		     '#' => '(trans.)' },
 'rondo'	=> { 'x' => 'round',
		     '#' => ', circle' },
 'rozo'		=> { 'x' => 'rose' },
 'ruĝa'		=> { 'x' => 'red' },
 'sabato'	=> { 'x' => 'saturday' },
 'sablo'	=> { 'x' => 'sand' },
 'sago'		=> { 'x' => 'arrow' },
 'salti'	=> { 'x' => 'jump' },
 'saluti'	=> { 'x' => 'greet' },
 'sama'		=> { 'x' => 'same' },
 'sana'		=> { 'x' => 'healthy' },
 'sandviĉo'	=> { 'x' => 'sandwich' },
 'sango'	=> { 'x' => 'blood' },
 'sata'		=> { 'x' => 'full',
		     '#' => ', not hungry' },
 'scii'		=> { 'x' => 'know' },
 'seĝo'		=> { 'x' => 'chair' },
 'seka'		=> { 'x' => 'dry' },
 'sekvi'	=> { 'x' => 'follow' },
 'semajno'	=> { 'x' => 'week' },
 'sen'		=> { 'x' => 'without',
		     't' => 'p' },
 'sendi'	=> { 'x' => 'send' },
 'senti'	=> { 'x' => 'feel ',
		     '#' => '(trans.)' },
 'septembro'	=> { 'x' => 'september' },
 'serĉi'	=> { 'x' => 'look for',
		     '#' => ', to seek' },
 'servi'	=> { 'x' => 'serve' },
 'sidi'		=> { 'x' => 'sit' },
 'silenti'	=> { 'x' => 'be silent' },
 'simpla'	=> { 'x' => 'simple' },
 'sinjoro'	=> { 'x' => 'mister',
		     '#' => ', gentleman' },
 'skatolo'	=> { 'x' => 'box',
		     '#' => ', case' },
 'skribi'	=> { 'x' => 'write' },
 'soifi'	=> { 'x' => 'be thirsty' },
 'sola'		=> { 'x' => 'alone' },
 'solvi'	=> { 'x' => 'solve ',
		     '#' => '(trans.)' },
 'somero'	=> { 'x' => 'summer' },
 'soni'		=> { 'x' => 'sound' },
 'speco'	=> { 'x' => 'kind',
		     '#' => ', sort' },
 'stacio'	=> { 'x' => 'station ',
		     '#' => '(for bus, train, etc.)' },
 'stari'	=> { 'x' => 'stand' },
 'stato'	=> { 'x' => 'state',
		     '#' => ', condition' },
 'stepo'	=> { 'x' => 'steppe' },
 'strato'	=> { 'x' => 'street' },
 'studi'	=> { 'x' => 'study' },
 'sub'		=> { 'x' => 'under',
		     't' => 'p',
		     '#' => ', beneath' },
 'suferi'	=> { 'x' => 'suffer' },
 'sufiĉa'	=> { 'x' => 'sufficient',
		     '#' => ', enough' },
 'sukcesi'	=> { 'x' => 'succeed' },
 'sukero'	=> { 'x' => 'sugar' },
 'suno'		=> { 'x' => 'sun' },
 'super'	=> { 'x' => 'over',
		     't' => 'p',
		     '#' => ', above' },
 'supro'	=> { 'x' => 'top',
		     '#' => ', summit' },
 'sur'		=> { 'x' => 'on',
		     't' => 'p',
		     '#' => ', upon' },
 'ŝafo'		=> { 'x' => 'sheep' },
 'ŝajni'	=> { 'x' => 'seem',
		     '#' => ', to appear to be' },
 'ŝanĝi'	=> { 'x' => 'change ',
		     '#' => '(trans.)' },
 'ŝati'		=> { 'x' => 'have a high opinion of',
		     '#' => ', to value, to like' },
 'ŝipo'		=> { 'x' => 'ship' },
 'ŝoseo'	=> { 'x' => 'road',
		     '#' => ', roadway' },
 'ŝtono'	=> { 'x' => 'stone' },
 'ŝuo'		=> { 'x' => 'shoe' },
 'tablo'	=> { 'x' => 'table' },
 'tago'		=> { 'x' => 'day' },
 'tajpi'	=> { 'x' => 'type' },
 'tamtamo'	=> { 'x' => 'tom-tom' },
 'taso'		=> { 'x' => 'cup' },
 'tasko'	=> { 'x' => 'task' },
 'teo'		=> { 'x' => 'tea' },
 'teatro'	=> { 'x' => 'a theater' },
 'teksaso'	=> { 'x' => 'texas',
		     't' => 'n',
		     '#' => 'capitalize' },
 'tempo'	=> { 'x' => 'time' },
 'teni'		=> { 'x' => 'hold',
		     '#' => ', to have' },
 'teniso'	=> { 'x' => 'tennis' },
 'tero'		=> { 'x' => 'earth',
		     '#' => ', ground' },
 'timi'		=> { 'x' => 'fear' },
 'tipo'		=> { 'x' => 'type',
		     '#' => ', sort' },
 'tiri'		=> { 'x' => 'pull' },
 'tra'		=> { 'x' => 'through',
		     't' => 'p' },
 'trafi'	=> { 'x' => 'hit ',
		     '#' => '(a goal, etc.), to strike' },
 'tranĉi'	=> { 'x' => 'cut' },
 'trankvila'	=> { 'x' => 'calm',
		     '#' => ', quiet' },
 'trans'	=> { 'x' => 'across',
		     't' => 'p',
		     '#' => ', on the other side of' },
 'trinki'	=> { 'x' => 'drink' },
 'trovi'	=> { 'x' => 'find' },
 'turni'	=> { 'x' => 'turn ',
		     '#' => '(trans.)' },
 'tuŝi'		=> { 'x' => 'touch' },
 'tuta'		=> { 'x' => 'whole',
		     '#' => ', entire' },
 'urbo'		=> { 'x' => 'city',
		     '#' => ', town' },
 'usono'	=> { 'x' => 'usa',
		     't' => 'n',
		     '#' => 'capitalize' },
 'utila'	=> { 'x' => 'useful' },
 'uzi'		=> { 'x' => 'use' },
 'vagono'	=> { 'x' => 'train waggon',
		     '#' => ', carriage' },
 'valizo'	=> { 'x' => 'suitcase',
		     '#' => ', luggage' },
 'valoro'	=> { 'x' => 'value' },
 'varbi'	=> { 'x' => 'recruit' },
 'varma'	=> { 'x' => 'warm',
		     '#' => ', hot' },
 'vasta'	=> { 'x' => 'vast',
		     '#' => ', huge' },
 'veki'		=> { 'x' => 'awake ',
		     '#' => '(someone) (trans.)' },
 'veni'		=> { 'x' => 'come' },
 'vendi'	=> { 'x' => 'sell ',
		     '#' => '(trans.)' },
 'vendredo'	=> { 'x' => 'friday' },
 'vento'	=> { 'x' => 'wind' },
 'vera'		=> { 'x' => 'true',
		     '#' => ', real' },
 'verda'	=> { 'x' => 'green' },
 'vespero'	=> { 'x' => 'evening' },
 'vesto'	=> { 'x' => 'garment',
		     '#' => ', article of clothing' },
 'vetero'	=> { 'x' => 'weather' },
 'veturi'	=> { 'x' => 'travel ',
		     '#' => '(by vehicle: to drive, to fly, etc.)' },
 'vidi'		=> { 'x' => 'see' },
 'vilaĝo'	=> { 'x' => 'village' },
 'vino'		=> { 'x' => 'wine' },
 'vintro'	=> { 'x' => 'winter' },
 'viro'		=> { 'x' => 'man' },
 'vitro'	=> { 'x' => 'glass ',
		     '#' => '(substance)' },
 'vivi'		=> { 'x' => 'live',
		     '#' => ', to be alive' },
 'vizaĝo'	=> { 'x' => 'face' },
 'viziti'	=> { 'x' => 'visit' },
 'vojo'		=> { 'x' => 'way',
		     '#' => ', road' },
 'vojaĝi'	=> { 'x' => 'travel',
		     '#' => ', to journey' },
 'voki'		=> { 'x' => 'call ',
		     '#' => '(trans)' },
 'voli'		=> { 'x' => 'want to' },
 'vorto'	=> { 'x' => 'word' },
 'zorgi'	=> { 'x' => 'care for',
		     '#' => ', to take care of' },
);
}

1;

