# vi: ts=8 sw=8

package Tongues::Latviesu;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Baltic CP1257 / ISO 8859-13 / Latin-7

# Alphabetical order
# A  B C  D E  F G  H I  J K  L  M N O P R S  T U  V Z 
# a  b c  d e  f g  h i  j k  l  m n o p r s  t u  v z 

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::BalticWin;

$charset = new Charsets::BalticWin;

# Table for converting words to root form
$grammar = [
 # Noun case
 # Noun gender
 # Noun plural
 # Adjectives
 # Verb past participle
 # Verb gerund
 # Verb present participle
 # Verb present
 # Verb present subjunctive
 # Verb imperitive
 # Verb preterite
 # Verb imperfect
 # Verb future
 # Verb conditional
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translatioin		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			nouns, pronouns, adjectives
#	m -> masculine
#	f -> feminine
# n -> number:			articles, pronouns, verbs, adjectives
#	s -> singular		default
#	p -> plural		default for words ending in s
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative
# c -> case:
#	n -> nominative
#	g -> genitive
#	d -> dative
#	a -> accusative
#	inst -> instrumental
#	l -> locative

# Latvian to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 #    Masculine
 #     Singular
 #     Plural
 #    Feminine
 #     Singular
 #     Plural
 #   Indefinite articles
 #  Pronouns & possessive adjectives
 #   1st person
 #   2nd person
 #   3rd person
 #  Other functional words
 'pa'		=> { 'x' => 'along',
		     '#' => '; on; to; during ',
 		     't' => 'p' },
 'par'		=> { 'x' => 'for',
		     '#' => 'of; about; ',
 		     't' => 'p' },
 'pat'		=> { 'x' => 'even', 
 		     't' => 'adv' },
 'pats'		=> { 'x' => 'self',
		     '#' => 'very ' },
 'pr'		=> { 'x' => 'over' },
 'prk'	=> { 'x' => 'too',
 		     't' => 'adv' },
 'prjais'	=> { 'x' => 'rest',
		     '#' => 'the rest',
 		     't' => 'n' },
 'pri'		=> { 'x' => 'above',
		     '#' => 'over; across; past; beyond ' },
 'pc'		=> { 'x' => 'in',
		     '#' => 'after; by; ',
 		     't' => 'p' },
 'pie'		=> { 'x' => 'by',
		     '#' => 'at; on; to; against ',
 		     't' => 'p' },
 'pirms'	=> { 'x' => 'before',
		     '#' => 'prep or adv.?' },
 'pret'		=> { 'x' => 'against',
		     '#' => '; for; to ',
 		     't' => 'p' },
 'prieku'	=> { 'x' => 'forward',
		     '#' => '(uz priesku); adv.?' },
 'projm'	=> { 'x' => 'away',
		     '#' => 'adv.? ' },
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 'pirmais'	=> { 'x' => 'first' },
 'piektais'	=> { 'x' => 'fifth' },
 # Days and months
 'pirmdiena'	=> { 'x' => 'monday' },
 'piektdiena'	=> { 'x' => 'friday' },
 'decembr'	=> { 'x' => 'december' },
 # Key verbs
 # Vocabulary
 'asambleja'	=> { 'x' => 'assembly',
 		     't' => 'n' },
 'deklarcija'	=> { 'x' => 'declaration',
 		     't' => 'n' },
 'enerl'	=> { 'x' => 'general',
 		     't' => 'a' },
 'pacelt'	=> { 'x' => 'lift',
		     '#' => 'to pick up ',
 		     't' => 'v' },
 'pacelties'	=> { 'x' => 'rise',
 		     't' => 'v' },
 'padart'	=> { 'x' => 'do',
		     '#' => 'finish ',
 		     't' => 'v' },
 'padomt'	=> { 'x' => 'think over',
		     '#' => 'multiword',
 		     't' => 'v' },
 'padome'	=> { 'x' => 'council',
		     '#' => 'soviet ',
 		     't' => 'v' },
 'padoms'	=> { 'x' => 'advice',
 		     't' => 'n' },
 'pagaidm'	=> { 'x' => 'for now',
		     '#' => 'for the time being; for the present ',
 		     't' => 'adv' },
 'pagaidt'	=> { 'x' => 'wait',
		     '#' => 'wait a little; wait for a while ',
 		     't' => 'v' },
 'pagalms'	=> { 'x' => 'yard',
 		     't' => 'n' },
 'paiet'	=> { 'x' => 'go',
		     '#' => 'to walk; to pass ',
 		     't' => 'v' },
 'pakpeniski'	=> { 'x' => 'gradually',
 		     't' => 'adv' },
 'palags'	=> { 'x' => 'sheet',
 		     't' => 'n' },
 'paldies'	=> { 'x' => 'thank you',
 		     't' => 'interj' },
 'palielinties'	=> { 'x' => 'increase',
	 		     't' => 'v' },
 'palielint'	=> { 'x' => 'increase',
		     '#' => 'sth.; enlarge ',
 		     't' => 'v' },
 'palikt'	=> { 'x' => 'remain',
		     '#' => 'stay; put ',
 		     't' => 'v' },
 'paldzt'	=> { 'x' => 'help',
		     '#' => 'aid ',
 		     't' => 'v' },
 'paldzba'	=> { 'x' => 'help',
		     '#' => 'aid ',
 		     't' => 'n' },
 'palgs'	=> { 'x' => 'helper',
		     '#' => 'assistant (person)',
 		     't' => 'n' },
 'palodze'	=> { 'x' => 'window sill',
		     '#' => 'multiword',
 		     't' => 'n' },
 'pamant'	=> { 'x' => 'notice',
 		     't' => 'v' },
 'pamats'	=> { 'x' => 'base',
		     '#' => 'basis; reason; foundation ',
 		     't' => 'n' },
 'pamest'	=> { 'x' => 'leave',
 		     't' => 'v' },
 'pankt'	=> { 'x' => 'achieve',
		     '#' => 'catch up ',
 		     't' => 'v' },
 'pankums'	=> { 'x' => 'success',
		     '#' => 'achievement ',
 		     't' => 'n' },
 'paemt'	=> { 'x' => 'take',
 		     't' => 'v' },
 'pamiens'	=> { 'x' => 'way',
		     '#' => 'method ',
 		     't' => 'n' },
 'pants'	=> { 'x' => 'article',
 		     't' => 'n' },
 'papdis'	=> { 'x' => 'heel',
 		     't' => 'n' },
 'paprs'	=> { 'x' => 'paper',
 		     't' => 'n' },
 'parasti'	=> { 'x' => 'usually',
 		     't' => 'adv' },
 'parasts'	=> { 'x' => 'usual',
		     '#' => 'ordinary ',
 		     't' => 'a' },
 'paraugs'	=> { 'x' => 'example',
		     '#' => 'sample; standard; model ',
 		     't' => 'n' },
 'pardt'	=> { 'x' => 'show', 
 		     't' => 'v' },
 'pardties'	=> { 'x' => 'appear',
		     '#' => 'emerge ',
 		     't' => 'v' },
 'paredzt'	=> { 'x' => 'foresee', 
 		     't' => 'v' },
 'pareizi'	=> { 'x' => 'correctly',
		     '#' => 'right ',
 		     't' => 'adv' },
 'pareizs'	=> { 'x' => 'correct',
		     '#' => 'right ',
 		     't' => 'a' },
 'part'	=> { 'x' => 'the day after tomorrow',
		     '#' => 'multiword',
 		     't' => 'n' },
 'parunt'	=> { 'x' => 'speak',
		     '#' => 'talk ',
 		     't' => 'v' },
 'pasaka'	=> { 'x' => 'fairy tale',
 		     't' => 'v' },
 'pasaule'	=> { 'x' => 'world',
 		     't' => 'n' },
 'paskums'	=> { 'x' => 'enterprise',
 		     't' => 'n' },
 'paskatties'	=> { 'x' => 'look at',
		     '#' => 'multiword',
 		     't' => 'n' },
 'pasniegt'	=> { 'x' => 'hand',
		     '#' => 'present ',
 		     't' => 'v' },
 'paststt'	=> { 'x' => 'tell',
		     '#' => 'to narrate ',
 		     't' => 'v' },
 'paapkalpoans'	=> { 'x' => 'self-service',
		     '#' => 'multiword?',
 			     't' => 'n' },
 'palaik'	=> { 'x' => 'now',
		     '#' => 'just now ',
 		     't' => 'adv' },
 'pareiz'	=> { 'x' => 'now',
		     '#' => 'at present ',
 		     't' => 'adv' },
 'pateikt'	=> { 'x' => 'say',
		     '#' => 'tell ',
 		     't' => 'v' },
 'pateikties'	=> { 'x' => 'thank',
 		     't' => 'v' },
 'patiesba'	=> { 'x' => 'truth',
 		     't' => 'n' },
 'patiem'	=> { 'x' => 'indeed',
		     '#' => 'really ',
 		     't' => 'adv' },
 'patikt'	=> { 'x' => 'like',
 		     't' => 'v' },
 'pavadt'	=> { 'x' => 'accompany',
		     '#' => 'see off',
 		     't' => 'v' },
 'pavasaris'	=> { 'x' => 'spring',
 		     't' => 'n' },
 'pavisam'	=> { 'x' => 'entirely',
 		     't' => 'adv' },
 'pazaudt'	=> { 'x' => 'lose',
 		     't' => 'v' },
 'pazt'	=> { 'x' => 'recognize',
		     '#' => 'know ',
 		     't' => 'v' },
 'pazust'	=> { 'x' => 'disappear',
 		     't' => 'v' },
 'prbaudt'	=> { 'x' => 'examine',
		     '#' => 'check ',
 		     't' => 'v' },
 'prdevjs'	=> { 'x' => 'salesperson',
		     '#' => 'shop assistant (person)',
 		     't' => 'n' },
 'prdot'	=> { 'x' => 'sell',
 		     't' => 'v' },
 'preja'	=> { 'x' => 'passage',
 		     't' => 'n' },
 'priet'	=> { 'x' => 'cross',
		     '#' => 'stop; cease ',
 		     't' => 'v' },
 'pris'	=> { 'x' => 'pair',
		     '#' => 'couple; several; few ',
 		     't' => 'n' },
 'prnkt'	=> { 'x' => 'return',
 		     't' => 'v' },
 'prsniegt'	=> { 'x' => 'exceed',
 		     't' => 'v' },
 'prtika'	=> { 'x' => 'food',
 		     't' => 'n' },
 'prtraukt'	=> { 'x' => 'interrupt',
		     '#' => 'stop ',
 		     't' => 'v' },
 'prtraukums'	=> { 'x' => 'break',
		     '#' => 'interval ',
 		     't' => 'n' },
 'prvrsties'	=> { 'x' => 'change',
		     '#' => 'change into ',
 		     't' => 'v' },
 'pele'		=> { 'x' => 'mouse',
		     '#' => 'animate',
 		     't' => 'n' },
 'pelks'	=> { 'x' => 'grey', 
 		     't' => 'a' },
 'pcpusdiena'	=> { 'x' => 'afternoon',
 		     't' => 'n' },
 'pda'		=> { 'x' => 'foot',
		     '#' => 'footprint ',
 		     't' => 'n' },
 'pdjais'	=> { 'x' => 'last',
		     '#' => 'the latest ',
 		     't' => 'a' },
 'pki'	=> { 'x' => 'suddenly',
 		     't' => 'adv' },
 'pieaugt'	=> { 'x' => 'grow',
		     '#' => 'increase ',
 		     't' => 'v' },
 'piecelties'	=> { 'x' => 'rise',
 		     't' => 'v' },
 'pieci'	=> { 'x' => 'fife',
 		     't' => 'n' },
 'piedalties'	=> { 'x' => 'participate',
 		     't' => 'v' },
 'piedert'	=> { 'x' => 'belong to',
		     '#' => 'multiword',
 		     't' => 'v' },
 'piedot'	=> { 'x' => 'forgive',
 		     't' => 'v' },
 'piemrs'	=> { 'x' => 'example',
 		     't' => 'n' },
 'piemineklis'	=> { 'x' => 'monument',
 		     't' => 'n' },
 'pienkt'	=> { 'x' => 'come',
		     '#' => 'come up; arrive ',
 		     't' => 'v' },
 'pienkums'	=> { 'x' => 'duty',
 		     't' => 'n' },
 'piens'	=> { 'x' => 'milk',
 		     't' => 'n' },
 'pieemt'	=> { 'x' => 'receive',
		     '#' => 'accept; adopt; engage; hire ',
 		     't' => 'v' },
 'pierast'	=> { 'x' => 'get used to',
		     '#' => 'accustom',
 		     't' => 'v' },
 'pierdt'	=> { 'x' => 'prove',
 		     't' => 'v' },
 'piere'	=> { 'x' => 'forehead',
 		     't' => 'n' },
 'pieredze'	=> { 'x' => 'experience',
 		     't' => 'n' },
 'pietikt'	=> { 'x' => 'suffice',
		     '#' => 'be enough; have enough ',
 		     't' => 'v' },
 'pietura'	=> { 'x' => 'stop',
 		     't' => 'n' },
 'pildspalva'	=> { 'x' => 'pen',
		     '#' => 'fountain-pen ',
 		     't' => 'n' },
 'pilngi'	=> { 'x' => 'completely',
		     '#' => 'absolutely ',
 		     't' => 'adv' },
 'pilns'	=> { 'x' => 'full',
 		     't' => 'a' },
 'pilsta'	=> { 'x' => 'town',
		     '#' => 'city ',
 		     't' => 'n' },
 'pilsonis'	=> { 'x' => 'citizen',
		     '#' => '(person)',
 		     't' => 'n' },
 'pircjs'	=> { 'x' => 'buyer',
		     '#' => 'customer (person)',
 		     't' => 'n' },
 'pirksts'	=> { 'x' => 'finger',
 		     't' => 'n' },
 'pirkt'	=> { 'x' => 'buy',
 		     't' => 'v' },
 'ple'		=> { 'x' => 'duck',
		     '#' => 'animate',
 		     't' => 'n' },
 'plai'	=> { 'x' => 'widely',
 		     't' => 'adv' },
 'plas'	=> { 'x' => 'wide',
		     '#' => 'spacious; extensive ',
 		     't' => 'a' },
 'plats'	=> { 'x' => 'broad',
		     '#' => 'wide ',
 		     't' => 'a' },
 'platums'	=> { 'x' => 'width',
		     '#' => 'latitude ',
 		     't' => 'n' },
 'plauksta'	=> { 'x' => 'palm', 
 		     't' => 'n' },
 'plaukts'	=> { 'x' => 'shelf',
 		     't' => 'n' },
 'plns'	=> { 'x' => 'thin',
		     '#' => 'adj.; plan noun' },
 'plecs'	=> { 'x' => 'shoulder',	
 		     't' => 'n' },
 'plme'	=> { 'x' => 'plum',
 		     't' => 'n' },
 'plst'	=> { 'x' => 'flow',
 		     't' => 'v' },
 'pava'	=> { 'x' => 'meadow',
 		     't' => 'n' },
 'poga'		=> { 'x' => 'button',
 		     't' => 'n' },
 'posms'	=> { 'x' => 'period',
		     '#' => 'span ',
 		     't' => 'n' },
 'prasba'	=> { 'x' => 'demand',
		     '#' => 'requirement ',
 		     't' => 'n' },
 'prast'	=> { 'x' => 'ask',
		     '#' => 'demand ',
 		     't' => 'v' },
 'prast'	=> { 'x' => 'know',
		     '#' => 'to be able ',
 		     't' => 'v' },
 'prts'	=> { 'x' => 'mind',
		     '#' => 'intellect ',
 		     't' => 'n' },
 'preambula'	=> { 'x' => 'preamble',
 		     't' => 'n' },
 'prece'	=> { 'x' => 'article',
		     '#' => 'goods ',
 		     't' => 'n' },
 'pretestba'	=> { 'x' => 'resistance', 
 		     't' => 'n' },
 'pretjs'	=> { 'x' => 'opposite',
		     '#' => 'adj., prep.?' },
 'priecties'	=> { 'x' => 'be glad',
		     '#' => 'enjoy oneself (multiword)',
 		     't' => 'v' },
 'priecgs'	=> { 'x' => 'glad',
		     '#' => 'happy ',
 		     't' => 'a' },
 'priede'	=> { 'x' => 'pine',
 		     't' => 'n' },
 'prieks'	=> { 'x' => 'joy',
		     '#' => 'pleasure ',
 		     't' => 'n' },
 'prieka'	=> { 'x' => 'front',
 		     't' => 'n' },
 'prieknieks'	=> { 'x' => 'head',
		     '#' => 'chief (poss. person)',
 		     't' => 'n' },
 'prieksdtjs'	=> { 'x' => 'chairman',
		     '#' => '(person) ',
	 		     't' => 'n' },
 'protams'	=> { 'x' => 'certainly',
 		     't' => 'adv' },
 'pudele'	=> { 'x' => 'bottle',
 		     't' => 'n' },
 'puika'	=> { 'x' => 'boy',
		     '#' => '(person)',
 		     't' => 'n' },
 'puisis'	=> { 'x' => 'lad',
		     '#' => 'bachelor; farmhand (person)',
 		     't' => 'n' },
 'pue'		=> { 'x' => 'flower',
 		     't' => 'n' },
 'pulkstenis'	=> { 'x' => 'clock',
 		     't' => 'n' },
 'pulveris'	=> { 'x' => 'powder',
 		     't' => 'n' },
 'punkts'	=> { 'x' => 'point',
		     '#' => 'full stop ',
 		     't' => 'n' },
 'purvs'	=> { 'x' => 'bog',
		     '#' => 'marsh ',
 		     't' => 'n' },
 'pusdiena'	=> { 'x' => 'noon',
		     '#' => 'which part of speech?' },
 'pusdienas'	=> { 'x' => 'dinner', 
 		     't' => 'n' },
 'puse'		=> { 'x' => 'half',
		     '#' => 'side ',
 		     't' => 'n' },
 'putns'	=> { 'x' => 'bird',
		     '#' => 'animate',
 		     't' => 'n' },
 'putra'	=> { 'x' => 'porridge',	
 		     't' => 'n' },
 'putraimi'	=> { 'x' => 'groats',
		     '#' => '??' },
 'visprj'	=> { 'x' => 'universal',
 		     't' => 'a' },
);
}

1;

