# vi: ts=8 sw=8 sts=8

package Tongues::Nederlands;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Western European CP1252 / ISO 8859-1 / Latin-1

# Alphabetical order
# A B C D E F G H I J K L M N O P Q R S T U V W X Y Z
# a b c d e f g h i j k l m n o p q r s t u v w x y z

# Extra characters
# IJ (Unicode only)
# ij (Unicode only)

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::WestEuroWin;

$charset = new Charsets::WestEuroWin;

# Table for converting words to root form
$grammar = [
 # Noun gender
 # Noun plural
 [ 'en',	'',		'',		's',	'n' ],
 [ 's',		'',		'',		's',	'n' ],
 # Adjectives
 # Verb past participle
 #  -t is added when the past tense adds -te, -d when -de is added in the past tense
 [ 'ge-t',	'en',		'',		'ed',	'v' ],
 [ 'ge-d',	'en',		'',		'ed',	'v' ],
 #  verbs ending with an unstressed prefix do not take ge- in the past participle.
 #[ 't',	'en',		'',		'ed',	'v' ],
 #[ 'd',	'en',		'',		'ed',	'v' ],
 #  verbs with a stressed prefix place ge- between the prefix and the verb to form the past participle.
 #   aan-ge-haald  -> aanhalen
 #   over-ge-haald -> overhalen
 #   voor-ge-zegd  -> voorzeggen
 # Verb gerund
 # Verb present participle
 [ 'd',		'en',		'',		'ing',	'v' ],
 #[ 'de',	'en',		'',		'ing',	'v' ],
 # Verb present (p)
 [ '',		'en',		'',		'',	'v' ],	# I	|root|  -> |root|en
 [ 'b',		'bben',		'',		'',	'v' ],	# 	heb     -> hebben
 [ 'k',		'kken',		'',		'',	'v' ],	#
 [ 'a',		'aan',		'',		'',	'v' ],
 [ 'eef',	'even',		'',		'',	'v' ],	#	leef    -> leven
 [ 'ees',	'ezen',		'',		'',	'v' ],	#	lees	-> lesen
 [ 'oof',	'oven',		'',		'',	'v' ],
 [ 't',		'en',		'',		'',	'v' ],	# you	|root|t -> |root|en (also imperative)
 [ 'bt',	'bben',		'',		'',	'v' ],	#	hebt    -> hebben
 [ 'kt',	'kken',		'',		'',	'v' ],	#
 # Verb past (t)
 #  -te, -ten are added when the consonant preceding the ending -en in the
 #  infinitive is strong.
 [ 'te',	'en',		'',		'ed',	'v' ],	# ik, je, hij
 [ 'aatte',	'aten',		'',		'ed',	'v' ],
 [ 'iste',	'issen',	'',		'ed',	'v' ],
 [ 'ookte',	'oken',		'',		'ed',	'v' ],
 [ 'oopte',	'open',		'',		'ed',	'v' ],
 [ 'ten',	'en',		'',		'ed',	'v' ],	# wij, zij
 [ 'aatten',	'aten',		'',		'ed',	'v' ],
 [ 'isten',	'issen',	'',		'ed',	'v' ],
 [ 'ookten',	'oken',		'',		'ed',	'v' ],
 [ 'oopten',	'open',		'',		'ed',	'v' ],
 #  In all other cases -de and -den are added
 [ 'de',	'en',		'',		'ed',	'v' ],	# ik, je, hij
 [ 'den',	'en',		'',		'ed',	'v' ],	# wij, zij
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translatioin		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			nouns, pronouns, adjectives
#	m -> masculine		default
#	f -> feminine		default for words ending in a
# n -> number:			articles, pronouns, verbs, adjectives
#	s -> singular		default
#	p -> plural		default for words ending in s
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative

# Dutch to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 'de'		=> { 'x' => 'the',
		     '#' => 'plural',
		     't' => 'art' },
 'het'		=> { 'x' => 'the/it',
		     '#' => 'neuter, it',
		     't' => 'art' },
 #   Indefinite articles
 'een'		=> { 'x' => 'a',
		     '#' => 'an, one',
 		     't' => 'art' },
 #  Pronouns & possessive adjectives
 #   1st person
 'ik'		=> { 'x' => 'i',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 'mij'		=> { 'x' => 'me',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 'me'		=> { 'x' => 'me',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 'mijn'		=> { 'x' => 'my',
		     '#' => 'possessive adjective',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 'mijne'	=> { 'x' => 'mine',
		     '#' => 'possessive pronoun',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 's' },
 #
 'wij'		=> { 'x' => 'we',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 'p' },
 'we'		=> { 'x' => 'we',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 'p' },
 'ons'		=> { 'x' => 'us',
		     '#' => 'object, after prep.',
 		     't' => 'pro',
		     '#' => 'possessive adj. before sng. neut. nouns',
		     'p' => '1',
		     'n' => 'p' },
 'onze'		=> { 'x' => 'our',
		     '#' => 'poss. adj. not before sng. neut. nouns',
 		     't' => 'pro',
		     '#' => 'poss. pro. ours',
		     'p' => '1',
		     'n' => 'p' },
 #   2nd person
 'jij'		=> { 'x' => 'you',
		     '#' => 'informal: tu, du',
 		     't' => 'pro',
		     '#' => 'singular only',
		     'p' => '2',
		     'n' => 's' },
 'jou'		=> { 'x' => 'you',
		     '#' => 'object, after prep.',
 		     't' => 'pro',
		     'p' => '2',
		     'n' => 's' },
 'je'		=> { 'x' => 'you',
		     '#' => 'singular & plural',
 		     't' => 'pro',
		     '#' => 'poss. adj. your',
		     'p' => '2' },
 'jullie'	=> { 'x' => 'we',
		     '#' => 'you people, youse, y\'all',
 		     't' => 'pro',
		     '#' => 'plural only',
		     'p' => '2',
		     '#' => 'poss. adj. your',
		     'n' => 'p' },
 'u'		=> { 'x' => 'you',
		     '#' => 'formal: usted, sie',
 		     't' => 'pro',
		     'p' => '2' },
 'gij'		=> { 'x' => 'you',
		     '#' => 'literary, biblical',
 		     't' => 'pro',
		     'p' => '2',
		     'n' => 's' },
 'we'		=> { 'x' => 'we',
 		     't' => 'pro',
		     'p' => '1',
		     'n' => 'p' },
 'jouw'		=> { 'x' => 'your',
		     '#' => 'poss. adj.',
 		     't' => 'pro',
		     'p' => '2' },
 'jouwe'	=> { 'x' => 'yours',
		     '#' => 'poss. pron.',
 		     't' => 'pro',
		     'p' => '2' },
 'uw'		=> { 'x' => 'your',
		     '#' => 'poss. adj.',
 		     't' => 'pro',
		     'p' => '2' },
 'uwe'		=> { 'x' => 'yours',
		     '#' => 'poss. pron.',
 		     't' => 'pro',
		     'p' => '2' },
 #   3rd person
 'hij'		=> { 'x' => 'he',
 		     't' => 'pro',
		     'p' => '3',
		     'n' => 's',
		     'g' => 'm' },
 'hem'		=> { 'x' => 'him',
		     '#' => 'object, after prep.',
 		     't' => 'pro',
		     'p' => '3',
		     'n' => 's',
		     'g' => 'm' },
 'haar'		=> { 'x' => 'her/them',
		     '#' => 'object, after prep.',
 		     't' => 'pro',
		     '#' => 'poss. adj. his her its',
		     'p' => '3' },
 'hare'		=> { 'x' => 'hers',
		     '#' => 'poss. pron.',
 		     't' => 'pro',
		     'p' => '3',
		     'g' => 'f',
		     'n' => 's' },
 'zij'		=> { 'x' => 'she/they',
 		     't' => 'pro',
		     'p' => '3' },
 'zijne'	=> { 'x' => 'his',
		     '#' => 'poss. pron.',
 		     't' => 'pro',
		     'p' => '3',
		     'g' => 'm',
		     'n' => 's' },
 'ze'		=> { 'x' => 'she/they',
		     '#' => 'them obj. after prep.',
 		     't' => 'pro',
		     '#' => 'things but also persons',
		     'p' => '3' },
 'hun'		=> { 'x' => 'them',
		     '#' => 'persons. object, after prep.',
 		     't' => 'pro',
		     '#' => 'spoken, dir. obj., ind. obj., after prep.',
		     'p' => '3',
		     '#' => 'poss. adj. their' },
 'hunne'	=> { 'x' => 'theirs',
		     '#' => 'poss. pron.',
 		     't' => 'pro',
		     'p' => '3',
		     'n' => 'p' },
 'hen'		=> { 'x' => 'them',
		     '#' => 'persons. object, after prep.',
 		     't' => 'pro',
		     '#' => 'written, dir. obj., after prep.',
		     'p' => '3' },
 #  Other functional words
 'altijd'	=> { 'x' => 'always',
		     '#' => 'adverb' },
 'boven'	=> { 'x' => 'above',
 		     't' => 'p' },
 'daar'		=> { 'x' => 'there',
		     '#' => 'adverb?' },
 'dat'		=> { 'x' => 'that',
		     '#' => 'demon. pron. cf die' },
 'deze'		=> { 'x' => 'this',
		     '#' => 'these; demon. pron. cf dit' },
 'die'		=> { 'x' => 'that',
		     '#' => 'those; demon. pron. cf dat' },
 'dit'		=> { 'x' => 'this',
		     '#' => 'demon. pron. cf deze' },
 'en'		=> { 'x' => 'and',
 		     't' => 'conj' },
 'geen'		=> { 'x' => 'no' },
 'genoeg'	=> { 'x' => 'enough',
		     '#' => 'adverb and adjective?' },
 'gisteren'	=> { 'x' => 'yesterday',
		     '#' => 'adverb and noun?' },
 'hier'		=> { 'x' => 'here',
		     '#' => 'adverb?' },
 'hoe'		=> { 'x' => 'how many',
		     '#' => '2 words' },
 'hoeveel'	=> { 'x' => 'how much',
		     '#' => '2 words' },
 'in'		=> { 'x' => 'in',
 		     't' => 'p' },
 'ja'		=> { 'x' => 'yes',
		     '#' => 'interjection' },
 'langs'	=> { 'x' => 'along',
 		     't' => 'p' },
 'maar'		=> { 'x' => 'but',
 		     't' => 'conj' },
 'meest'	=> { 'x' => 'most',
		     '#' => 'superlative' },
 'morgen'	=> { 'x' => 'tomorrow',
		     '#' => 'adverb and noun?' },
 'na'		=> { 'x' => 'after',
		     't' => 'p' },
 'naar'		=> { 'x' => 'to',
		     '#' => 'at',
 		     't' => 'p' },
 'naast'	=> { 'x' => 'next',
		     '#' => 'next to',
 		     't' => 'p' },
 'natuurlijk'	=> { 'x' => 'naturally',
		     '#' => 'of course; adverb, interjection' },
 'neen'		=> { 'x' => 'no',
		     '#' => 'interjection' },
 'niet'		=> { 'x' => 'not' },
 'nooit'	=> { 'x' => 'never',
		     '#' => 'adverb' },
 'noord'	=> { 'x' => 'north',
		     '#' => 'noun & adverb?  compass direction' },
 'nu'		=> { 'x' => 'now',
		     '#' => 'adverb?' },
 'of'		=> { 'x' => 'or',
		     '#' => 'conjunction' },
 'om'		=> { 'x' => 'round',
		     '#' => 'in order to, in, at, about',
 		     't' => 'p' },
 'ooit'		=> { 'x' => 'ever' },
 'ook'		=> { 'x' => 'too' },
 'op'		=> { 'x' => 'on',
		     '#' => 'at',
 		     't' => 'p' },
 'soms'		=> { 'x' => 'sometimes' },
 'straks'	=> { 'x' => 'presently',
		     '#' => 'adverb' },
 'te'		=> { 'x' => 'too' },
 'van'		=> { 'x' => 'of',
		     '#' => 'from',
 		     't' => 'p' },
 'veel'		=> { 'x' => 'much' },
 'voor'		=> { 'x' => 'for',
 		     't' => 'p' },
 'waar'		=> { 'x' => 'where' },
 'waarom'	=> { 'x' => 'why' },
 'wie'		=> { 'x' => 'who' },
 'zo'		=> { 'x' => 'so' },
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 'n'		=> { 'x' => 'one',
		     '#' => 'but usually "een"' },
 'eerste'	=> { 'x' => 'first' },
 'eens'		=> { 'x' => 'once' },
 'twee'		=> { 'x' => 'two' },
 'tweede'	=> { 'x' => 'second' },
 'drie'		=> { 'x' => 'three' },
 'derde'	=> { 'x' => 'third' },
 'vier'		=> { 'x' => 'four' },
 'vijf'		=> { 'x' => 'five' },
 'zes'		=> { 'x' => 'six' },
 'zeven'	=> { 'x' => 'seven' },
 'acht'		=> { 'x' => 'eight' },
 'negen'	=> { 'x' => 'nine' },
 'tien'		=> { 'x' => 'ten' },
 'elf'		=> { 'x' => 'eleven' },
 'twaalf'	=> { 'x' => 'twelve' },
 'veertig'	=> { 'x' => 'forty' },
 'vijftig'	=> { 'x' => 'fifty' },
 'zestig'	=> { 'x' => 'sixty' },
 'zeventig'	=> { 'x' => 'seventy' },
 'tachtig'	=> { 'x' => 'eighty' },
 'negentig'	=> { 'x' => 'ninety' },
 'honderd'	=> { 'x' => 'hundred' },
 'duizend'	=> { 'x' => 'thousane' },
 # Days and months
 'zondag'	=> { 'x' => 'sunday' },
 'maandag'	=> { 'x' => 'monday' },
 'dinsdag'	=> { 'x' => 'tuesday' },
 'woensdag'	=> { 'x' => 'wednesday' },
 'donderdag'	=> { 'x' => 'thursday' },
 'vridag'	=> { 'x' => 'friday' },
 'zaterdag'	=> { 'x' => 'saturday' },
 'januari'	=> { 'x' => 'january' },
 'februari'	=> { 'x' => 'february' },
 'maart'	=> { 'x' => 'march' },
 'april'	=> { 'x' => 'april' },
 'mei'		=> { 'x' => 'may' },
 'juni'		=> { 'x' => 'june' },
 'juli'		=> { 'x' => 'july' },
 'augustus'	=> { 'x' => 'august' },
 'september'	=> { 'x' => 'september' },
 'oktober'	=> { 'x' => 'october' },
 'november'	=> { 'x' => 'november' },
 'december'	=> { 'x' => 'december' },

 # Key verbs
 #  zijn - to be
 'zijn'		=> { 'x' => 'be',
		     '#' => 'inf., we, y\'all, they',
 		     't' => 'v',
		     '#' => 'also poss. adj. his, her, its' },
 'ben'		=> { 'x' => 'am',
 		     'r' => 'zijn',
		     't' => 'v',
		     'p' => '1',
		     'n' => 's',
		     'c' => 'p' },
 'bent'		=> { 'x' => 'are',
 		     'r' => 'zijn',
		     't' => 'v',
		     'p' => '2',
		     'n' => 's',
		     'c' => 'p' },
 'is'		=> { 'x' => 'is',
 		     'r' => 'zijn',
		     't' => 'v',
		     'p' => '3',
		     'n' => 's',
		     'c' => 'p' },
 'wees'		=> { 'x' => 'be',
 		     'r' => 'zijnn',
		     't' => 'v',
		     'n' => 's',
		     'c' => 'imp' },
 'weest'	=> { 'x' => 'be',
 		     'r' => 'zijn',
		     't' => 'v',
		     'n' => 'p',
		     'c' => 'imp' },
 'was'		=> { 'x' => 'was',
		     '#' => 'ik, jij, hij',
 		     'r' => 'zijn',
		     't' => 'v',
		     'n' => 's',
		     'c' => 't' },
 'waren'	=> { 'x' => 'were',
		     '#' => 'wij, zij',
 		     'r' => 'zijn',
		     't' => 'v',
		     'n' => 'p',
		     'c' => 't' },
 #  hebben - to have
 'hebben'	=> { 'x' => 'have',
 		     't' => 'v' },
 'heeft'	=> { 'x' => 'has',
 		     'r' => 'hebben',
		     't' => 'v' },
 'had'		=> { 'x' => 'had',
 		     'r' => 'hebben',
		     't' => 'v',
		     'c' => 't',
		     '#' => 'ik, jij, hij' },
 'hadden'	=> { 'x' => 'had',
 		     'r' => 'hebben',
		     't' => 'v',
		     'c' => 't',
		     '#' => 'wij, zij' },
 #  kunnen - can
 'kunnen'	=> { 'x' => 'can',
		     '#' => 'may, be able to',
 		     't' => 'v' },
 'kan'		=> { 'x' => 'can',
 		     'r' => 'kunnen',
		     't' => 'v' },
 'kun'		=> { 'x' => 'can',
		     '#' => 'je',
 		     'r' => 'kunnen',
		     't' => 'v' },
 'kunt'		=> { 'x' => 'can',
		     '#' => 'je, U',
 		     'r' => 'kunnen',
		     't' => 'v' },
 'kon'		=> { 'x' => 'could',
		     '#' => 'was able to; ik jij hij',
 		     'r' => 'kunnen',
		     't' => 'v',
		     'c' => 't' },
 'konden'	=> { 'x' => 'could',
		     '#' => 'was able to; wij zij',
 		     'r' => 'kunnen',
		     't' => 'v',
		     'c' => 't' },
 'gekund'	=> { 'x' => 'been able to',
 		     'r' => 'kunnen',
		     't' => 'v',
		     'c' => 'pp' },
 #  moeten - must, have to
 'moeten'	=> { 'x' => 'must',
 		     't' => 'v' },
 #  mogen - may, be allowed to
 'mogen'	=> { 'x' => 'may',
		     '#' => 'be allowed to',
 		     't' => 'v' },
 #  willen - will, want
 #  zullen - shall, will
 'zullen'	=> { 'x' => 'will',
 		     't' => 'v' },
 'zal'		=> { 'x' => 'will',
		     '#' => 'ik hij',
 		     'r' => 'zullen',
		     't' => 'v' },
 'zult'		=> { 'x' => 'will',
 		     'r' => 'zullen',
		     't' => 'v' },
 'zou'		=> { 'x' => 'would',
		     '#' => 'was going to; ik je hij',
 		     'r' => 'zullen',
		     't' => 'v',
		     'c' => 't' },
 'zouden'	=> { 'x' => 'would',
		     '#' => 'was going to; wij zij',
 		     'r' => 'zullen',
		     't' => 'v',
		     'n' => 'p',
		     'c' => 't' },

 # Vocabulary
 'artikel'	=> { 'x' => 'article',
		     't' => 'n' },
 'astronaut'	=> { 'x' => 'astronaut',
 		     't' => 'n' },
 'australi'	=> { 'x' => 'australia',
 		     't' => 'n' },
 'beloven'	=> { 'x' => 'promise',
 		     't' => 'v' },
 'besluit'	=> { 'x' => 'decision',
 		     't' => 'n',
		     'g' => 'n' },
 'beven'	=> { 'x' => 'tremble',
 		     't' => 'v' },
 'bijten'	=> { 'x' => 'bite',
		     '#' => 'strong beet, beten, gebeten',
 		     't' => 'v' },
 'blijven'	=> { 'x' => 'stay',
		     '#' => 'strong bleef, bleven, gebleven',
 		     't' => 'v' },
 'boek'		=> { 'x' => 'book',
 		     't' => 'n',
		     'g' => 'n' },
 'boot'		=> { 'x' => 'boat',
 		     't' => 'n' },
 'branden'	=> { 'x' => 'burn',
 		     't' => 'v' },
 'brief'	=> { 'x' => 'letter',
		     '#' => 'as in mail',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'brood'	=> { 'x' => 'bread',
		     '#' => 'loaf',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'n' },
 'broer'	=> { 'x' => 'brother',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 's' },
 'deur'		=> { 'x' => 'door',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'dozijn'	=> { 'x' => 'dozen',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'n' },
 'duitsland'	=> { 'x' => 'germany',
 		     't' => 'n' },
 'duren'	=> { 'x' => 'last',
		     '#' => 'endure',
 		     't' => 'v' },
 'duur'		=> { 'x' => 'dear',
 		     't' => 'a' },
 'ei'		=> { 'x' => 'egg',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'eieren',
		     '#' => 'plural!' },
 'eieren'	=> { 'x' => 'eggs',
 		     'r' => 'ei',
 		     't' => 'n',
		     'n' => 'p' },
 'elektriciteit'	=> { 'x' => 'electricity',
 			     't' => 'n' },
 'ernstig'	=> { 'x' => 'serious',
 		     't' => 'a' },
 'esperanto'	=> { 'x' => 'esperanto',
 		     't' => 'n' },
 'ezel'		=> { 'x' => 'donkey',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 's' },
 'fiets'	=> { 'x' => 'bicycle',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'gaan'		=> { 'x' => 'go',
 		     't' => 'v' },
 'geloven'	=> { 'x' => 'believe',
 		     't' => 'v' },
 'gemakkelijk'	=> { 'x' => 'easy',
		     '#' => 'easily' },
 'gezang'	=> { 'x' => 'hymn',
 		     't' => 'n',
		     'g' => 'n' },
 'glijden'	=> { 'x' => 'glide',
		     '#' => 'slide strong gleed, gleden, gegleden',
 		     't' => 'v' },
 'goud'		=> { 'x' => 'gold',
 		     't' => 'n',
		     'g' => 'n' },
 'grijpen'	=> { 'x' => 'grip',
		     '#' => 'seize strong greep, grepen, gegrepen',
 		     't' => 'v' },
 'grootmoeder'	=> { 'x' => 'grandmother',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 's' },
 'grootvader'	=> { 'x' => 'grandfather',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 's' },
 'gulden'	=> { 'x' => 'guilder',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 's' },
 'hakken'	=> { 'x' => 'hack',
 		     't' => 'v' },
 'held'		=> { 'x' => 'hero',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'hoed'		=> { 'x' => 'hat',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'hond'		=> { 'x' => 'dog',
 		     't' => 'n',
		     'g' => 'de' },
 'hopen'	=> { 'x' => 'hope',
 		     't' => 'v' },
 'houden'	=> { 'x' => 'hold',
 		     't' => 'v' },
 'hout'		=> { 'x' => 'wood',
 		     't' => 'n' },
 'huis'		=> { 'x' => 'house',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'n' },
 'ijs'		=> { 'x' => 'ice',
 		     't' => 'n' },
 'inhoud'	=> { 'x' => 'contents',
 		     't' => 'n' },
 'jaar'		=> { 'x' => 'year',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'n' },
 'japan'	=> { 'x' => 'japan',
 		     't' => 'n' },
 'kalf'		=> { 'x' => 'calf',
 		     't' => 'n' },
 'kamer'	=> { 'x' => 'room',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 's' },
 'kantoor'	=> { 'x' => 'office',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'n' },
 'kat'		=> { 'x' => 'cat',
 		     't' => 'n' },
 'kiezen'	=> { 'x' => 'choose',
		     '#' => 'strong koos, kozen, gekozen',
 		     't' => 'v' },
 'kijken'	=> { 'x' => 'look',
		     '#' => 'strong keek, keken, gekeken',
 		     't' => 'v' },
 'kind'		=> { 'x' => 'child',
 		     't' => 'n' },
 'kinderen'	=> { 'x' => 'children',
		     'r' => 'kind',
 		     't' => 'n',
		     'n' => 'p' },
 'kindje'	=> { 'x' => 'baby',
 		     't' => 'n',
		     'g' => 'n' },
 'kindertjes'	=> { 'x' => 'babies',
		     'r' => 'kindje',
 		     't' => 'n',
		     'n' => 'p' },
 'klauw'	=> { 'x' => 'claw',
 		     't' => 'n' },
 'klok'		=> { 'x' => 'clock',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'kok'		=> { 'x' => 'cook',
		     '#' => 'male',
 		     't' => 'n' },
 'koken'	=> { 'x' => 'cook',
		     '#' => 'boil',
 		     't' => 'v' },
 'kou'		=> { 'x' => 'cold',
 		     't' => 'n',
		     'g' => 'de' },
 'koud'		=> { 'x' => 'cold',
 		     't' => 'a' },
 'krant'	=> { 'x' => 'newspaper',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'kus'		=> { 'x' => 'kiss',
 		     't' => 'n' },
 'kussen'	=> { 'x' => 'cushion',
 		     't' => 'n' },
 'lachen'	=> { 'x' => 'laugh',
 		     't' => 'v' },
 'lezen'	=> { 'x' => 'read',
		     '#' => 'las, lazen, gelezen',
 		     't' => 'v' },
 'licht'	=> { 'x' => 'light',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'n' },
 'liegen'	=> { 'x' => 'lie',
		     '#' => 'tell lies',
 		     't' => 'v' },
 'lui'		=> { 'x' => 'lazy',
 		     't' => 'a' },
 'maaien'	=> { 'x' => 'mow',
 		     't' => 'v' },
 'man'		=> { 'x' => 'man',
 		     't' => 'n' },
 'malen'	=> { 'x' => 'grind',
 		     't' => 'v' },
 'meel'		=> { 'x' => 'flour',
 		     't' => 'n' },
 'minuut'	=> { 'x' => 'minute',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'modificeren'	=> { 'x' => 'modify',
 		     't' => 'v' },
 'moeder'	=> { 'x' => 'mother',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 's' },
 'morren'	=> { 'x' => 'grumble',
 		     't' => 'v' },
 'noordzee'	=> { 'x' => 'north sea',
 		     't' => 'n',
		     'g' => 'de' },
 'oom'		=> { 'x' => 'uncle',
 		     't' => 'n' },
 'opstaan'	=> { 'x' => 'get up',
		     '#' => 'up-stand, stand up',
 		     't' => 'v' },
 'paard'	=> { 'x' => 'horse',
 		     't' => 'n',
		     'g' => 'n' },
 'papier'	=> { 'x' => 'paper',
 		     't' => 'n',
		     'g' => 'g' },
 'paraguay'	=> { 'x' => 'paraguay',
		     '#' => 'proper; place',
 		     't' => 'n' },
 'pen'		=> { 'x' => 'pen',
 		     't' => 'n' },
 'pil'		=> { 'x' => 'pill',
 		     't' => 'n' },
 'plaats'	=> { 'x' => 'place',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'pot'		=> { 'x' => 'pot',
 		     't' => 'n' },
 'praten'	=> { 'x' => 'talk',
 		     't' => 'v' },
 'raam'		=> { 'x' => 'window',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'n' },
 'recht'	=> { 'x' => 'right',
 		     't' => 'a' },
 'rijden'	=> { 'x' => 'ride',
		     '#' => 'drive strong reed, reden, gereden',
 		     't' => 'v' },
 'rust'		=> { 'x' => 'rest' },
 'ruw'		=> { 'x' => 'rough' },
 'schaap'	=> { 'x' => 'sheep',
 		     't' => 'n',
		     'g' => 'n' },
 'school'	=> { 'x' => 'school',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 'n' },
 'staan'	=> { 'x' => 'stand',
 		     't' => 'v' },
 'sterven'	=> { 'x' => 'die',
		     '#' => 'pp=gestorven',
 		     't' => 'v' },
 'strand'	=> { 'x' => 'sands' },
 'strijden'	=> { 'x' => 'fight',
		     '#' => 'strong streed, streden, gestreden',
 		     't' => 'v' },
 'tabak'	=> { 'x' => 'tobacco',
 		     't' => 'n',
		     'g' => 'de' },
 'tafel'	=> { 'x' => 'table',
 		     't' => 'n' },
 'teken'	=> { 'x' => 'sign',
		     '#' => 'token',
 		     't' => 'n' },
 'uruguay'	=> { 'x' => 'uruguay',
		     '#' => 'proper; place',
 		     't' => 'n' },
 'vader'	=> { 'x' => 'father',
 		     't' => 'n' },
 'vallen'	=> { 'x' => 'fall',
 		     't' => 'v' },
 'venster'	=> { 'x' => 'window',
 		     't' => 'n' },
 'veranderen'	=> { 'x' => 'change',
 		     't' => 'v' },
 'verhaal'	=> { 'x' => 'story',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'n' },
 'verwekken'	=> { 'x' => 'generate',
 		     't' => 'v' },
 'vissen'	=> { 'x' => 'fish',
 		     't' => 'v' },
 'vrouw'	=> { 'x' => 'woman',
 		     't' => 'n' },
 'vuur'		=> { 'x' => 'fire',
 		     't' => 'n',
		     'g' => 'het',
		     'p' => 'p' },
 'winkel'	=> { 'x' => 'shop',
 		     't' => 'n',
		     'g' => 'de' },
 'winter'	=> { 'x' => 'winter',
 		     't' => 'n',
		     'g' => 'de' },
 'woord'	=> { 'x' => 'word',
 		     't' => 'n' },
 'woordenboek'	=> { 'x' => 'dictionary',
 		     't' => 'n' },
 'worden'	=> { 'x' => 'become',
 		     't' => 'v' },
 'zaaien'	=> { 'x' => 'sow',
 		     't' => 'v' },
 'zee'		=> { 'x' => 'sea',
 		     't' => 'n' },
 'zien'		=> { 'x' => 'see',
 		     't' => 'v' },
 'zoon'		=> { 'x' => 'son',
 		     't' => 'n' },
 'zuster'	=> { 'x' => 'sister',
 		     't' => 'n',
		     'g' => 'de',
		     'p' => 's' },
 'zwemmen'	=> { 'x' => 'swim',
 		     't' => 'v' },
);
}

1;

