# vi: ts=8 sw=8 sts=8

package Tongues::Thai;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $charset $grammar %dictionary);

use Exporter   ();
# set the version for version checking
@ISA         = qw(Exporter);
@EXPORT      = qw(charset grammar dictionary);
@EXPORT_OK   = qw();
$VERSION     = 0.00;

# Character set Windows Thai CP874 / TIS-620 

sub new {
	my $class = shift;
	my $self = bless {}, $class;
	return $self;
}

sub charset {
	return $charset;
}

sub grammar {
	return $grammar;
}

sub dictionary {
	return \%dictionary;
}

sub BEGIN {

require Charsets::TIS_620;

$charset = new Charsets::TIS_620;

# Table for converting words to root form
$grammar = [
 # Noun case
 # Noun gender
 # Noun plural
 # Adjectives
 # Verb past participle
 # Verb gerund
 # Verb present participle
 # Verb present
 # Verb present subjunctive
 # Verb imperitive
 # Verb preterite
 # Verb imperfect
 # Verb future
 # Verb conditional
 # Adverb
 # Higher level transformations
];

#Fields:
# x -> translatioin		all words
# r -> root			irregular declensions
# t -> type:			all words
#	n -> noun
#	v -> verb
#	a -> adjective
#	p -> preposition
#	art -> article
#	pro -> pronoun
#	conj -> conjugation
#	adv -> adverb
# g -> gender:			nouns, pronouns, adjectives
#	m -> masculine		default
#	f -> feminine		default for words ending in a
# n -> number:			articles, pronouns, verbs, adjectives
#	s -> singular		default
#	p -> plural		default for words ending in s
# p -> person:			pronouns, verbs
#	1 -> 1st person
#	2 -> 2nd person
#	3 -> 3rd person		default
# c -> conjugation:
#	p -> present
#	i -> imperfect
#	f -> future
#	c -> conditional
#	t -> preterite
#	ps -> present subjunctive
#	is -> imperfect subjunctive
#	inf -> infinitive		default
#	pp -> past participle
#	g -> gerund
#	imp -> imperative

# Thai to English dictionary
%dictionary = (
 # Functional words
 #  Articles
 #   Definite articles
 #    Masculine
 #     Singular
 #     Plural
 #    Feminine
 #     Singular
 #     Plural
 #   Indefinite articles
 #  Pronouns & possessive adjectives
 #   1st person
 #   2nd person
 #   3rd person
 #  Other functional words
 #   Partitive / Contractions
 # Numbers: cardinal and ordinal
 'ٹ'		=> { 'x' => 'zero' },
 '˹'		=> { 'x' => 'one' },
 '˹'		=> { 'x' => 'first',
		     't' => 'a' },
 'ͧ'		=> { 'x' => 'two' },
 'ͧ'		=> { 'x' => 'second',
		     't' => 'a' },
 ''		=> { 'x' => 'three' },
 ''		=> { 'x' => 'four' },
 ''		=> { 'x' => 'five' },
 'ˡ'		=> { 'x' => 'six' },
 ''		=> { 'x' => 'seven' },
 'Ỵ'		=> { 'x' => 'eight' },
 ''		=> { 'x' => 'nine' },
 'Ժ'		=> { 'x' => 'ten' },
 'Ժ'		=> { 'x' => 'twenty' },
 ''		=> { 'x' => 'hundred' },
 'ѹ'		=> { 'x' => 'thousand' },
 'ҹ'		=> { 'x' => 'million' },
 # Days and months
 # From http://oss.software.ibm.com/cgi-bin/icu/lx/en_AU/?_=th&
 'ѹҷԵ'	=> { 'x' => 'sunday' },
 'ѹѹ'	=> { 'x' => 'monday' },
 'ѹѧ'	=> { 'x' => 'tuesday' },
 'ѹظ'		=> { 'x' => 'wednesday' },
 'ѹʺ'	=> { 'x' => 'thursday' },
 'ѹء'	=> { 'x' => 'friday' },
 'ѹ'	=> { 'x' => 'saturday' },
 'Ҥ'	=> { 'x' => 'january' },
 'Ҿѹ'	=> { 'x' => 'february' },
 'չҤ'	=> { 'x' => 'march' },
 '¹'	=> { 'x' => 'april' },
 'Ҥ'	=> { 'x' => 'may' },
 'Զع¹'	=> { 'x' => 'june' },
 'áҤ'	=> { 'x' => 'july' },
 'ԧҤ'	=> { 'x' => 'august' },
 'ѹ¹'	=> { 'x' => 'september' },
 'Ҥ'	=> { 'x' => 'october' },
 'Ȩԡ¹'	=> { 'x' => 'november' },
 'ѹҤ'	=> { 'x' => 'december' },
 # From Glen's dictionary
 'ѹҷԵ'	=> { 'x' => 'sunday',
		     '#' => 'day of the sun',
		     't' => 'n' },
 'ѹѹ'	=> { 'x' => 'monday',
		     '#' => 'day of the moon',
		     't' => 'n' },
 'ѹѧ'	=> { 'x' => 'tuesday',
		     '#' => 'day of mars',
		     't' => 'n' },
 'ѹظ'		=> { 'x' => 'wednesday',
		     '#' => 'day of mercury',
		     't' => 'n' },
 'ѹ'	=> { 'x' => 'thursday',
		     '#' => 'day of jupiter',
		     't' => 'n' },
 'ѹء'	=> { 'x' => 'friday',
		     '#' => 'day of venus',
		     't' => 'n' },
 'ѹ'	=> { 'x' => 'saturday',
		     '#' => 'day of saturn',
		     't' => 'n' },
 'Ҥ'	=> { 'x' => 'january',
		     't' => 'n' },
 'Ҿѹ'	=> { 'x' => 'february',
		     't' => 'n' },
 'չҤ'	=> { 'x' => 'march',
		     't' => 'n' },
 '¹'	=> { 'x' => 'april',
		     't' => 'n' },
 'Ҥ'	=> { 'x' => 'may',
		     't' => 'n' },
 'Զع¹'	=> { 'x' => 'june',
		     't' => 'n' },
 'áҤ'	=> { 'x' => 'july',
		     't' => 'n' },
 'ԧҤ'	=> { 'x' => 'august',
		     't' => 'n' },
 'ѹ¹'	=> { 'x' => 'september',
		     't' => 'n' },
 'Ҥ'	=> { 'x' => 'october',
		     't' => 'n' },
 'ʨԡ¹'	=> { 'x' => 'november',
		     't' => 'n' },
 'ѹҤ'	=> { 'x' => 'december',
		     't' => 'n' },
 # Key verbs
 # Vocabulary
 ''		=> { 'x' => 'chinese',
		     '#' => 'girl; adj. or noun?' },

 # Auto-generated from Glenn Slayden's dicitonary...
 ''		=> { 'x' => 'wheel',
		     '#' => 'rim, circle, arch, arc',
		     't' => 'nf' },
 ''		=> { 'x' => 'grandfather',
		     't' => 'n' },
 'ҧ'	=> { 'x' => 'business',
		     '#' => 'affairs',
		     't' => 'n' },
 ''	=> { 'x' => 'bend over',
		     't' => 'v' },
 ''		=> { 'x' => 'rule',
		     '#' => 'regulation',
		     't' => 'n' },
 ''	=> { 'x' => 'scissors',
		     't' => 'n' },
 ''		=> { 'x' => 'japan',
		     't' => 'n' },
 'Ϳ'	=> { 'x' => 'office',
		     't' => 'nl' },
 ''	=> { 'x' => 'wife',
		     't' => 'n' },
 'á'		=> { 'x' => 'emerald',
		     't' => 'n' },
 ''		=> { 'x' => 'fish',
		     't' => 'n' },
 ''		=> { 'x' => 'flag',
		     't' => 'n' },
 'ء'		=> { 'x' => 'every',
		     't' => 'a' },
 ''		=> { 'x' => 'wheel',
		     't' => 'n' },
 ''		=> { 'x' => 'smile',
		     't' => 'v' },
 ''		=> { 'x' => 'smells bad',
		     't' => 'v' },
 ''		=> { 'x' => 'sore',
		     '#' => 'hurt',
		     't' => 'v' },
 'ŧ'		=> { 'x' => 'song',
		     't' => 'n' },
 ''		=> { 'x' => 'new',
		     't' => 'a' },
 ''		=> { 'x' => 'father',
		     't' => 'n' },
 ''		=> { 'x' => 'chicken',
		     't' => 'n' },
 '͹'		=> { 'x' => 'hot',
		     't' => 'a' },
 ''		=> { 'x' => 'snake',
		     't' => 'n' },
 ''		=> { 'x' => 'rain',
		     't' => 'n' },
 ''		=> { 'x' => 'put in',
		     '#' => 'add',
		     't' => 'v' },
 ''		=> { 'x' => 'egg',
		     't' => 'n' },
 'Ǵ'		=> { 'x' => 'bottle',
		     't' => 'n' },
 ''		=> { 'x' => 'water buffalo',
		     't' => 'n' },
 ''		=> { 'x' => 'person',
		     't' => 'n' },
 'ҹ'		=> { 'x' => 'plate',
		     't' => 'n' },
 ''		=> { 'x' => 'cymbal',
		     't' => 'n' },
 'ҧ'		=> { 'x' => 'elephant',
		     't' => 'n' },
 ''		=> { 'x' => 'bush',
		     't' => 'n' },
 '˭ԧ'		=> { 'x' => 'woman',
		     't' => 'n' },
 ''		=> { 'x' => 'novice',
		     '#' => 'monk',
		     't' => 'n' },
 ''		=> { 'x' => 'child',
		     '#' => 'kid',
		     't' => 'n' },
 ''		=> { 'x' => 'turtle',
		     't' => 'n' },
 ''		=> { 'x' => 'soldier',
		     't' => 'n' },
 '˹'		=> { 'x' => 'mouse',
		     't' => 'n' },
 ''		=> { 'x' => 'leaf',
		     't' => 'n' },
 ''		=> { 'x' => 'bee',
		     't' => 'n' },
 'ѹ'		=> { 'x' => 'tooth',
		     't' => 'n' },
 ''		=> { 'x' => 'horse',
		     't' => 'n' },
 ''		=> { 'x' => 'boat',
		     't' => 'n' },
 'ԧ'		=> { 'x' => 'monkey',
		     't' => 'n' },
 'ǹ'		=> { 'x' => 'ring',
		     't' => 'n' },
 ''		=> { 'x' => 'tiger',
		     't' => 'n' },
 ''		=> { 'x' => 'kite',
		     't' => 'n' },
 '١'		=> { 'x' => 'owl',
		     't' => 'n' },
 'ʴ'		=> { 'x' => 'hello',
		     '#' => 'goodbye',
		     't' => 'interj' },
 ''		=> { 'x' => 'be',
		     '#' => 'is, was',
		     't' => 'v' },
 ''		=> { 'x' => 'this',
		     't' => 'pro' },
 ''		=> { 'x' => 'not',
		     '#' => 'no' },
 ''		=> { 'x' => 'go',
		     '#' => 'goes, went',
		     't' => 'v' },
 'ٴ'		=> { 'x' => 'speak',
		     't' => 'v' },
 ''		=> { 'x' => 'language',
		     't' => 'v' },
 ''		=> { 'x' => 'want',
		     't' => 'v' },
 'ͺس'	=> { 'x' => 'thank you',
		     't' => 'interj' },
 'س'		=> { 'x' => 'mr.',
		     '#' => 'mrs.',
		     't' => 'pro' },
 ''		=> { 'x' => 'also',
		     '#' => 'well, therefore.' },
 ''		=> { 'x' => 'spicy',
		     't' => 'a' },
 'ҡ'		=> { 'x' => 'much',
		     't' => 'adv' },
 'ᾧ'		=> { 'x' => 'expensive',
		     't' => 'a' },
 ''		=> { 'x' => 'what' },
 '˹ѧ'		=> { 'x' => 'cinema',
		     '#' => 'film, movie',
		     't' => 'n' },
 ''		=> { 'x' => 'yes',
		     '#' => 'agree, think so',
		     't' => 'n' },
 'ö¹'	=> { 'x' => 'car',
		     '#' => 'automobile',
		     't' => 'n' },
 '硫'		=> { 'x' => 'taxi',
		     '#' => 'cab',
		     't' => 'n' },
 'ͧٻ'	=> { 'x' => 'camera',
		     't' => 'n' },
 'ѡ'		=> { 'x' => 'know',
		     't' => 'v' },
 'ҹ'		=> { 'x' => 'house',
		     't' => 'n' },
 ''		=> { 'x' => 'hill',
		     '#' => 'she, they, them, him, her, mountain',
		     't' => 'n' },
 'ҡ͹'	=> { 'x' => 'goodbye',
		     't' => 'interj' },
 'ҪԹ'		=> { 'x' => 'queen',
		     't' => 'n' },
 'е'	=> { 'x' => 'rabbit',
		     't' => 'n' },
 ''		=> { 'x' => 'cow',
		     't' => 'n' },
 'մ'		=> { 'x' => 'knife',
		     't' => 'n' },
 ''		=> { 'x' => 'cat',
		     't' => 'n' },
 ''		=> { 'x' => 'dog',
		     't' => 'n' },
 'ء'		=> { 'x' => 'jail',
		     '#' => 'prison',
		     't' => 'n' },
 ''	=> { 'x' => 'garlic',
		     't' => 'n' },
 ''		=> { 'x' => 'trash',
		     '#' => 'garbage',
		     't' => 'n' },
 '͹'		=> { 'x' => 'friend',
		     't' => 'n' },
 'ش'		=> { 'x' => 'period',
		     '#' => 'dot, decimal point',
		     't' => 'n' },
 'ʹء'		=> { 'x' => 'fun',
		     't' => 'a' },
 ''	=> { 'x' => 'nation',
		     '#' => 'country',
		     't' => 'n' },
 ''		=> { 'x' => 'crab',
		     't' => 'n' },
 ''		=> { 'x' => 'nun',
		     't' => 'n' },
 ''		=> { 'x' => 'nun',
		     't' => 'n' },
 ''		=> { 'x' => 'hungry',
		     't' => 'a' },
 ''		=> { 'x' => 'here',
		     't' => 'p' },
 ''	=> { 'x' => 'food',
		     't' => 'n' },
 ''		=> { 'x' => 'fire',
		     '#' => 'electric light, electricity',
		     't' => 'n' },
 ''		=> { 'x' => 'come',
		     't' => 'v' },
 ''		=> { 'x' => 'address',
		     't' => 'n' },
 'ҵ'		=> { 'x' => 'death',
		     '#' => 'fate, end',
		     't' => 'n' },
 ''		=> { 'x' => 'buy',
		     '#' => 'purchase',
		     't' => 'v' },
 'ػ'		=> { 'x' => 'soup',
		     't' => 'n' },
 '૿'		=> { 'x' => 'safe',
		     't' => 'n' },
 '͡'	=> { 'x' => 'flower',
		     't' => 'n' },
 ''		=> { 'x' => 'pork',
		     't' => 'na' },
 ''		=> { 'x' => 'beef',
		     '#' => 'meat',
		     't' => 'na' },
 ''		=> { 'x' => 'believe',
		     't' => 'v' },
 ''		=> { 'x' => 'beat',
		     '#' => 'hit, strike',
		     't' => 'v' },
 ''	=> { 'x' => 'because',
		     '#' => 'reason',
		     't' => 'conj' },
 ''		=> { 'x' => 'crow',
		     't' => 'n' },
 ''		=> { 'x' => 'city',
		     '#' => 'municipality',
		     't' => 'n' },
 'ا෾'	=> { 'x' => 'bangkok',
		     't' => 'n' },
 ''		=> { 'x' => 'also',
		     '#' => 'too, likewise' },
 ''		=> { 'x' => 'music',
		     't' => 'n' },
 'Ό'		=> { 'x' => 'boyfriend',
		     '#' => 'girlfriend, lover',
		     't' => 'nl' },
 ''		=> { 'x' => 'beer',
		     't' => 'nl' },
 '˭'		=> { 'x' => 'big',
		     '#' => 'large',
		     't' => 'a' },
 'ѡҹ'	=> { 'x' => 'bicycle',
		     't' => 'n' },
 ''		=> { 'x' => 'small',
		     't' => 'a' },
 ''		=> { 'x' => 'far',
		     '#' => 'distant',
		     't' => 'p' },
 ''		=> { 'x' => 'near',
		     '#' => 'close',
		     't' => 'p' },
 'ǹ'		=> { 'x' => 'fat',
		     '#' => 'overweight',
		     't' => 'a' },
 'Ҵ'		=> { 'x' => 'smart',
		     '#' => 'intelligent',
		     't' => 'a' },
 ''		=> { 'x' => 'softly',
		     't' => 'adv' },
 'ʵ'	=> { 'x' => 'stamp',
		     't' => 'n' },
 'Ѿ'	=> { 'x' => 'telephone',
		     't' => 'n' },
 'Թ'	=> { 'x' => 'violin',
		     't' => 'nl' },
 ''		=> { 'x' => 'view',
		     't' => 'nl' },
 ''		=> { 'x' => 'have',
		     '#' => 'possess',
		     't' => 'v' },
 'ɳ'	=> { 'x' => 'post office',
		     't' => 'n' },
 ''		=> { 'x' => 'fruit',
		     't' => 'n' },
 ''		=> { 'x' => 'empty',
		     '#' => 'finished',
		     't' => 'a' },
 ''		=> { 'x' => 'already',
		     '#' => 'past, still',
		     't' => 'adv' },
 '˹ҵҧ'	=> { 'x' => 'window',
		     't' => 'n' },
 '¹'		=> { 'x' => 'study',
		     't' => 'v' },
 '֡'		=> { 'x' => 'study',
		     't' => 'v' },
 'ҧ'		=> { 'x' => 'vacant',
		     '#' => 'free, available, empty',
		     't' => 'a' },
 'š'		=> { 'x' => 'earth',
		     '#' => 'world',
		     't' => 'n' },
 '¹'		=> { 'x' => 'write',
		     't' => 'v' },
 'Ѻ'		=> { 'x' => 'with',
		     't' => 'p' },
 ''		=> { 'x' => 'and',
		     't' => 'conj' },
 ''		=> { 'x' => 'but',
		     't' => 'conj' },
 'ͧ'	=> { 'x' => 'taxi',
		     '#' => 'pickup truck',
		     't' => 'n' },
 'ç'	=> { 'x' => 'hotel',
		     't' => 'n' },
 ''	=> { 'x' => 'hotel',
		     't' => 'nl' },
 'çҺ'	=> { 'x' => 'hospital',
		     't' => 'n' },
 'Թ'		=> { 'x' => 'walk',
		     't' => 'v' },
 ''		=> { 'x' => 'thai',
		     't' => 'a' },
 ''	=> { 'x' => 'thai person',
		     't' => 'n' },
 ''		=> { 'x' => 'caucasian',
		     't' => 'al' },
 ''		=> { 'x' => 'skilled',
		     '#' => 'talented',
		     't' => 'a' },
 ''		=> { 'x' => 'coffee',
		     't' => 'nl' },
 ''		=> { 'x' => 'water',
		     '#' => 'liquid',
		     't' => 'na' },
 '§'	=> { 'x' => 'chiang rai',
		     't' => 'n' },
 '§'	=> { 'x' => 'chiang mai',
		     't' => 'n' },
 'ոҪ'	=> { 'x' => 'nakhon si thammarat',
		     't' => 'n' },
 ''		=> { 'x' => 'phuket',
		     't' => 'n' },
 ''	=> { 'x' => 'gaw samui',
		     't' => 'n' },
 'Ҫ'	=> { 'x' => 'khorat',
		     't' => 'n' },
 ''		=> { 'x' => 'fast',
		     '#' => 'quick',
		     't' => 'a' },
 ''		=> { 'x' => 'city',
		     't' => 'n' },
 'ѧѴ'	=> { 'x' => 'province',
		     't' => 'n' },
 ''		=> { 'x' => 'namely',
		     '#' => 'simply',
		     't' => 'conj' },
 'ԡ'	=> { 'x' => 'america',
		     '#' => 'united states',
		     't' => 'n' },
 ''	=> { 'x' => 'thailand',
		     't' => 'n' },
 'ȡ٪'	=> { 'x' => 'cambodia',
		     't' => 'n' },
 ''	=> { 'x' => 'australia',
		     't' => 'n' },
 ''		=> { 'x' => 'burma',
		     '#' => 'myanmar',
		     't' => 'n' },
 '᤹Ҵ'	=> { 'x' => 'canada',
		     't' => 'n' },
 'չ'		=> { 'x' => 'china',
		     't' => 'n' },
 'ѧ'	=> { 'x' => 'england',
		     '#' => 'english, great britain',
		     't' => 'n' },
 ''	=> { 'x' => 'france',
		     't' => 'n' },
 '´'	=> { 'x' => 'vietnam',
		     't' => 'n' },
 ''		=> { 'x' => 'laos',
		     't' => 'n' },
 ''	=> { 'x' => 'korea',
		     't' => 'n' },
 ''	=> { 'x' => 'malaysia',
		     't' => 'n' },
 'ԧ'	=> { 'x' => 'singapore',
		     't' => 'n' },
 'ѹ'	=> { 'x' => 'german',
		     't' => 'n' },
 'Ե'	=> { 'x' => 'italy',
		     't' => 'n' },
 '໹'	=> { 'x' => 'spain',
		     't' => 'n' },
 ''		=> { 'x' => 'table',
		     't' => 'n' },
 ''		=> { 'x' => 'chair',
		     't' => 'n' },
 'д'	=> { 'x' => 'paper',
		     't' => 'n' },
 'Թ'		=> { 'x' => 'pencil',
		     't' => 'n' },
 'ҡ'	=> { 'x' => 'pen',
		     't' => 'n' },
 ''		=> { 'x' => 'than',
		     't' => 'conj' },
 ''		=> { 'x' => 'rice',
		     't' => 'n' },
 'ͧ'	=> { 'x' => 'restroom',
		     '#' => 'bathroom, toilet',
		     't' => 'n' },
 'ҹ'	=> { 'x' => 'restaurant',
		     't' => 'n' },
 ''	=> { 'x' => 'piano',
		     't' => 'nl' },
 ''		=> { 'x' => 'bird',
		     't' => 'n' },
 ''		=> { 'x' => 'butterfly',
		     't' => 'n' },
 'öԤѾ'	=> { 'x' => 'pickup truck',
		     't' => 'nl' },
 ''		=> { 'x' => 'sew',
		     't' => 'v' },
 '١'	=> { 'x' => 'son',
		     't' => 'n' },
 ''		=> { 'x' => 'shy',
		     't' => 'a' },
 'Թ'		=> { 'x' => 'money',
		     '#' => 'silver',
		     't' => 'n' },
 ''		=> { 'x' => 'sister',
		     't' => 'n' },
 'ͧ'	=> { 'x' => 'sister',
		     't' => 'n' },
 ''		=> { 'x' => 'sky',
		     't' => 'n' },
 ''		=> { 'x' => 'stupid',
		     '#' => 'silly, dumb',
		     't' => 'a' },
 '͹'	=> { 'x' => 'similar',
		     '#' => 'like',
		     't' => 'a' },
 ''		=> { 'x' => 'if',
		     't' => 'conj' },
 ''		=> { 'x' => 'look',
		     '#' => 'examine, inspect',
		     't' => 'v' },
 ''		=> { 'x' => 'ask for',
		     '#' => 'request, like',
		     't' => 'v' },
 ''		=> { 'x' => 'mountain',
		     '#' => 'hill',
		     't' => 'n' },
 ''		=> { 'x' => 'golf',
		     't' => 'nl' },
 ''		=> { 'x' => 'good',
		     't' => 'a' },
 ''		=> { 'x' => 'bad',
		     't' => 'a' },
 '⪤'	=> { 'x' => 'bad luck',
		     't' => 'n' },
 '⪤'		=> { 'x' => 'good luck',
		     't' => 'n' },
 'Դ'		=> { 'x' => 'open',
		     '#' => 'turn on',
		     't' => 'v' },
 'Դ'		=> { 'x' => 'close',
		     '#' => 'turn off',
		     't' => 'v' },
 'Ѵ'		=> { 'x' => 'fan',
		     't' => 'n' },
 '١'		=> { 'x' => 'true',
		     '#' => 'correct, right',
		     't' => 'a' },
 ''		=> { 'x' => 'cool',
		     't' => 'a' },
 '˹'		=> { 'x' => 'cold',
		     't' => 'a' },
 ''		=> { 'x' => 'don\'t...' },
 'ҡ'		=> { 'x' => 'want',
		     '#' => 'desire' },
 'Ҵ'		=> { 'x' => 'market',
		     't' => 'n' },
 'ͧ'		=> { 'x' => 'must',
		     '#' => 'have to' },
 'ԾԸѳ'	=> { 'x' => 'museum',
		     't' => 'n' },
 'ç'		=> { 'x' => 'straight',
		     't' => 'a' },
 'ҷ'		=> { 'x' => 'baht',
		     't' => 'n' },
 ''		=> { 'x' => 'cloud',
		     't' => 'n' },
 'ͧ'		=> { 'x' => 'gong',
		     '#' => 'cymbal',
		     't' => 'n' },
 ''		=> { 'x' => 'frog',
		     't' => 'n' },
 'ø'		=> { 'x' => 'anger',
		     '#' => 'angry',
		     't' => 'v' },
 ''		=> { 'x' => 'angry',
		     '#' => 'furious',
		     't' => 'a' },
 ''	=> { 'x' => 'crazy',
		     't' => 'a' },
 ''	=> { 'x' => 'excuse me',
		     't' => 'interj' },
 ''	=> { 'x' => 'crocodile',
		     't' => 'n' },
 'ѵ'		=> { 'x' => 'animal',
		     't' => 'n' },
 'е'		=> { 'x' => 'door',
		     '#' => 'gate',
		     't' => 'n' },
 ''		=> { 'x' => 'doctor',
		     't' => 'n' },
 'Ѻ'		=> { 'x' => 'yes' },
 ''		=> { 'x' => 'yes' },
 #  no E, but there is D...
 ''		=> { 'x' => 'hair',
		     '#' => 'me, my',
		     't' => 'n' },
 'ҹѴ'	=> { 'x' => 'barbershop',
		     't' => 'n' },
 'ԩѹ'		=> { 'x' => 'i',
		     '#' => 'me',
		     't' => 'pro' },
 'ѹ'		=> { 'x' => 'i',
		     '#' => 'me',
		     't' => 'pro' },
 ''		=> { 'x' => 'we',
		     't' => 'pro' },
 '§'		=> { 'x' => 'bed',
		     't' => 'n' },
 'ͧ͹'	=> { 'x' => 'bedroom',
		     't' => 'n' },
 ''	=> { 'x' => 'sorry',
		     't' => 'n' },
 ''	=> { 'x' => 'understand',
		     '#' => 'comprehend',
		     't' => 'v' },
 ''		=> { 'x' => 'left',
		     't' => 'a' },
 ''		=> { 'x' => 'right',
		     't' => 'a' },
 ''		=> { 'x' => 'turn',
		     't' => 'v' },
 ''		=> { 'x' => 'television',
		     't' => 'nl' },
 'Կ'		=> { 'x' => 'elevator',
		     't' => 'nl' },
 ''	=> { 'x' => 'letter',
		     't' => 'n' },
 'й'	=> { 'x' => 'lime',
		     '#' => 'lemon',
		     't' => 'n' },
 'ԧ'		=> { 'x' => 'ginger',
		     't' => 'n' },
 ''		=> { 'x' => 'glass',
		     't' => 'n' },
 'ʹ'		=> { 'x' => 'fry',
		     '#' => 'fried',
		     't' => 'va' },
 ''		=> { 'x' => 'send',
		     '#' => 'deliver',
		     't' => 'v' },
 'Ѻ'		=> { 'x' => 'return',
		     't' => 'v' },
 ''		=> { 'x' => 'sea',
		     't' => 'n' },
 'ԡ'	=> { 'x' => 'watch',
		     '#' => 'timepiece, clock',
		     't' => 'n' },
 'ء'		=> { 'x' => 'ripe',
		     '#' => 'heated',
		     't' => 'a' },
 ''		=> { 'x' => 'finished',
		     '#' => 'completed',
		     't' => 'a' },
 'ѧ'		=> { 'x' => 'yet',
		     't' => 'adv' },
 'ͻ'	=> { 'x' => 'apple',
		     't' => 'nl' },
 ''	=> { 'x' => 'computer',
		     't' => 'nl' },
 '˹ѧ'	=> { 'x' => 'book',
		     't' => 'n' },
 ''		=> { 'x' => 'word',
		     '#' => 'term',
		     't' => 'n' },
 '٧'		=> { 'x' => 'tall',
		     't' => 'a' },
 ''		=> { 'x' => 'short',
		     't' => 'a' },
 'ѹ'		=> { 'x' => 'today',
		     't' => 'n' },
 ''		=> { 'x' => 'shirt',
		     't' => 'n' },
 'ҧࡧ'	=> { 'x' => 'pants',
		     't' => 'n' },
 'ا'		=> { 'x' => 'mosquito' },
 ''		=> { 'x' => 'forget',
		     't' => 'v' },
 'ѡ'		=> { 'x' => 'love',
		     't' => 'v' },
 'ѡ'		=> { 'x' => 'cute',
		     't' => 'a' },
 'öԴ'		=> { 'x' => 'traffic jam',
		     't' => 'n' },
 'ö'		=> { 'x' => 'train',
		     't' => 'n' },
 'ѹ'	=> { 'x' => 'taiwan',
		     't' => 'pa' },
 'ѧ'		=> { 'x' => 'careful',
		     '#' => 'warning',
		     't' => 'v' },
 'ä'		=> { 'x' => 'disease',
		     't' => 'n' },
 ''		=> { 'x' => 'will',
		     't' => 'adv' },
 '͡'		=> { 'x' => 'exit',
		     't' => 'n' },
 'ͧ'		=> { 'x' => 'city',
		     '#' => 'nation, country',
		     't' => 'n' },
 ''		=> { 'x' => 'old',
		     't' => 'a' },
 ''		=> { 'x' => 'old',
		     't' => 'a' },
 ''		=> { 'x' => 'many',
		     't' => 'a' },
 'ѹ'		=> { 'x' => 'day',
		     't' => 'n' },
 'ҷԵ'	=> { 'x' => 'week',
		     't' => 'n' },
 'ç¹'	=> { 'x' => 'school',
		     't' => 'n' },
 'Է'	=> { 'x' => 'university',
		     't' => 'n' },
 'ٻ'	=> { 'x' => 'photograph',
		     '#' => 'picture',
		     't' => 'n' },
 ''		=> { 'x' => 'towards',
		     '#' => 'to, give',
		     't' => 'v' },
 'ա'		=> { 'x' => 'another',
		     '#' => 'after, additional',
		     't' => 'a' },
 '͹'		=> { 'x' => 'month',
		     't' => 'n' },
 ''		=> { 'x' => 'single',
		     '#' => 'one',
		     't' => 'a' },
 ''		=> { 'x' => 'not',
		     '#' => 'void, empty',
		     't' => 'na' },
 ''		=> { 'x' => 'or',
		     't' => 'conj' },
 ''		=> { 'x' => 'that',
		     't' => 'conj' },
 ''		=> { 'x' => 'speak',
		     '#' => 'say',
		     't' => 'v' },
 ''		=> { 'x' => 'permanent',
		     't' => 'a' },
 ''		=> { 'x' => 'forsake',
		     '#' => 'abandon, leave',
		     't' => 'v' },
 'ʺ'		=> { 'x' => 'happy',
		     '#' => 'comfortable, content',
		     't' => 'v' },
 '֧'		=> { 'x' => 'towards',
		     '#' => 'arrive, about',
		     't' => 'p' },
 '֧'		=> { 'x' => 'thus',
		     '#' => 'therefore, so',
		     't' => 'conj' },
 ''		=> { 'x' => 'can',
		     '#' => 'able, obtain',
		     't' => 'v' },
 ''		=> { 'x' => 'silk',
		     't' => 'n' },
 'ͧ'		=> { 'x' => 'of',
		     '#' => 'belongings',
		     't' => 'a' },
 ''		=> { 'x' => 'fall',
		     't' => 'v' },
 '⪤'		=> { 'x' => 'luck',
		     't' => 'n' },
 #  no E, but there is D...
 ''		=> { 'x' => 'island',
		     't' => 'n' },
 ''		=> { 'x' => 'name',
		     't' => 'n' },
 ''		=> { 'x' => 'man',
		     't' => 'n' },
 '˭ԧ'		=> { 'x' => 'woman',
		     't' => 'n' },
 'ǹ'		=> { 'x' => 'think',
		     '#' => 'portion, fraction',
		     't' => 'n' },
 'Դ'		=> { 'x' => 'think',
		     '#' => 'consider, imagine',
		     't' => 'v' },
 ''		=> { 'x' => 'just',
		     '#' => 'recently',
		     't' => 'a' },
 ''		=> { 'x' => 'how many',
		     't' => 'adv' },
 ''		=> { 'x' => 'together',
		     '#' => 'as well, along with',
		     't' => 'adv' },
 ''		=> { 'x' => 'when' },
 'ҹ'	=> { 'x' => 'yesterday',
		     't' => 'n' },
 'ͺ'		=> { 'x' => 'like',
		     '#' => 'enjoy, prefer',
		     't' => 'v' },
 'ҡ'		=> { 'x' => 'from',
		     't' => 'v' },
 ''		=> { 'x' => 'wait',
		     't' => 'v' },
 'ҧࡧ'	=> { 'x' => 'underwear',
		     '#' => 'briefs',
		     't' => 'n' },
 ''		=> { 'x' => 'glenn',
		     't' => 'n' },
 'ᴧ'		=> { 'x' => 'red',
		     't' => 'a' },
 ''	=> { 'x' => 'green',
		     't' => 'a' },
 'ͧ'	=> { 'x' => 'yellow',
		     't' => 'a' },
 'տ'		=> { 'x' => 'blue',
		     't' => 'a' },
 'ǧ'		=> { 'x' => 'purple',
		     't' => 'a' },
 'մ'		=> { 'x' => 'black',
		     't' => 'a' },
 'բ'		=> { 'x' => 'white',
		     't' => 'a' },
 'չӵ'	=> { 'x' => 'brown',
		     't' => 'a' },
 'ժ'		=> { 'x' => 'pink',
		     't' => 'a' },
 ''		=> { 'x' => 'orange',
		     't' => 'a' },
 'չԹ'	=> { 'x' => 'blue',
		     't' => 'a' },
 ''		=> { 'x' => 'gray',
		     't' => 'a' },
 '͵'	=> { 'x' => 'seattle',
		     't' => 'n' },
 ''		=> { 'x' => 'live',
		     '#' => 'reside',
		     't' => 'v' },
 ''		=> { 'x' => 'at',
		     't' => 'p' },
 '˹'		=> { 'x' => 'where' },
 # Ф no E, but there is D...
 '§'		=> { 'x' => 'noon' },
 '§׹'	=> { 'x' => 'midnight' },
 '׹'		=> { 'x' => 'night' },
 ''		=> { 'x' => 'morning' },
 ''		=> { 'x' => 'evening' },
 'ҷ'		=> { 'x' => 'minute',
		     't' => 'n' },
 'ѧ'		=> { 'x' => 'hope',
		     '#' => 'expect, want',
		     't' => 'v' },
 'Ѻ'		=> { 'x' => 'receive',
		     '#' => 'get, accept',
		     't' => 'v' },
 ''		=> { 'x' => 'further',
		     '#' => 'beyond, more, extremely',
		     't' => 'adv' },
 '͡'		=> { 'x' => 'outside',
		     '#' => 'external, foreign, alien',
		     't' => 'a' },
 ''		=> { 'x' => 'that one',
		     't' => 'a' },
 ''		=> { 'x' => 'over there',
		     't' => 'a' },
 'á'		=> { 'x' => 'first',
		     '#' => 'primary, initial',
		     't' => 'a' },
 'Ѻ'		=> { 'x' => 'transcript',
		     '#' => 'document, copy',
		     't' => 'n' },
 ''		=> { 'x' => 'affair',
		     '#' => 'subject, matter, topic, feeling, substance' },
 '͹'		=> { 'x' => 'period',
		     '#' => 'section, portion',
		     't' => 'n' },
 'Ѵ'		=> { 'x' => 'select',
		     '#' => 'pick, choose',
		     't' => 'v' },
 #  no E, but there is D...
 'ҧ'		=> { 'x' => 'some',
		     '#' => 'any, partially',
		     't' => 'ad' },
 'ҧ'		=> { 'x' => 'some',
		     't' => 'ad' },
 'Һ'		=> { 'x' => 'know',
		     't' => 'v' },
 ''		=> { 'x' => 'know',
		     't' => 'v' },
 ''		=> { 'x' => 'trip',
		     '#' => 'vacation, tour',
		     't' => 'nv' },
 ''		=> { 'x' => 'year',
		     't' => 'n' },
 ''		=> { 'x' => 'this',
		     't' => 'a' },
 'ѡ'		=> { 'x' => 'person who',
		     '#' => 'enthusiast, devotee, expert',
		     't' => 'na' },
 ''		=> { 'x' => 'origin',
		     '#' => 'beginning, start',
		     't' => 'n' },
 ''		=> { 'x' => 'support',
		     '#' => 'level, flush, team with, equal',
		     't' => 'v' },
 'ҹ'		=> { 'x' => 'read',
		     't' => 'v' },
 'Ѵ'		=> { 'x' => 'sharp',
		     '#' => 'clear, focused',
		     't' => 'a' },
 ''		=> { 'x' => 'use',
		     't' => 'v' },
 ''		=> { 'x' => 'time',
		     't' => 'n' },
 'ҳ'	=> { 'x' => 'approximately',
		     '#' => 'about',
		     't' => 'adv' },
 'ӧҹ'	=> { 'x' => 'work',
		     't' => 'v' },
 ''		=> { 'x' => 'play',
		     't' => 'v' },
 'Է'	=> { 'x' => 'college',
		     't' => 'n' },
 '˹'		=> { 'x' => 'face',
		     '#' => 'front, next',
		     't' => 'n' },
 ''		=> { 'x' => 'road',
		     't' => 'n' },
 'Ҥ'	=> { 'x' => 'bank',
		     't' => 'n' },
 ''	=> { 'x' => 'hour',
		     't' => 'n' },
 'Ѻ'		=> { 'x' => 'capture',
		     't' => 'v' },
 '   '	=> { 'x' => 'leader',
		     't' => 'n' },
 ''		=> { 'x' => 'lane',
		     't' => 'n' },
 'ͧ'	=> { 'x' => 'tile',
		     '#' => 'porcelain, ceramic, earthenware',
		     't' => 'n' },
 'ͧپ'	=> { 'x' => 'tile',
		     '#' => 'floor',
		     't' => 'n' },
 'ԧ'		=> { 'x' => 'lion',
		     't' => 'n' },
 '١ '	=> { 'x' => 'daughter',
		     't' => 'n' },
);
}

1;

